# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qtcanvas import QCanvasRectangle, QCanvasText
from qt import QBrush, QColor, QFont, QFontMetrics, QInputDialog, QLineEdit

class CanvasLabel(QCanvasRectangle):


    def __init__(self, parent, canvas, text):

        self.parent = parent
        self.canvas = canvas
        self.type = "label"

        self.color = QColor(80, 80, 80)
        self.selectColor = QColor(4, 115, 137)
        self.textCanvas = None
        
        QCanvasRectangle.__init__(self, self.canvas)

        nodeX = self.parent.x()
        nodeY = self.parent.y()
        nodeHeight = self.parent.height()
        nodeWidth = self.parent.width()
                
        self.setX(nodeX+2)
        self.setY(nodeY + nodeHeight - 2)
        self.setZ(parent.z() + 1)
        self.setBrush(QBrush(self.color))

        self._set_text(text)

        self.show()
        self.canvas.update()

        # evil hack to get getType() and getParent() into QCanvasText, blame Reidar, he showed me how to do it >:)
        QCanvasText.getType = self.getType
        QCanvasText.type = self.type
        QCanvasText.getParent = self.getParent
        QCanvasText.parent = self.parent

    def _set_text(self, text):
        self.text = text

        metric = QFontMetrics(QFont("Ariel", 8))
        self.length = metric.width(text, len(text))

        if self.textCanvas:
            self.textCanvas.setCanvas(None)

        self.textCanvas = QCanvasText(text, QFont("Ariel", 8), self.canvas)
        self.textCanvas.setX(self.x() + 2)
        self.textCanvas.setY(self.y() + 1)
        self.textCanvas.setZ(self.z() + 1)
        self.textCanvas.setColor(QColor(255, 255, 255))
        self.textCanvas.show()

        self.setSize(self.length + 5, 16)

    def move(self, dx, dy):
        self.moveBy(dx, dy)
        self.textCanvas.moveBy(dx, dy)

    def getType(self):
        return self.type

    def getParent(self):
        return self.parent

    def delete(self):
        self.textCanvas.setCanvas(None)
        self.setCanvas(None)
        self.canvas.update()
        del self

    def newZ(self, z):
        self.setZ(z)
        self.textCanvas.setZ(z+1)
        self.canvas.update()

    def set_hightlight(self, value=True):
        if value:
            self.setBrush(QBrush(self.selectColor))
        else:
            self.setBrush(QBrush(self.color))
        self.canvas.update()

    def interactive_rename(self):
        new_name, ok = QInputDialog.getText("Renaming node %s..." % self.text,
                                            "New name:", QLineEdit.Normal,
                                            self.text)

        if ok:
            self._set_text(str(new_name))
            self.parent.getDiagramNode().setName(self.text)
            self.canvas.update()
