# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.


from qt import QColor, QPen, Qt
from qtcanvas import QCanvasLine
 
from Library.Util.Config import Config

class CanvasLine(QCanvasLine):
    """General class for displaying canvas items"""


    def __init__(self, parent, canvas, start, end, cap_style=Qt.FlatCap):
        """creates a canvasline going from start to end"""

        QCanvasLine.__init__(self, canvas)
        
        self.type = "link"

        self.parent = parent
        self._cap_style = cap_style

        # Setup the pen used for drawing the line.
        pen = QPen(QColor(Config.lineR, Config.lineG, Config.lineB), Config.lineWidth)
        pen.setJoinStyle(Qt.RoundJoin)
        pen.setCapStyle(self._cap_style)
        
        self.setPen(pen)
        self.setPoints(start.x(), start.y(), end.x(), end.y())
        self.setZ(-1)
        self.show()

    def getType(self):
        return self.type

    def delete(self):
        """removes this line from the cavas"""
        self.setCanvas(None)
        del self
    
    def getParent(self):
        return self.parent
        
    def changeColor(self, color):
        if self.canvas():
            pen = QPen(QColor(color), Config.lineWidth)
            pen.setCapStyle(self._cap_style)
            pen.setJoinStyle(Qt.RoundJoin)
            self.setPen(pen)
            self.canvas().update()
       
    def getPoints(self):
        return [self.startPoint(), self.endPoint()]
