# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qt import QColor, QPen
from qtcanvas import QCanvasLine

from Library.Util.Config import Config

class CanvasMarkLine(QCanvasLine):
    """Class for displaying a thin line"""


    def __init__(self, parent, canvas, start, z):
        """creates a canvasline going from start to end"""

        self.canvas = canvas

        apply(QCanvasLine.__init__, (self, self.canvas))
        
        self.type = "link"
        self.start = start        
        self.parent = parent
        
        self.setPen(QPen(QColor(Config.lineR, Config.lineG, Config.lineB), max(Config.lineWidth-2, 1)))
        self.setZ(z-1)
        self.show()
        self.canvas.update()


    def updatePosition(self, pos):
        self.setPoints(self.start.x(), self.start.y(), pos.x(), pos.y())
        #self.setZ(-1)
        self.canvas.update()
        

    def getType(self):
        return self.type


    def delete(self):
        """removes this line from the cavas"""
        self.setCanvas(None)
        self.canvas.update()
        del self

    
    def getParent(self):
        return self.parent
        

    

        
