# -*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qt import QFileDialog, QMessageBox, QSize, QTabWidget, QVBoxLayout
from qt import QWidget, qApp
from GUI.Plots import PlotWindowSetupWidget
from GUI.Plots.DataFilterController import DataFilterController
from Library.Util.Config import Config
from xml.dom import minidom
import os
import os.path

class MoleculeEditorWindowControl(QWidget):
    """Class for setting up the editor window to the users specification"""
    def __init__(self, gui, node, parent, name=None):
        QWidget.__init__(self, parent, name, 0)

        if not name:
            self.setName("plotControl")

        # self.centralLayout = QVBoxLayout(self.widget(), 11, 6, "centralLayout")
        
        self.gui = gui
        self.finished = False
        self.node = node
        self.filterControl = DataFilterController(self)
        self.outputData = []

        self.plotControlLayout = QVBoxLayout(self,6,6,"plotControlLayout")
        
        
        # Tab widget containing the control to all plot renderes
        # tab widgets
        self.mainSetupWidget = QTabWidget(self, "mainSetupWidget")
        
        self.plotControlLayout.addWidget(self.mainSetupWidget)

        self.addSetupTab()
#        self.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
#        self.resize(QSize(640,480).expandedTo(self.minimumSizeHint()))
        # self.show()
        #self.loadNodeDiagram() #do this in gui instead


    def addSetupTab(self):
        """Adds a control tab at the beginning"""

        # ctrl = QWidget(self.mainSetupWidget)
        ctrl = PlotWindowSetupWidget.PlotWindowSetupWidget(self, None, self.node)
        self.plotSetup = ctrl
        ctrl.hide()
#        self.mainSetupWidget.addTab(ctrl, "Plot Setup")
        # ctrl.slotAddRenderWindows()

    def toggleBuffering(self, bool):
        """Kludge"""
        pass

    def changeBufferSize(self, newSize):
        """Kludge"""
        pass

    def showErrorMessage(self, message):

        retval = QMessageBox.warning(self,
                                     "SciCraft",
                                     str(message),
                                     QMessageBox.Ok,
                                     QMessageBox.NoButton)

    def getInputPorts(self):
        return self.plotSetup.guiPorts.keys()

    def setFinished(self, state):
        self.finished = state

    def isFinished(self):
        return self.finished
    
    def updateInputPorts(self, ports):
        self.plotSetup.updateInputPorts(ports)

    def redrawPlots(self):
        self.filterControl.updateData(self.gui.getData())
        self.gui.plot.redrawPlot(self.gui.renderWindow)

    def saveConfig(self):
        # legg til info om porter og nxn oppsett
        config = ""
        config += "<plotconfig>\n"
        setupWidget = self.plotSetup
        config += "<rows>" + str(setupWidget.rows) + "</rows>\n"
        config += "<cols>" + str(setupWidget.cols) + "</cols>\n"
        ports = setupWidget.guiPorts
        for portname in ports:
            config += "<port>\n"
            config += "\t<name>" + str(portname) + "</name>\n"
            config += "\t<type>" + str((ports[portname])[1]) + "</type>\n"
            config += "\t<desc>" + str((ports[portname])[2]) + "</desc>\n"
            config += "</port>\n"
        for render in self.getRenderWindows():
            setupWidget = render.getSetupWidget()
            config += setupWidget.getConfig()
        config += "</plotconfig>\n"

        #get the full path of the scicraft .rc file
        custompath = os.path.join(Config.userconfigdir, "Plots")
        if not os.path.isdir(custompath) :
            os.mkdir(custompath, 0755)
        custompath += os.sep + "Custom"
        if not os.path.isdir(custompath) :
            os.mkdir(custompath, 0755)

        filename = QFileDialog.getSaveFileName(custompath,
                                               "SciCraft plot files (*.zpl)",
                                               self,
                                               "save file dialog",
                                               "Choose a file").latin1()
        
        if filename:
            if filename.rfind(".zpl") < 0:
                filename += ".zpl"
            file = open(filename, 'w+')
            file.write(config)
            self.gui.setStatusMessage("Config written to " + filename, self.gui.statusTime)

            # Added by oyvindkn. Try to save a pixmap file also
            # Won't work in most cases, but I don't care.
            try:                
                pixfile = os.path.basename(filename)
                pixfile = os.path.splitext(pixfile)[0] + ".txt"
                f = open(os.path.join("GUI",
                                      "conf",
                                      pixfile),
                         'w')
                f.write("type=" + str(os.path.splitext(pixfile)[0]) + "\n")
                f.write("image=3D_in\n")
                f.write("point1=[0,20]:[-10,20] \n")
                f.close()
            except Exception, e:
                pass
        else:
            self.gui.setStatusMessage("Save operation cancelled", self.gui.statusTime)

    def getAvailableAliases(self):
        return self.filterControl.getAliasData()

    def getRenderWindows(self):

        renList = []

        for index in range(0, self.mainSetupWidget.count()):
            
            renList.append(self.mainSetupWidget.page(index).renderWindow)

        return renList

    def resizeController(self, glob = False):

        if glob:
            # print "glob glob glob..."
            
            self.resize(QSize(10, 10).expandedTo(self.minimumSizeHint()))
            # self.gui.setMinimumSize(self.gui.
            self.gui.resize(QSize(10, 10).expandedTo(self.gui.minimumSizeHint()))
        else:
            self.resize(QSize(10, 10).expandedTo(self.minimumSizeHint()))
            


        


        

    def __tr(self,s,c = None):
        return qApp.translate("plotControl",s,c)

    def saveNodeDiagram(self):
        config = ""
        config += "<plotconfig>\n"
        setupWidget = self.plotSetup
        config += "<rows>" + str(setupWidget.rows) + "</rows>\n"
        config += "<cols>" + str(setupWidget.cols) + "</cols>\n"
        # ports aren't needed when we save the whole module diagram
        renderWindows = self.getRenderWindows()
        for render in renderWindows:
            setupWidget = render.getSetupWidget()
            config += setupWidget.getConfig()
        config += "</plotconfig>\n"

        # make sure xml is valid
        try:
            dom = minidom.parseString(config)
            self.node.setCustomXML(config)
        except Exception, e:
            print "Failed setting custom XML:", e


    def setRenderTab(self, renderTab):
        self.mainSetupWidget.insertTab(renderTab, self.tr("Editor Controls"))
        self.mainSetupWidget.showPage(renderTab)

        

        
