# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from GUI.guinode import GUINode
from System.Data.Data import Data
from qt import QMessageBox

class MoleculeEditorNode(GUINode):

    def __init__(self, parent, node):
        GUINode.__init__(self, parent, node)
        self.plotData = {}
        self.plotWindow = None
        

    def updatePlotData(self):
        ports = self.getDiagramNode().getInputPorts()
        data = self.getDiagramNode().getMoleculeModels()
                
        for port in ports:
            # currently abit stupid as all ports (should be only
            # one though) is stuffed with data fram the underlying
            # processing Node.
            self.plotData[port.getName()] = Data("molecule",data)


    def _showPlot(self):
        self.updatePlotData()

        if self.plotData:
            # Plot Window depends on data being stored with keys (nodeId, plotName)
            data = {}
            for portname in self.plotData:                
                data[(self.getDiagramNode().getId(), portname)] = self.plotData[portname]
            if not self.plotWindow:
                from GUI.Editors.MoleculeEditorWindow import MoleculeEditorWindow
                self.plotWindow = MoleculeEditorWindow(self.node)
            self.plotWindow.setData(data)
            self.plotWindow.controller.setFinished(1)
            self.plotWindow.show()
            self.plotWindow.controller.redrawPlots()

        else:
            self.plotWindow = self.openPlotWindow(None)
            self.plotWindow.controller.setFinished(0)
            self.plotWindow.show()


    def nodeDialog(self):
        try:
            import vtk
            self._showPlot()
        except ImportError:
            QMessageBox.warning(None, "Missing module VTK",
                                "You need VTK with python bindings installed to use 3D molecule editing.")

    def saveGuiSettings(self):
        if self.plotWindow:
            self.plotWindow.saveNodeDiagram()

