# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

import os

from qt import QListViewItem, QObject, SIGNAL
from qtui import QWidgetFactory

from GUI.guinode import GUINode
from Library.Util.Config import Config
from System.FileHandlers.Input.FileReader import data_info
from System.Data.Data import RData


class GUIDissectionNode(GUINode):

    def __init__(self, parent, node):
        GUINode.__init__(self, parent, node)
        self._widget = QWidgetFactory.create(os.path.join(Config.uidir, 'dissectnode.ui'),
                                             None, parent)
        self._input_view = self._widget.child('input_view')
        self._node = node

        QObject.connect(self._widget.child('add_button'), SIGNAL('clicked()'),
                        self._slot_add_to_output_clicked)
        QObject.connect(self._input_view,
                        SIGNAL('doubleClicked(QListViewItem *, const QPoint &, int)'),
                        self._slot_add_to_output_clicked)
        QObject.connect(self._widget.child('clear_button'), SIGNAL('clicked()'),
                        self._slot_clear_outputs)
        QObject.connect(self._widget.child('remove_button'), SIGNAL('clicked()'),
                        self._slot_remove_button_clicked)

        

    def nodeDialog(self):
        self._update_input_view()
        self._update_output_view()
        self._widget.show()

    def _update_input_view(self):
        self._input_view.clear()
        for data in self._node.get_all_struct_data():
            if isinstance(data, RData):
                struct = data.get_data_with_dimnames()
            else:
                struct = data.getData()
            self._add_struct(struct, name = data.getName())
        
    def _add_struct(self, struct, root = None, name = None):
        """Receives a dict object adds this to the input list view.

        struct - the dict object.
        root - the root QListViewItem that will be used as parent.
        name - the text that will be used for this QListViewItem.
        """
        if not root:
            root = QListViewItem(self._widget.child('input_view'), name)
             
        for key in struct.keys():
            item = QListViewItem(root, key,
                                     data_info(struct[key]))
            if isinstance(struct[key], dict):
                self._add_struct(struct[key], item)
            
    def _slot_add_to_output_clicked(self):
        sub_elements = []
        item = self._input_view.currentItem()
        if not item:
            return
        
        if not item.parent():
            self._node.set_output(str(item.text(0)), [])
        else:
            parent = item.parent()
            while item.parent():
                sub_elements.append(str(item.text(0)))
                item = item.parent()
            sub_elements.reverse()
            self._node.set_output(str(item.text(0)), sub_elements)

        self._update_output_view()


    def _update_output_view(self):

        output_view = self._widget.child('output_view')
        output_view.clear()
        ports = self._node.getOutputPorts()
        for port in ports:
            QListViewItem(output_view, port.getName())
    
    def _slot_clear_outputs(self):
        self._node.clear_output()
        self._update_output_view()

    def _slot_remove_button_clicked(self):
        item = self._widget.child('output_view').currentItem()
        if not item:
            return 
        item_text = str(item.text(0))
        self._node.remove_output(item_text)
        self._update_output_view()
        
        
        
        
                
