# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from GUI.guinode import GUINode
from qt import QMessageBox

class GUIPlot3DNode(GUINode):

    def __init__(self, parent, node, eventServer):
        GUINode.__init__(self, parent, node)
        self.plotWindow = None
        self.plotData = {}
        self.eventServer = eventServer

    def updatePlotData(self):
        for inputPort in self.getDiagramNode().getInputPorts():
            data = inputPort.getData()
            if data:
                self.plotData[inputPort.getName()] = data

    def _showPlot(self):

        # Get data from middleware
        self.updatePlotData()

        if self.plotData:

            type = self.getDiagramNode().getPlotType()
            
            # Plot Window depends on data being stored with keys (nodeId, plotName)
            data = {}
            for portname in self.plotData:
                data[(self.getDiagramNode().getId(), portname)] = self.plotData[portname]

            plotWindow = self.openPlotWindow(data)
            plotWindow.controller.setFinished(1)
            plotWindow.show()
            plotWindow.controller.apply_all_plot_settings()

            # Check whether the MD has just run, or we are reopening
            # a plot with up to date data.
            if not plotWindow.isDataUpdated():                
                plotWindow.controller.redrawPlots()
                plotWindow.setDataUpdated(True)

        else:
            type = self.getDiagramNode().getPlotType()
            plotWindow = self.openPlotWindow(None)
            plotWindow.controller.setFinished(0)
            plotWindow.show()


    def nodeDialog(self):
        try:
            import vtk
            self._showPlot()
        except ImportError:
            QMessageBox.warning(None, "Missing module VTK",
                                "You need VTK with python bindings installed to use 3D plotting.")

    def saveGuiSettings(self):
        GUINode.saveGuiSettings(self)
        if self.plotWindow:
            self.plotWindow.saveNodeDiagram()


    def openPlotWindow(self, data):
        """
        Params:
               - data : List - This parameter is on the away out.
        Opens a plot window specified by its id. If the window has not been opened before,
        a new plot window will be created and opened."""

        #print "opening plot window..."
        if self.plotWindow:
            if not self.plotWindow.isDataUpdated():
                self.plotWindow.setData(data)
                # self.plotWindow.setDataUpdated(True)
            return self.plotWindow
        else:
            # imported here to make vtk optional
            from GUI.Plots import PlotWindow
            type = self.getDiagramNode().getPlotType()
            plotWindow = PlotWindow.PlotWindow(data, self.eventServer, self.getDiagramNode(), type)
            self.plotWindow = plotWindow
            # plotWindow.show()
            return plotWindow
