# -*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

# Very nasty Torbjrn stuff
from qt import QObject
from qt import PYSIGNAL


class DataFilterController(QObject):

    def __init__(self, controller):
        QObject.__init__(self)
        self.controller = controller
        self.filters = []
        self.data = {}
        self.aliasData = {}
        
        self.bufferIndex = 0
        self.bufferSize = 0

    def registerFilter(self, filter):

        self.filters.append(filter)
        filter.setFilterControl(self)

    def unregisterFilter(self, filter):

        self.filters.remove(filter)
        filter.removeFilterControl()

    def updateData(self, data):
        """
        Params:
               - data : dict - A dictionary with port ids as keys, and data objects as fields.
               The form of the dictionary is as following: {(nodeId, portName) : Data}

        Updates the data variables available to the plots in this plot window. It will unwrap the
        data objects given as argument, and store the data in a dictionary for easy access.
        """

        for elem in data:
            # Explicit making of list of the data as it probably will come as a Numeric array
            # from the middleware
            nodeid, portname = elem

            try:
                dataElem = data[elem].getData().tolist()
            except AttributeError, e:
                dataElem = data[elem].getData()

            if self.isAliasData(portname, dataElem):
                self.aliasData[portname] = dataElem
            else:                
                self.data[portname] = dataElem
            
        for filter in self.filters:
            filter.setData(self.data)

            ### Hack alarm, this must be removed.
            # filter.setRange(filter.computeFullRange())

    def isAliasData(self, name, data):

        if name == "aliases" or name == "alias" or name == "Aliases" or name == "Alias":

            if type(data) == list and type(data[0]) == str:
                return 1

        return 0

    def getAliasData(self):
        retlist = []
        for key in self.aliasData:
            retlist += self.aliasData[key]

        return retlist
        
        
    def registerPick(self, index, dataFilter):
        involvedData = []
        # Here we must translate the phony index to the real index! We do that in the
        # filters themselves.

        realIndex = dataFilter.getRealIndex(index)

        realRange = dataFilter.computeFullRange()
        
        # for filter in dataFilter.filters:
        #    involvedData.append({filter.variableName : [filter.direction, filter.elements, index]})
        for filter in self.filters:
            filter.pickedEvent(realIndex, realRange)

    def unRegisterPick(self, index, dataFilter):
        involvedData = []
        # Here we must translate the phony index to the real index! We do that in the
        # filters themselves.

        realIndex = dataFilter.getRealIndex(index)

        realRange = dataFilter.computeFullRange()
        
        # for filter in dataFilter.filters:
        #    involvedData.append({filter.variableName : [filter.direction, filter.elements, index]})
        for filter in self.filters:
            filter.unPickedEvent(realIndex, realRange)


    def getIndex(self):
        return self.bufferIndex
    
    def increaseBufferIndex(self):
        self.setBufferIndex(1)
        
    def decreaseBufferIndex(self):
        self.setBufferIndex(-1)
        
    def setBufferIndex(self,modifier):
        if modifier == 1 or modifier == -1:
            
            self.bufferIndex += modifier
            
            # the obviuos doesnt work, bug?
            #self.controller.gui.animationSlider.sliderStart()
            
            # the not so nice, but working solution
            slider = self.controller.gui.animSlider
            slider.setValue( slider.minValue() )

        if self.bufferIndex < 0:
            self.bufferIndex = 0
        
        if self.bufferIndex > self.bufferSize-1:
            self.bufferIndex = self.bufferSize-1
            
        self.emit(PYSIGNAL("indexChanged"),())
        
               
    def setBufferSize(self,newSize):
        self.bufferSize = newSize
        
        if self.bufferIndex-1 > newSize:
            self.bufferIndex = newSize-1
            
            
            
    def getBufferSize(self):
        return self.bufferSize 
    
    def getBufferIndex(self):
        return self.bufferIndex
   
   
