# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.


from Library.Util.Config import Config
import os, sys, types, re

class PlotConfig:
    """Class containing variables related to configuration options
    of various plots. The variables are stored here instead of locally to
    be able to store them permanentely in a clean fashion, using only one
    config file."""
            
    lastsavedir = Config.homedir
    plotPictureSaveFilter = "Portable Network Graphics (*.png)"
    __initialized = 0

    bgR = 0
    bgG = 0
    bgB = 0

    interaction3DMode = "Trackball Camera"

    eyeAngle = 2.0
    stereo_mode = 1

def writeConfig():
    """Writes all the variables in the PlotConfig class to a file
    for permanent storage."""

    rcfile = os.path.join(Config.userconfigdir, "plotsrc")
    
    try:
        # test directory
        dirTest = os.path.exists(Config.userconfigdir)
        
        if dirTest == 0:
            os.mkdir(Config.userconfigdir)
                       
        configFile =  open(rcfile, "w")

        for key in dir(PlotConfig):
            # Check that key is not a reserved variable name
            # or a private variable (i.e on the form
            # _PlotConfig__variableName)
            if key[:2] != '__' and key[:2] != '_P':
                value = getattr(PlotConfig, key)

                
                if value == None or value == "None":
                    line = str(key) + "=" + "\n"
                else:
                    line = str(key) + "=" + str(value) + "\n"

                configFile.write(line)

        configFile.flush()
    except IOError, e:
        
            print "Error writing plot config file. Error:", e

def readConfig():
    """Reads a config file and stores its values in the variables in
    the PlotConfig class """

    rcfile = os.path.join(Config.userconfigdir, "plotsrc")
    
    try:
        
        configFile = open(rcfile)

        for line in configFile.readlines():

            # filter out whitespace lines and comment lines
            if ((re.compile("^\#").match(line)) or not (re.compile("\S").match(line))):
                continue
            
            item, value = tuple(line.split("=")) 

            value = value[:-1]

            if value == "None" + "\n":
                value = None
            elif type:
                try:
                    value = int(value)
                except ValueError:
                    pass

            setattr(PlotConfig, item, value)
        # writeConfig()
    except IOError, e:
        writeConfig()

# Try to read the variables in the start
# The testing here is utter bollocks. This
# will be run only once regardless of the number of
# classes importing this module. Let
# this code stand as a lesson on the
# consequenses of not reading the python
# documentaton

if not PlotConfig._PlotConfig__initialized:
    readConfig()
    PlotConfig._PlotConfig__initialized = 1

