# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qt import QLabel, QLineEdit, QMessageBox, QSizePolicy, QWidget, Qt

class PlotSetup(QWidget):

    def __init__(self, renderSetup = None, name = None, fl = 0):
        """
        Params:
               - renderSetup : RenderSetupWidget - The setup widgets that controls the
               renderer that this plot is connected to.
               - parent : QWidget - The parent widget of this widget.
               - name : String - Qt specific thing. Just leave it alone.
               - fl : int - Also Qt specific, leave it!

        Constructs a setupWidget for a given plot. This setup widget controls what kind of
        data should be in the plot plus numerous other properties.
        """
        self.renderSetup = renderSetup
        
        QWidget.__init__(self, renderSetup.plotSetupView.viewport(), name, fl)

        self.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)

        # These are useful for a lot of plots, therefore they are placed here
        # so other classes know they exist. Usually you want to "show()" them
        # in the plot's own plot setup. 
        self.typeLabel = QLabel(self, "typeLabel")
        self.name = QLineEdit(self, "name")
        self.typeLabel.hide()
        self.name.hide()
        
    def setPlot(self, plot):
        """
        asdjksodfk "oaskf"
        adpklsdflk"""
        
        self.plot = plot
        self.typeLabel.setText(plot.plotType + " setup")
        self.name.setText(plot.plotType)

    def parseRange(self, rangeString):
        """
        Params:
               - rangeString : String - a user defined string making the range og the data to be plotted.
               The form of the string should for example be '1,2,5-10'.
        Return:
               - List - A list of the elements to be included. For instance, a range '1,2,5-10' will return
               a list [0,1,4,5,6,7,8,9]. As you can se the range is shifted to comfort python and the developers.
        Generates a list with numbers, denoting the range of data that should be included in a plot."""

        resultList = []
        # Split on commas, now we have [1,2,3-5,10-15]
        splitList = rangeString.split(",")

        try:
            for subrange in splitList:
                # Split on dashes, now we have [1,2,[3,5],[10-15]]
                elements = subrange.split("-")
                
                if len(elements) == 1:
                    
                    resultList.append(int(elements[0]) - 1)
                    
                elif len(elements) == 2:
                    for singleElem in range(int(elements[0]) - 1, int(elements[1])):
                        resultList.append(singleElem)
                else:
                    raise TypeError, "Parsing went bad"

            return resultList
                
        except TypeError, e:
            retVal = QMessageBox.warning(self,
                                         "SciCraft",
                                         "The format of the range string is incorrect!\n" +
                                         "The string will be disregarded and the full range will be used.\n" +
                                         "The format should be something like this: \"1,2,5-10,20-22,25,26\"",
                                         QMessageBox.Ok)
            resultList = ["*"]
            return resultList
        
    
    def slotApply(self):
        """Applies changes made to the setup of the plot"""
        if not self.plot.renderWindow:
            self.plot.renderWindow = self.renderSetup.renderWindow
            
        if self.plot.renderWindow.windowControl.isFinished():
            # This can be regarded as a crude way of accessing vital data, I know... 
            self.renderSetup.windowController.filterControl.updateData(self.renderSetup.windowController.gui.getData())

            try:
                self.plot.redrawPlot(self.plot.renderWindow)
            except IndexError, e:

                self.renderSetup.windowController.showErrorMessage(e)
    
    def updateInputPorts(self, ports):

        pass
