# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qt import QDialog, QHBoxLayout, QIconView, QIconViewItem, QPixmap, SIGNAL
import os.path
from Library.Util.Config import Config

class FragmentDialog(QDialog):
    def __init__(self, path, callback, parent = None, name = "", modal = True):
        """Create a dialogbox displaying fragments."""
        QDialog.__init__(self, parent, name, modal)

        self.resize(320,240)
        
        h = QHBoxLayout(self)
        h.setMargin(10)
        h.setSpacing(10)

        self.icons = QIconView(self)
        self.icons.setSorting(True)
        self.icons.setAutoArrange(True)
        self.icons.setItemsMovable(False)

        h.addWidget(self.icons)

        self.connect(self.icons, SIGNAL("doubleClicked(QIconViewItem*)"), callback)

        os.path.walk(path, self.walker, self.icons)

        self.icons.arrangeItemsInGrid(True)

    def count(self):
        return self.icons.count()

    def walker(self, iconview, dir, fnames):
        for f in fnames:
            pngpath = os.path.join(dir, f[:-3] + "png")
            if f.endswith(".pkl"):
                if os.path.exists(pngpath):
                    item = QIconViewItem(iconview, f[:-4], QPixmap(pngpath))
                else:
                    item = QIconViewItem(iconview, f[:-4], QPixmap(os.path.join(Config.pixmapdir, "Unknown.png")))

                item.fragmentPath = os.path.join(dir, f)
                # evil hack
                item.dialog = self
