# -*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qt import QCheckBox, QComboBox, QGridLayout, QLabel, QLineEdit, QPushButton
from qt import QSize, QSizePolicy, SIGNAL, qApp
from GUI.Plots import PlotSetup

#hack for redhat-installed pymol
import sys
import os.path
for path in sys.path:
    combopath = os.path.join(path, 'pymol/modules')
    if os.path.exists(combopath):
        if sys.path.count(combopath) == 0:
            sys.path.append(combopath)

class MolPlot3DSetup(PlotSetup.PlotSetup):

    BNSTEXT = "Ball'n'Stick"
    SFTEXT = "Space Filling"
    LTEXT = "Line"
    
    def __init__(self, parent, name = None,fl = 0):
        """See GUI/Plots/PlotSetup """
        PlotSetup.PlotSetup.__init__(self, parent, name, fl)

        self.gui = parent.windowController.gui
        self.controller = parent.windowController

        if not name:
            self.setName("MolPlot3DSetup")
        
        MolPlot3DSetupLayout = QGridLayout(self,1,1,11,6,"MolPlot3DSetupLayout")


        self.name = QLineEdit(self,"name")

        MolPlot3DSetupLayout.addWidget(self.name,1,1)

        self.nameLabel = QLabel(self,"nameLabel")
        self.nameLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.nameLabel.sizePolicy().hasHeightForWidth()))
        MolPlot3DSetupLayout.addWidget(self.nameLabel,1,0)


        # Source of data
        self.source = QComboBox(0,self,"Source")
        self.source.setSizePolicy(QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Fixed,0,0,self.source.sizePolicy().hasHeightForWidth()))        
        MolPlot3DSetupLayout.addWidget(self.source,2,1)

        self.sourceLabel = QLabel(self,"sourceLabel")
        self.sourceLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.sourceLabel.sizePolicy().hasHeightForWidth()))
        self.sourceLabel.setText(self.__tr("Data source:"))
        MolPlot3DSetupLayout.addWidget(self.sourceLabel,2,0)

        # Show index for each atom
        self.showIndexLabel = QLabel(self,"showIndexLabel")
        self.showIndexLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.showIndexLabel.sizePolicy().hasHeightForWidth()))
        self.showIndexLabel.setText(self.__tr("Show indices:"))
        MolPlot3DSetupLayout.addWidget(self.showIndexLabel,5,0)

        self.showIndexBox = QCheckBox(self, "showIndexBox")
        MolPlot3DSetupLayout.addWidget(self.showIndexBox,5,1)
        self.connect(self.showIndexBox, SIGNAL("toggled(bool)"), self.slotIndexBoxToggled)

        # Show names of atoms
        self.showNameLabel = QLabel(self,"showNameLabel")
        self.showNameLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.showNameLabel.sizePolicy().hasHeightForWidth()))
        self.showNameLabel.setText(self.__tr("Show symbol/name:"))
        MolPlot3DSetupLayout.addWidget(self.showNameLabel,4,0)

        self.showNameBox = QCheckBox(self, "showNameBox")
        MolPlot3DSetupLayout.addWidget(self.showNameBox,4,1)
        self.connect(self.showNameBox, SIGNAL("toggled(bool)"), self.slotNameBoxToggled)
        
        # Plot type
        self.plotTypeLabel = QLabel(self,"plotTypeLabel")
        self.plotTypeLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.plotTypeLabel.sizePolicy().hasHeightForWidth()))
        self.plotTypeLabel.setText(self.__tr("Plot Type:"))
        MolPlot3DSetupLayout.addWidget(self.plotTypeLabel,3,0)

        self.plotType = QComboBox(0,self,"plotType")
        self.plotType.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.plotType.sizePolicy().hasHeightForWidth()))
        MolPlot3DSetupLayout.addWidget(self.plotType,3,1)

        self.plotType.insertItem(self.BNSTEXT) # make sure ball'n'stick is default by inserting it first
        self.plotType.insertItem(self.SFTEXT)
        self.plotType.insertItem(self.LTEXT)
        self.connect(self.plotType, SIGNAL("activated(int)"), self.slotChangePlotType)

        self.applyButton = self.createButton("applyButton", "Apply setup", self.slotApply)
        self.invertButton = self.createButton("invertButton", "Invert selection", self.slotInvert)
        self.extendButton = self.createButton("extendButton", "Extend to model", self.slotExtendSelectionToModel)
        self.extendAlongButton = self.createButton("extendAlongButton", "Extend along bonds", self.slotExtendSelectionAlongBonds)
        self.hideButton = self.createButton("hideButton", "Hide selection", self.slotHide)
        self.angleButton = self.createButton("angleButton", "Angle selection", self.slotAngle)
        self.unhideButton = self.createButton("unhideButton", "Unhide all", self.slotUnhideAll)
        self.selectBoxButton = self.createButton("SelectByBox", "SelectBox selection", self.slotSelectBox)
        self.selectAllButton = self.createButton("selectAllButton", "Select all", self.slotSelectAll)


        self.typeLabel = QLabel(self,"typeLabel")
        self.typeLabel.setSizePolicy(QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed,0,0,self.typeLabel.sizePolicy().hasHeightForWidth()))

        self.setCaption(self.__tr("Plot Config"))

        self.nameLabel.setText(self.__tr("Plot name:"))
        #self.typeLabel.setText(self.__tr("MolPlot3D setup:"))
        self.resize(QSize(333,195).expandedTo(self.minimumSizeHint()))

        MolPlot3DSetupLayout.addWidget(self.applyButton,6,3)
        MolPlot3DSetupLayout.addWidget(self.invertButton,1,3)
        MolPlot3DSetupLayout.addWidget(self.extendButton,5,4)
        MolPlot3DSetupLayout.addWidget(self.extendAlongButton,6,4)
        MolPlot3DSetupLayout.addWidget(self.hideButton,1,4)
        MolPlot3DSetupLayout.addWidget(self.angleButton,4,4)
        MolPlot3DSetupLayout.addWidget(self.unhideButton,2,4)
        MolPlot3DSetupLayout.addWidget(self.selectBoxButton,5,3)
        MolPlot3DSetupLayout.addWidget(self.selectAllButton,2,3)
        MolPlot3DSetupLayout.addMultiCellWidget(self.typeLabel,0,0,0,1)

    def createButton(self, name, text, callback):
        button = QPushButton(self,name)
        button.setText(self.__tr(text))
        self.connect(button, SIGNAL("clicked()"), callback)
        return button

    def updateInputPorts(self, ports):
        source_text = str(self.source.currentText())
        self.source.clear()
        for port in ports:
            self.source.insertItem(port)

        for item_index in range(self.source.count()):
            if source_text == str(self.source.text(item_index)):
                self.source.setCurrentItem(item_index)

    def slotApply(self):
        config = self.getConfig()
        
        filter = self.plot.getDataFilter()
        filter.clearFilters()
        filter.addFilter(config['source'])
        PlotSetup.PlotSetup.slotApply(self)

        
    def updateDataFields(self):
        pass
        
    def __tr(self,s,c = None):
        return qApp.translate("MolPlot3DSetup",s,c)

    
    def getConfig(self):
        config = {}
        config['name'] = str(self.name.text())
        config['source'] = str(self.source.currentText())
        config['plotType'] = str(self.plotType.currentText())
        config['showIndex'] = str(self.showIndexBox.isChecked())
        config['showName'] = str(self.showNameBox.isChecked())
        return config

    def setConfig(self, config):

        self.name.setText(config["name"])

        for i in range(self.source.count()):
            self.source.setCurrentItem(i)
            if str(self.source.currentText()) == config["source"]:
                break

        try:
            for i in range(self.plotType.count()):
                self.plotType.setCurrentItem(i)
                self.slotChangePlotType(i)
                if str(self.plotType.currentText()) == config["plotType"]:
                    break
        except KeyError:
            pass

        try:
            if config['showIndex'] == "True":
                if not self.showIndexBox.isChecked():
                    self.showIndexBox.toggle()
            else:
                if self.showIndexBox.isChecked():
                    self.showIndexBox.toggle()
        except KeyError:
            pass
        
        try:
            if config['showName'] == "True":
                if not self.showNameBox.isChecked():
                    self.showNameBox.toggle()
            else:
                if self.showNameBox.isChecked():
                    self.showNameBox.toggle()
        except KeyError:
            pass

    def slotSelectAll(self):
        self.plot.selectAll()

    def slotSelectBox(self):
        self.plot.startSelection()
        
    def slotHide(self):
        self.plot.hidePicked()

    def slotUnhideAll(self):
        self.plot.unhideAll()

    def slotInvert(self):
        self.plot.invertPicked()

    def slotExtendSelectionToModel(self):
        self.plot.extendSelectionToModel()

    def slotExtendSelectionAlongBonds(self):
        self.plot.extendSelectionAlongBonds()
         
        
    def handleEvent(self,code,data):
        if code == "MDSTOPPED":
            print "self.plot:",self.plot
            if self.plot and self.plot.renderer and self.plot.renderWindow:
                self.plot.redrawPlot()
                

    def slotAngle(self):
        self.plot.printPlaneAngleForSelectedFour()

    def slotChangePlotType(self, int):
        if self.plotType.currentText() == self.BNSTEXT:
            self.plot.setBallNStickPlot()
        elif self.plotType.currentText() == self.SFTEXT:
            self.plot.setSpaceFillingPlot()
        elif self.plotType.currentText() == self.LTEXT:
            self.plot.setLinePlot()

    def slotNameBoxToggled(self,on):
        self.plot.showName = self.showNameBox.isChecked()
        if self.plot.renderer and self.plot.renderWindow:
            self.plot.updateAnnotation()
            self.plot.renderWindow.update()
            self.plot.renderer.Render()

    def slotIndexBoxToggled(self,on):
        self.plot.showIndex = self.showIndexBox.isChecked()
        if self.plot.renderer and self.plot.renderWindow:
            self.plot.updateAnnotation()
            self.plot.renderWindow.update()
            self.plot.renderer.Render()

