# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.


from vtk import vtkActor, vtkActor2D, vtkConeSource, vtkCoordinate
from vtk import vtkCubeAxesActor2D, vtkCubeSource, vtkFollower
from vtk import vtkImageEllipsoidSource, vtkImageMapper, vtkLineSource
from vtk import vtkPolyDataMapper, vtkSphereSource, vtkTextMapper, vtkTubeFilter
from vtk import vtkVectorText
from qt import QAction, QIconSet, QKeySequence, QObject, QPixmap, QPopupMenu
from qt import QWidget, SIGNAL
from GUI.Plots.Plots3D import Plot3D
from GUI.Pixmaps.Icons import Icons
from GUI.Plots.Plots3D.ScatterPlot3D import ScatterPlot3DSetup
class ScatterPlot3D(Plot3D.Plot3D):
    """Draws a 3D scatter plot with axes and spheres as objects."""
    def __init__(self):

        Plot3D.Plot3D.__init__(self)

        self.actorList["label"] = []
        
        # self.plotType="Scatter Plot 3D"
        self.plotType = "3D-Scatter"
        self.isPickable = 1
        # self.setActorShape()
        self.shapeName = "Sphere"
        self.setupWidget = None
        self.textColor = [0,0,0]

        # Lable modes
        self.NO_LABELS = 0        
        self.ALL_LABELS = 1
        self.PICKED_LABELS = 2
        self.labelMode = self.NO_LABELS

    def setLabelMode(self, mode):
        self.labelMode = mode
        

    def setActorShape(self, shape = "Sphere"):

        if shape == "Sphere":
            self.shapeName = "Sphere"
            self.actorShape = vtkSphereSource()
            self.actorShape.SetThetaResolution(8)
            self.actorShape.SetPhiResolution(8)
            # Testing
            # self.actorShape.SetEndTheta(180.0)
            self.actorShape.SetRadius(0.2)

        elif shape == "Cube":
            self.shapeName = "Cube"
            self.actorShape = vtkCubeSource()
            self.actorShape.SetXLength(0.5)
            self.actorShape.SetYLength(0.5)
            self.actorShape.SetZLength(0.5)

        elif shape == "Ellipse":
            self.shapeName = "Ellipse"
            self.actorShape = vtkImageEllipsoidSource()
            self.actorShape.SetRadius(0.2, 0.2, 0.2)
            
    def getActorShape(self):

        if self.shapeName == "Sphere":
            actorShape = vtkSphereSource()
            actorShape.SetThetaResolution(8)
            actorShape.SetPhiResolution(8)
            # Testing
            # self.actorShape.SetEndTheta(180.0)
            actorShape.SetRadius(0.2)

            return actorShape

        elif self.shapeName == "Cube":
            actorShape = vtkCubeSource()
            actorShape.SetXLength(0.5)
            actorShape.SetYLength(0.5)
            actorShape.SetZLength(0.5)
            return actorShape

        elif self.shapeName == "Ellipse":
            print "ScatterPlot3D: Ellipses are not supported"
            self.shapeName == "Sphere"
            return getActorShape()

    def createSelf(self, renderWindow = None):
        
        Plot3D.Plot3D.createSelf(self, renderWindow)
        # self.renderer.SetBackground(0.8, 0.8, 0.8)
        # self.addAxes()
        self.textColor = self.getPreferredTextColor()

        self.pickedActorText = pat = vtkTextMapper()
        textProperty = pat.GetTextProperty()
        textProperty.SetFontFamilyToArial()
        textProperty.SetFontSize(12)
        textProperty.SetBold(0)

        self.pickedActorTextActor = pata = vtkActor2D()
        pata.SetVisibility(0)
        pata.SetMapper(pat)
        self.renderer.AddActor2D(pata)

    def getOptions(self, parent = None):

        if self.options:
            return self.options

        return ScatterPlot3DOptions.ScatterPlot3DOptions(parent,
                                                         "Scatter Plot 3D Options",
                                                         self)

    def testSlot(self, number):

        print "Menu item " + str(number) + " clicked"
    
    def createBarItems(self):

        Plot3D.Plot3D.createBarItems(self)
        
        # First the items that go into the menu _and_
        # the toolbar
        
        mainmenu = QPopupMenu(self.renderWindow)

        QObject.connect(mainmenu, SIGNAL("activated(int)"), self.testSlot)
        nestmenu = QPopupMenu(self.renderWindow)
        testmenu = QPopupMenu(self.renderWindow)
        prpAc = QAction(self.renderWindow)
        prpAc.setIconSet(QIconSet(QPixmap(Icons.plotOptionsPic)))
        prpAc.setText("Options ...")
        prpAc.setMenuText("&Options ...")
        prpAc.setOn(0)
        prpAc.setToolTip("Options for 3D Scatter Plot")
        prpAc.setAccel(QKeySequence("CTRL+O"))
        
        QObject.connect(prpAc, SIGNAL("activated()"), self.dummy)
        
        # Add to the popupmenu and to the toolbarItems list
        prpAc.addTo(mainmenu)
        self.toolbarItems.append(prpAc)

        testAc = QAction(self.renderWindow)
        testAc.setText("Test item ...")
        testAc.setMenuText("&Test item ...")
        testAc.setOn(0)
        testAc.setToolTip("Test item for 3D Scatter Plot")
        testAc.setAccel(QKeySequence("CTRL+T"))
        QObject.connect(testAc, SIGNAL("activated()"), self.dummy)

        testAc.addTo(nestmenu)
        nestmenu.insertItem("Hello World!")
        QObject.connect(nestmenu, SIGNAL("activated(int)"), self.testSlot)
        mainmenu.insertItem("Nested", nestmenu)

        smiAc = QAction(self.renderWindow)
        smiAc.setIconSet(QIconSet(QPixmap(Icons.smileyPic)))
        smiAc.setText("Smile!")
        smiAc.setMenuText("Smile!")
        smiAc.setOn(0)
        smiAc.setToolTip("Smile you bastard!")
        QObject.connect(smiAc, SIGNAL("activated()"), self.dummy)
        self.toolbarItems.append(smiAc)
        smiAc.addTo(testmenu)

        self.menus["3D Scatter Plot"] = mainmenu
        self.menus["Smile Options"] = testmenu

    def addAxes(self, axisTitles = None):

        self._add_centered_axes(axisTitles)

    def _add_cube_axes(self, axisTitles = None):
        try:
            
            data = self.dataFilter.getPlotData()
            
            xmin = 100000000
            xmax = -100000000
            ymin = xmin
            ymax = xmax
            zmin = xmin
            zmax = xmax
            for row in data:

                if row[0] < xmin:
                    xmin = row[0]
                if row[0] > xmax:
                    xmax = row[0]

                if row[1] < ymin:
                    ymin = row[1]
                if row[1] > ymax:
                    ymax = row[1]

                if row[2] < zmin:
                    zmin = row[2]
                if row[2] > zmax:
                    zmax = row[2]
            
            axes = vtkCubeAxesActor2D()
            axes.SetBounds(xmin, xmax, ymin, ymax, zmin, zmax)
            axes.SetCamera(self.renderer.GetActiveCamera())
            axes.SetFlyModeToOuterEdges()
            axes.GetProperty().SetColor(0.0, 0.0, 0.0)
            axes.GetAxisLabelTextProperty().BoldOn()
            axes.GetAxisLabelTextProperty().ShadowOn()
            axes.SetScaling(False)
            axes.SetPickable(False)
            self.renderer.AddActor(axes)
            # print axes
        except Error, e:
            print e
            
        
    def _add_centered_axes(self, axisTitles = None):
        """
        Params:
               - axisTitles : List[String] - A list of the titles that should be used along
               the axes

        Adds a set of axes to the renderer. If no axis titles are specified, X, Y and Z will be used."""

        if not self.renderer:
            return
        
        setupTitles = self.setupWidget.getConfig()
        minmax = self.dataFilter.getMinMax()
        self.scale = max(abs(minmax[1]),abs(minmax[0]))

        # Maybe a better way?
        self.textColor = textColor = self.getPreferredTextColor()
        tubeRadius = 0.01*self.scale
        tubeSides = 8
        
        xAxis = vtkLineSource()
        xAxis.SetPoint1(-self.scale, 0, 0)
        xAxis.SetPoint2(self.scale, 0, 0)

        xTube = vtkTubeFilter()
        xTube.SetInput(xAxis.GetOutput())
        xTube.SetRadius(tubeRadius)
        xTube.SetNumberOfSides(tubeSides)

        xTubeMapper = vtkPolyDataMapper()
        xTubeMapper.SetInput(xTube.GetOutput())

        xAxisActor = vtkActor()
        xAxisActor.GetProperty().SetColor(textColor)
        xAxisActor.SetMapper(xTubeMapper)
        xAxisActor.SetPickable(0)
        self.renderer.AddActor(xAxisActor)
        self.actorList["axis"].append(xAxisActor)

        # Y axis
        yAxis = vtkLineSource()
        yAxis.SetPoint1(0, -self.scale, 0)
        yAxis.SetPoint2(0, self.scale, 0)

        yTube = vtkTubeFilter()
        yTube.SetInput(yAxis.GetOutput())
        yTube.SetRadius(tubeRadius)
        yTube.SetNumberOfSides(tubeSides)

        yTubeMapper = vtkPolyDataMapper()
        yTubeMapper.SetInput(yTube.GetOutput())

        yAxisActor = vtkActor()
        yAxisActor.GetProperty().SetColor(textColor)
        yAxisActor.SetMapper(yTubeMapper)
        yAxisActor.SetPickable(0)
        self.renderer.AddActor(yAxisActor)
        self.actorList["axis"].append(yAxisActor)

        # Z axis
        zAxis = vtkLineSource()
        zAxis.SetPoint1(0, 0, -self.scale)
        zAxis.SetPoint2(0, 0, self.scale)

        zTube = vtkTubeFilter()
        zTube.SetInput(zAxis.GetOutput())
        zTube.SetRadius(tubeRadius)
        zTube.SetNumberOfSides(tubeSides)

        zTubeMapper = vtkPolyDataMapper()
        zTubeMapper.SetInput(zTube.GetOutput())

        zAxisActor = vtkActor()
        zAxisActor.GetProperty().SetColor(textColor)
        zAxisActor.SetMapper(zTubeMapper)
        zAxisActor.SetPickable(0)
        self.renderer.AddActor(zAxisActor)
        self.actorList["axis"].append(zAxisActor)

               
        
        # Cones to mark positive axis
        Xcone = vtkConeSource()
        Xcone.SetRadius(0.04*self.scale)
        Xcone.SetHeight(0.06*self.scale)
        Xcone.SetResolution(15)
        XconeMapper = vtkPolyDataMapper()
        XconeMapper.SetInput(Xcone.GetOutput())
        XconeActor = vtkActor()
        XconeActor.SetMapper(XconeMapper)
        XconeActor.SetPosition(self.scale,0,0)
        XconeActor.GetProperty().SetColor(textColor)
        self.renderer.AddActor(XconeActor)
        self.actorList["axis"].append(XconeActor)

        Ycone = vtkConeSource()
        Ycone.SetRadius(0.04*self.scale)
        Ycone.SetHeight(0.06*self.scale)
        Ycone.SetResolution(15)
        YconeMapper = vtkPolyDataMapper()
        YconeMapper.SetInput(Ycone.GetOutput())
        YconeActor = vtkActor()
        YconeActor.SetMapper(YconeMapper)
        YconeActor.SetPosition(0, self.scale, 0)
        YconeActor.GetProperty().SetColor(textColor)
        YconeActor.RotateZ(90)
        self.renderer.AddActor(YconeActor)
        self.actorList["axis"].append(YconeActor)
        
        Zcone = vtkConeSource()
        Zcone.SetRadius(0.04*self.scale)
        Zcone.SetHeight(0.06*self.scale)
        Zcone.SetResolution(15)
        ZconeMapper = vtkPolyDataMapper()
        ZconeMapper.SetInput(Zcone.GetOutput())
        ZconeActor = vtkActor()
        ZconeActor.SetMapper(ZconeMapper)
        ZconeActor.SetPosition(0, 0, self.scale)
        ZconeActor.GetProperty().SetColor(textColor)
        ZconeActor.RotateY(-90)
        self.renderer.AddActor(ZconeActor)
        self.actorList["axis"].append(ZconeActor)

                
        self.XText = XText = vtkVectorText()
        if axisTitles and len(axisTitles) >= 3:
            Xtext.SetText(axisTitles[0])
        else:

            text = (str(setupTitles["xdata"]) + "_" +
                    str(setupTitles["xdirection"])[0:3] + "_" +
                    str(setupTitles["xnumber"]) + "(" + "%0.3f" % (self.scale) +")")
            XText.SetText(text)
        
        self.XTextMapper = XTextMapper = vtkPolyDataMapper()
        XTextMapper.SetInput(XText.GetOutput())
        self.XActor = XActor =vtkFollower()
        self.XActor.SetPickable(0)
        XActor.SetMapper(XTextMapper)
        a = 0.05*self.scale
        XActor.SetScale(a, a, a)
        XActor.SetPosition(self.scale, -0.1*self.scale, -0.1*self.scale)
        XActor.GetProperty().SetColor(textColor)
        self.renderer.AddActor(XActor)
        self.actorList["axistitle"] = []
        self.actorList["axistitle"].append(XActor)

        self.YText = YText = vtkVectorText()
        if axisTitles and len(axisTitles) >= 3:
            YText.SetText(axisTitles[1])
        else:
            text = (str(setupTitles["ydata"]) + "_" +
                    str(setupTitles["ydirection"])[0:3] + "_" +
                    str(setupTitles["ynumber"]))
            YText.SetText(text)
            
        
        self.YTextMapper = YTextMapper = vtkPolyDataMapper()
        YTextMapper.SetInput(YText.GetOutput())
        YActor = vtkFollower()
        YActor.SetPickable(0)
        YActor.SetMapper(YTextMapper)
        YActor.SetScale(a, a, a)
        YActor.SetPosition(-0.1 * self.scale, self.scale, -0.1 * self.scale)
        YActor.GetProperty().SetColor(textColor)
        self.renderer.AddActor(YActor)
        self.actorList["axistitle"].append(YActor)

        self.ZText = ZText =vtkVectorText()
        if axisTitles and len(axisTitles) >= 3:
            ZText.SetText(axisTitles[2])
        else:
            text = (str(setupTitles["zdata"]) + "_" +
                    str(setupTitles["zdirection"])[0:3] + "_" +
                    str(setupTitles["znumber"]))
            ZText.SetText(text)
            
            
        self.ZTextMapper = ZTextMapper = vtkPolyDataMapper()
        ZTextMapper.SetInput(ZText.GetOutput())
        self.ZActor = ZActor = vtkFollower()
        ZActor.SetPickable(0)
        ZActor.SetMapper(ZTextMapper)
        ZActor.SetScale(a, a, a)
        ZActor.SetPosition(-0.1*self.scale, -0.1*self.scale, self.scale)
        ZActor.GetProperty().SetColor(textColor)
        self.renderer.AddActor(ZActor)
        self.actorList["axistitle"].append(ZActor)
        
        XActor.SetCamera(self.renderer.GetActiveCamera())
        YActor.SetCamera(self.renderer.GetActiveCamera())
        ZActor.SetCamera(self.renderer.GetActiveCamera())
        

    def addData(self, data, confidenceEllipsis = None, safety = None, colourMap = None):
        """
        Params:
               - axis1Source : List - A list with two elements. The first is the name
               of the variable, and the second is the column number of the variable. Sets
               the first axis in the plot
               - axis2Source : List - A list with two elements. The first is the name
               of the variable, and the second is the column number of the variable. Sets
               the second axis in the plot
               - axis3Source : List - A list with two elements. The first is the name
               of the variable, and the second is the column number of the variable. Sets
               the third axis in the plot

        Adds the data to the plot"""

        if not self.renderer:
            return

        minmax = self.dataFilter.getMinMax()
        self.scale = max(abs(minmax[1]),abs(minmax[0]))
        ## Ad-hoc radius. Looks pretty nice, that's all
        radius = self.scale/60.0

        if confidenceEllipsis and len(confidenceEllipsis) != len(data):
            confidenceEllipsis = None

        if safety and len(safety) != len(data):
            safety = None
        # Constructs a totally unnessecary 3D vtkCoordinate
        # and doesn't use it at all when giving the actors
        # their position :)
        
        for rowindex in range(len(data)):
            # coord = vtkCoordinate()
            # coord.SetCoordinateSystemToNormalizedDisplay()
            # coord.SetValue(row)

            #cont = 0

            # print str(len(data[rowindex])) # Big no no
            if len(data[rowindex]) > 3:
                print "3D-Scatter: Wrong dimension of data. Want 3, got " + str(len(data[rowindex]))
                print "Truncating row to fit dimension"
                data[rowindex] = data[rowindex][0:3]

            elif len(data[rowindex]) < 3:
                print "3D-Scatter: Too few dimensions to plot, removing row from input."
                continue
            
            shape = self.getActorShape()

            shape.SetRadius(radius)

            if confidenceEllipsis:
                clist = confidenceEllipsis[rowindex]
                counter = 0
                sum = 0
                for el in clist:
                    sum += el
                    counter += 1
                mean = float(sum)/float(counter)
                
                shape.SetRadius(mean)

                                            
            mapper = vtkPolyDataMapper()

            if self.shapeName == "Ellipse":
                mapper = vtkImageMapper()
            mapper.SetInput(shape.GetOutput())

            actor = vtkActor()
            actor.SetMapper(mapper)
            #                           The name of var  row num    column number
            #actor.SetPosition([self.data[axis1Source[0]][rowindex][axis1Source[1]],
            #                   self.data[axis2Source[0]][rowindex][axis2Source[1]],
            #                   self.data[axis3Source[0]][rowindex][axis3Source[1]])

            actor.SetPosition(data[rowindex])

            actor.GetProperty().SetColor(0,0,1)

            if safety:
                
                actor.GetProperty().SetOpacity(safety[rowindex])



            self.actorList["pos"].append(actor)
            self.renderer.AddActor(actor)

            # Add position actor to list of labels
            textScale = 0.03*self.scale
            labelText = vtkVectorText()
            labelText.SetText(str(rowindex+1))
            labelMapper = vtkPolyDataMapper()
            labelMapper.SetInput(labelText.GetOutput())
            labelActor = vtkFollower()
            labelActor.SetPickable(0)
            labelActor.SetMapper(labelMapper)
            labelActor.SetScale(textScale, textScale, textScale)
            labelActor.SetPosition(0.5*textScale+data[rowindex][0],
                                   0.5*textScale+data[rowindex][1],
                                   0.5*textScale+data[rowindex][2])
            labelActor.GetProperty().SetColor(self.getPreferredTextColor())
            
            labelActor.SetCamera(self.renderer.GetActiveCamera())
            if self.labelMode == self.ALL_LABELS:
                self.renderer.AddActor(labelActor)

            self.actorList["label"].append(labelActor)
            
            # actor.SetPickMethod(self.annotatePick)
            # actor.Pick()

        # cam = self.renderer.GetActiveCamera()
        # cam.SetFocalPoint(0,0,0)
        # cam.SetPosition(1,1,1)
        # self.renderer.SetActiveCamera(cam)
        
        # Reset camera and rotatwe around origo
        self.renderer.ResetCamera()
        self.renderer.GetActiveCamera().SetFocalPoint(0,0,0)
        self.renderWindow.update()


    def endPickEvent(self, object, event):
        """Redefined from Plot. Displayes the
        coordinates of the object that was picked.
        """
        
        pickedActor = self.picker.GetActor()

        if pickedActor:
            pickPoint = self.picker.GetSelectionPoint()
            color = self.textColor
            position = pickedActor.GetPosition()
            
            self.pickedActorText.GetTextProperty().SetColor(color)
            self.pickedActorText.SetInput("(%.4f, %.4f, %.4f)"%position)

            # self.pickedActorTextActor.SetPosition(pickPoint[:2])
            # self.pickedActorTextActor.SetPosition([pickPoint[0] + 5, pickPoint[1]])
            # self.pickedActorTextActor.SetVisibility(1)

            self.renderWindow.plotWindow.setStatusMessage(self.plotType +
                                                      ": Picked actor with " +
                                                      "coordinates " +
                                                      "(%.4f, %.4f, %.4f)"%position,
                                                      0)
        else:
            self.pickedActorTextActor.SetVisibility(0)
            # pass
        

    def pickActor(self, index):
        """Method for registering an actor in the picked list"""
        actor = self.actorList["pos"][index]
        
        actor.GetProperty().SetColor(self.negateColor(actor.GetProperty().GetColor()))

        
            

        self.actorList["picked"].append(actor)

        # Show index labels if the right mode is selectedd
        if self.labelMode == self.PICKED_LABELS:
            labelActor = self.actorList["label"][index]
            self.renderer.AddActor(labelActor)
        
        self.renderWindow.update()
        self.renderWindow.hideBoundingBox()
        

    def unPickActor(self, index):
        actor = self.actorList["pos"][index]

        if actor in self.actorList["picked"]:
                    
            actor.GetProperty().SetColor(self.negateColor(actor.GetProperty().GetColor()))
            self.actorList["picked"].remove(actor)
            # Remove label if the right mode is selected
            if self.labelMode == self.PICKED_LABELS:
                self.renderer.RemoveActor(self.actorList["label"][index])
            
            self.renderWindow.update()
        
    def unPickAllActors(self):
        """
        Unpicks all the actors that have not yet been removed.
        """
        

        # Weird looping but the list wil shrink
        # in unPickActor so we can't just traverse it like we normally
        # could. Therefore we always pick the first element of the list,
        # and hopefully the element will disappear befor the next step
        # in the loop.
        for actorIndex in range(len(self.actorList["picked"])):
            self.annotatePick(self.actorList["picked"][0])

        self.renderWindow.update()

    def selectWithinBox(self, x, y, width, height):

        # Clear all previously picked actors but leave the picked ones
        # as they are.
        self.unPickAllActors()

        for actor in self.actorList["pos"]:

            vc = vtkCoordinate()
            vc.SetCoordinateSystemToWorld()
            vc.SetValue(actor.GetPosition())

            dispValue = vc.GetComputedDisplayValue(self.renderer)

            
            realDispValue = (dispValue[0], self.renderWindow.height() - dispValue[1])

            if realDispValue[0] > x and realDispValue[0] < (x + width) and realDispValue[1] > y and realDispValue[1] < (y + height):
                # Actor is inside box
                # self.actorList["picked"].append(actor)
                # actor.GetProperty().SetColor(self.negateColor(actor.GetProperty().GetColor()))
                self.annotatePick(actor)

        self.renderWindow.update()
        self.renderer.Render()
    
    
    def dummy(self):
        print "You 3D Scatter dummy!"

    def getSetupWidget(self, renderSetup):
        """
        Params:
               - renderSetup : RenderSetupWidget - The render setup widget that controlls all things
               related to the render window the plot belongs to.
               - parent : QWidget - The parent widget of the setup widget. Should not be
               None, otehrwise we will get a lot of unwanted top level windows.

        Returns:
               - ScatterPlot3DSetup - This plot's setup widget.
        Returns the setup widget of this plot. If no exists, one will be created before is is
        returned"""
        
        if not self.setupWidget:
            self.setupWidget = ScatterPlot3DSetup.ScatterPlot3DSetup(renderSetup)
            self.setupWidget.setPlot(self)
        return self.setupWidget

    def deletePickedElements(self):
        """Redefined from Plot.py. Removed eventual labels to picked actors."""

        # We have labels to remove if this is true
        if not self.labelMode == self.NO_LABELS:
            for actor in self.actorList["picked"]:

                # Get the index of the actor.
                index = self.actorList["pos"].index(actor)

                # Remove the label actor with the same index as the
                # object actor
                self.renderer.RemoveActor(self.actorList["label"][index])

        return Plot3D.Plot3D.deletePickedElements(self)

    def undoPicking(self):
        """
        Redefines Plot method. Adds labels back to the plot where appropriate.
        
        """

        # Add labels back into the plot if the right mode is selected.
        if self.labelMode == self.ALL_LABELS:
            for actor in self.actorList["deleted"]:
                index = self.actorList["pos"].index(actor)
                self.renderer.AddActor(self.actorList["label"][index])

        Plot3D.Plot3D.undoPicking(self)
            

    def moveActors(self,newCoords):
        """Moves the actors in the plot
        newCoords is a dict with actor indeces and new coordinates
        
        example, moving actor 5 to new point: { 5 : [1.0, 1.1, 1.2] }"""

        for actor_index in newCoords.keys():
            
            try:
                actor = self.actorList["pos"][actor_index]
            except:
                continue
            
            coord = newCoords[actor_index]

            if coord == 'hide':
                actor.SetVisibility(0)
            else:
                actor.SetVisibility(1)
                actor.SetPosition(coord)

        self.renderWindow.Render()
        
        
