# -*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.
from qt import QComboBox, QGridLayout, QHBoxLayout, QLabel, QLineEdit
from qt import QPushButton, QSize, QSizePolicy, QSpinBox, QToolTip, QWhatsThis
from qt import SIGNAL, qApp
from GUI.Plots import PlotSetup

class ScatterPlot3DSetup(PlotSetup.PlotSetup):
    def __init__(self, renderSetup = None,name = None,fl = 0):
        """See GUI/Plots/PlotSetup """
        PlotSetup.PlotSetup.__init__(self, renderSetup, name, fl)

        if not name:
            self.setName("ScatterPlot3DSetup")

        self.name.show()
        
        ScatterPlot3DSetupLayout = QGridLayout(self,1,1,11,6,"ScatterPlot3DSetupLayout")

        self.rangeLabel = QLabel(self,"rangeLabel")
        self.rangeLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.rangeLabel.sizePolicy().hasHeightForWidth()))

        ScatterPlot3DSetupLayout.addWidget(self.rangeLabel,5,0)

        self.zSource = QComboBox(0,self,"zSource")

        ScatterPlot3DSetupLayout.addWidget(self.zSource,4,1)

        self.ySource = QComboBox(0,self,"ySource")

        ScatterPlot3DSetupLayout.addWidget(self.ySource,3,1)

        self.xLabel = QLabel(self,"xLabel")
        self.xLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.xLabel.sizePolicy().hasHeightForWidth()))

        ScatterPlot3DSetupLayout.addWidget(self.xLabel,2,0)

        self.zDir = QComboBox(0,self,"zDir")

        ScatterPlot3DSetupLayout.addWidget(self.zDir,4,2)

        self.zLabel = QLabel(self,"zLabel")
        self.zLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.zLabel.sizePolicy().hasHeightForWidth()))

        ScatterPlot3DSetupLayout.addWidget(self.zLabel,4,0)

        self.xSource = QComboBox(0,self,"xSource")
        self.xSource.setSizePolicy(QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Fixed,0,0,self.xSource.sizePolicy().hasHeightForWidth()))

        ScatterPlot3DSetupLayout.addWidget(self.xSource,2,1)

        self.yLabel = QLabel(self,"yLabel")
        self.yLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.yLabel.sizePolicy().hasHeightForWidth()))

        ScatterPlot3DSetupLayout.addWidget(self.yLabel,3,0)

        self.xDir = QComboBox(0,self,"xDir")

        ScatterPlot3DSetupLayout.addWidget(self.xDir,2,2)

        self.yDir = QComboBox(0,self,"yDir")

        ScatterPlot3DSetupLayout.addWidget(self.yDir,3,2)

        self.range = QLineEdit(self,"range")
        self.range.setSizePolicy(QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed,0,0,self.range.sizePolicy().hasHeightForWidth()))

        ScatterPlot3DSetupLayout.addWidget(self.range,5,1)

        self.applyButton = QPushButton(self, "applyButton")
        self.applyButton.setText("Apply setup")
        ScatterPlot3DSetupLayout.addWidget(self.applyButton,6,3)
        self.connect(self.applyButton, SIGNAL("clicked()"), self.slotApply)

        # self.name is defined in PlotSetup
        ScatterPlot3DSetupLayout.addWidget(self.name,1,1)

        self.nameLabel = QLabel(self,"nameLabel")
        self.nameLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.nameLabel.sizePolicy().hasHeightForWidth()))

        ScatterPlot3DSetupLayout.addWidget(self.nameLabel,1,0)

        layout2 = QHBoxLayout(None,0,6,"layout2")

        self.xNrLabel = QLabel(self,"xNrLabel")
        self.xNrLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Preferred,0,0,self.xNrLabel.sizePolicy().hasHeightForWidth()))
        layout2.addWidget(self.xNrLabel)

        self.xNumber = QSpinBox(self,"xNumber")
        self.xNumber.setSizePolicy(QSizePolicy(QSizePolicy.Minimum, QSizePolicy.Fixed,0,0,self.xNumber.sizePolicy().hasHeightForWidth()))
        self.xNumber.setMaxValue(100000)
        self.xNumber.setMinValue(1)
        self.xNumber.setValue(1)
        layout2.addWidget(self.xNumber)

        ScatterPlot3DSetupLayout.addLayout(layout2,2,3)

        layout3 = QHBoxLayout(None,0,6,"layout3")

        self.yNrLabel = QLabel(self,"yNrLabel")
        self.yNrLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Preferred,0,0,self.yNrLabel.sizePolicy().hasHeightForWidth()))
        layout3.addWidget(self.yNrLabel)

        self.yNumber = QSpinBox(self,"yNumber")
        self.yNumber.setMaxValue(100000)
        self.yNumber.setMinValue(1)
        self.yNumber.setValue(2)
        layout3.addWidget(self.yNumber)

        ScatterPlot3DSetupLayout.addLayout(layout3,3,3)

        layout4 = QHBoxLayout(None,0,6,"layout4")

        self.zNrLabel = QLabel(self,"zNrLabel")
        self.zNrLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Preferred,0,0,self.zNrLabel.sizePolicy().hasHeightForWidth()))
        layout4.addWidget(self.zNrLabel)

        self.zNumber = QSpinBox(self,"zNumber")
        self.zNumber.setMaxValue(100000)
        self.zNumber.setMinValue(1)
        self.zNumber.setValue(3)
        layout4.addWidget(self.zNumber)

        ScatterPlot3DSetupLayout.addLayout(layout4,4,3)

        # self.typeLabel is defined in PlotSetup
        self.typeLabel.setSizePolicy(QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed,0,0,self.typeLabel.sizePolicy().hasHeightForWidth()))

        ScatterPlot3DSetupLayout.addMultiCellWidget(self.typeLabel,0,0,0,1)


        self.setCaption(self.__tr("Plot Config"))
        self.rangeLabel.setText(self.__tr("Data range:"))
        self.zSource.clear()
        self.ySource.clear()
        self.xSource.clear()
        
        self.xLabel.setText(self.__tr("X-axis data:"))
        self.zDir.clear()
        self.zDir.insertItem(self.__tr("column"))
        self.zDir.insertItem(self.__tr("row"))
        self.zLabel.setText(self.__tr("Z-axis data:"))
        
        self.yLabel.setText(self.__tr("Y-axis data:"))
        self.yDir.clear()
        self.yDir.insertItem(self.__tr("column"))
        self.yDir.insertItem(self.__tr("row"))
        
        self.xDir.clear()
        self.xDir.insertItem(self.__tr("column"))
        self.xDir.insertItem(self.__tr("row"))

        QToolTip.add(self.range,self.__tr("Ex: 1,3,5-7"))
        self.nameLabel.setText(self.__tr("Plot name:"))
        self.xNrLabel.setText(self.__tr("nr"))
        self.yNrLabel.setText(self.__tr("nr"))
        self.zNrLabel.setText(self.__tr("nr"))
        #self.typeLabel.setText(self.__tr("ScatterPlot3D setup:"))



        # Object label section #
        
        self.objectLabelLabel = QLabel(self, "objectlabel")
        self.objectLabelLabel.setText("Object labelling:")

        self.objectLabelCombo = QComboBox(self, "objectLabelCombo")
        self.objectLabelCombo.insertItem("No labels", 0)
        self.objectLabelCombo.insertItem("All objects labelled", 1)
        self.objectLabelCombo.insertItem("Picked objects labelled", 2)
        QToolTip.add(self.objectLabelCombo,
                     "Labelling mode for objects")
        QWhatsThis.add(self.objectLabelCombo,
                       "Sets the mode for object labelling. \"No Labels\" means that no objects are labelles. " +
                       "This is the default setting. \"All objects labelled\" means that all objects in the plot " +
                       "will get a label indicating the index of the object in the data set of the plot. " +
                       "\"Picked objects labelled\" means that only the objects that are picked will display a label.")

        ScatterPlot3DSetupLayout.addWidget(self.objectLabelLabel, 6,0)
        ScatterPlot3DSetupLayout.addWidget(self.objectLabelCombo, 6,1)

        
        self.resize(QSize(333,195).expandedTo(self.minimumSizeHint()))
        

        self.setTabOrder(self.name,self.xSource)
        self.setTabOrder(self.xSource,self.xDir)
        self.setTabOrder(self.xDir,self.xNumber)
        self.setTabOrder(self.xNumber,self.ySource)
        self.setTabOrder(self.ySource,self.yDir)
        self.setTabOrder(self.yDir,self.yNumber)
        self.setTabOrder(self.yNumber,self.zSource)
        self.setTabOrder(self.zSource,self.zDir)
        self.setTabOrder(self.zDir,self.zNumber)
        self.setTabOrder(self.zNumber,self.range)

    def updateInputPorts(self, ports):
        
        x_text = str(self.xSource.currentText())
        y_text = str(self.ySource.currentText())
        z_text = str(self.zSource.currentText())
        self.xSource.clear()
        self.ySource.clear()
        self.zSource.clear()

        for port in ports:
            self.xSource.insertItem(port)
            self.ySource.insertItem(port)
            self.zSource.insertItem(port)

        for item_index in range(self.xSource.count()):
            if x_text == str(self.xSource.text(item_index)):
                self.xSource.setCurrentItem(item_index)
                # x_found = True
            if y_text == str(self.ySource.text(item_index)):
                self.ySource.setCurrentItem(item_index)
                # y_found = True
            if z_text == str(self.zSource.text(item_index)):
                self.zSource.setCurrentItem(item_index)
            
    def slotApply(self):

        config = self.getConfig()
        
        filter = self.plot.getDataFilter()

        filter.clearFilters()

        filter.addFilter(config["xdata"], config["xdirection"], config["xnumber"])
        filter.addFilter(config["ydata"], config["ydirection"], config["ynumber"])
        filter.addFilter(config["zdata"], config["zdirection"], config["znumber"])

        range = config["range"]
        
        if not range:
            range = ["*"]
        else:
            # parseRange is from PlotSetup 
            range = self.parseRange(range)
        
        filter.setRange(range)

        self.plot.setLabelMode(int(self.objectLabelCombo.currentItem()))

        self.renderSetup.renameSelectedPlot(config["name"])
        # Always call this at the end if you want to redraw a plot!!!
        PlotSetup.PlotSetup.slotApply(self)
        
    def __tr(self,s,c = None):
        return qApp.translate("ScatterPlot3DSetup",s,c)

    
    def getConfig(self):
        config = {}
        config["name"] = str(self.name.text())
        config["xdata"] = str(self.xSource.currentText())
        config["xdirection"] = str(self.xDir.currentText())
        config["xnumber"] = str(self.xNumber.text())
        config["ydata"] = str(self.ySource.currentText())
        config["ydirection"] = str(self.yDir.currentText())
        config["ynumber"] = str(self.yNumber.text())
        config["zdata"] = str(self.zSource.currentText())
        config["zdirection"] = str(self.zDir.currentText())
        config["znumber"] = str(self.zNumber.text())
        config["range"] = str(self.range.text())
        config["labelMode"] = str(self.objectLabelCombo.currentItem())
        return config

    def setConfig(self, config):
        self.name.setText(str(config["name"]))

        # find the right field in the combo boxes by try-and-fail:
        for i in range(self.xSource.count()):
            self.xSource.setCurrentItem(i)
            if str(self.xSource.currentText()) == str(config["xdata"]):
                break
        for i in range(self.xDir.count()):
            self.xDir.setCurrentItem(i)
            if str(self.xDir.currentText()) == str(config["xdirection"]):
                break
        self.xNumber.setValue(int(config["xnumber"]))

        # find the right field in the combo boxes by try-and-fail:
        for i in range(self.ySource.count()):
            self.ySource.setCurrentItem(i)
            if str(self.ySource.currentText()) == str(config["ydata"]):
                break
        for i in range(self.yDir.count()):
            self.yDir.setCurrentItem(i)
            if str(self.yDir.currentText()) == str(config["ydirection"]):
                break
        self.yNumber.setValue(int(config["ynumber"]))
        
        # find the right field in the combo boxes by try-and-fail:
        for i in range(self.zSource.count()):
            self.zSource.setCurrentItem(i)
            if str(self.zSource.currentText()) == str(config["zdata"]):
                break
        for i in range(self.zDir.count()):
            self.zDir.setCurrentItem(i)
            if str(self.zDir.currentText()) == str(config["zdirection"]):
                break
        self.zNumber.setValue(int(config["znumber"]))

        self.range.setText(str(config["range"]))

        try:
            self.objectLabelCombo.setCurrentItem(int(config["labelMode"]))

        # Old format of config
        except KeyError, e:
            # Plot has no label mode. Setting to NO LABEL.
            self.objectLabelCombo.setCurrentItem(0)
