# -*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qt import QComboBox, QGridLayout, QLabel, QLineEdit, QPushButton, QSize
from qt import QSizePolicy, SIGNAL, qApp
from GUI.Plots import PlotSetup

class SurfacePlot3DSetup(PlotSetup.PlotSetup):
    def __init__(self, renderSetup = None, name = None, fl = 0):
        PlotSetup.PlotSetup.__init__(self, renderSetup, name, fl)

        if not name:
            self.setName("SurfacePlot3DSetup")

        SurfacePlot3DSetupLayout = QGridLayout(self,1,1,11,6,"SurfacePlot3DSetupLayout")

        self.typeLabel = QLabel(self,"typeLabel")
        self.typeLabel.setSizePolicy(QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Fixed,0,0,self.typeLabel.sizePolicy().hasHeightForWidth()))


        self.nameLabel = QLabel(self,"nameLabel")
        self.nameLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.nameLabel.sizePolicy().hasHeightForWidth()))

        self.dataLabel = QLabel(self,"dataLabel")
        self.dataLabel.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed,0,0,self.dataLabel.sizePolicy().hasHeightForWidth()))

        self.dataSource = QComboBox(0,self,"dataSource")

        self.name = QLineEdit(self,"name")

        self.applyButton = QPushButton(self, "applyButton")
        self.applyButton.setText("Apply setup")
        self.connect(self.applyButton, SIGNAL("clicked()"), self.slotApply)

        SurfacePlot3DSetupLayout.addWidget(self.typeLabel,0,0)
        SurfacePlot3DSetupLayout.addWidget(self.nameLabel,1,0)
        SurfacePlot3DSetupLayout.addWidget(self.name,1,1)
        SurfacePlot3DSetupLayout.addWidget(self.dataLabel,2,0)
        SurfacePlot3DSetupLayout.addWidget(self.dataSource,2,1)
        SurfacePlot3DSetupLayout.addWidget(self.applyButton,3,1)

        self.resize(QSize(308,80).expandedTo(self.minimumSizeHint()))
        #self.clearWState(Qt.WState_Polished)

        self.setTabOrder(self.name,self.dataSource)
        self.setCaption(self.__tr("Plot Config"))
        self.nameLabel.setText(self.__tr("Plot name:"))
        self.dataLabel.setText(self.__tr("Source data:"))
        self.dataSource.clear()
        
        #self.typeLabelLabel.setText(self.__tr("Type:"))
        #self.typeLabel.setText(self.__tr("SurfacePlot3D"))

    def updateInputPorts(self, ports):
        source_text = str(self.dataSource.currentText())
        self.dataSource.clear()

        for port in ports:
            self.dataSource.insertItem(port)

        for item_index in range(self.dataSource.count()):
            if source_text == str(self.dataSource.text(item_index)):
                self.dataSource.setCurrentItem(item_index)
        
    def slotApply(self):
        config = self.getConfig()
        filter = self.plot.getDataFilter()

        filter.clearFilters()

        filter.addFilter(config["data"])
        self.renderSetup.renameSelectedPlot(config["name"])

        PlotSetup.PlotSetup.slotApply(self)
        

    def __tr(self,s,c = None):
        return qApp.translate("SurfacePlot3DSetup",s,c)

    def getConfig(self):
        config = {}
        config["name"] = str(self.name.text())
        config["data"] = str(self.dataSource.currentText())
        return config

    def setConfig(self, config):
        self.name.setText(str(config["name"]))
        for i in range(self.dataSource.count()):
            self.dataSource.setCurrentItem(i)
            if str(self.dataSource.currentText()) == str(config["data"]):
                break

    
