# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.



from qt import QObject

class SimplePlotDataFilter(QObject):
    """A simple filter without much logic. Used by plots that are supposed to always
    use the whole data range of the input data (e.g. surface plots)"""
    
    def __init__(self, data = None):
        QObject.__init__(self)
        self.data = data
        self.filters = []
        self.filterControl = None


    def getPlotData(self):
        """
        Return:
               - List[List[float]] - the data set of the variable name in the filter.
        Return the data that this node handles."""
        
        try:
            for filter in self.filters:
                return self.data[filter]
        except KeyError, e:
            # Port seems empty of data
            return [[]]


    def getMinMax(self):
        """
        Return:
              - List[float, float] - the minimum and maximum values in the data set"""
        
        data = self.getPlotData()

        if type(data) == list and type(data[0]) == list:

            maxList = []
            minList = []
            try:
                for row in data:
                    maxList.appned(max(row))
                    minList.append(min(row))

                return [min(minList), max(maxList)]
            except ValueError, e:

                return [0,0]

        elif type(data) == list:
            try:
                return [min(data), max(data)]
            except ValueError, e:
                pass

        else:

            return [0,0]
        
    def addFilter(self, variableName):

        self.filters.append(variableName)

    def computeFullRange(self):
        return []
    
    def setFilterControl(self, control):

        self.filterControl = control

    def removeFilterControl(self):

        self.filterControl = None

    def clearFilters(self):
        self.data = {}
        self.filters = []

    def setData(self, data):
        """
        Params:
               - data : dictionary - A dictionary with all data available to this filter."""

        self.data = data

    def updateRangeToData(self):
        """This methos i added because Plot.py contains a general
        method to redraw plots. That methot calls updateRangeToData on
        all filters, simple or not."""
        
        pass
    
