# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

class InteractionMode:
    """Represents an interaction mode for use in plots, specifically created for the
    MoleculeEditor."""

    def __init__(self, renderWindow):
        self.renderWindow = renderWindow
        self.mouseDown = False

    # main interface start

    def startMode(self):
        """Callback, mode is active, set it up."""
        pass

    def endMode(self):
        """Callback, mode is now not active, clean up."""
        pass

    def mousePressed(self, x, y):
        """Mouse pressed down at pixel position x,y. Returns True if event should be passed on."""
        self.mouseDown = True
        return True

    def mouseReleased(self, x, y):
        """Mouse released at pixel position x,y. Returns True if event should be passed on."""
        self.mouseDown = False
        return True

    def mouseMoved(self, x, y):
        """Mouse moved, currently at pixel position x,y. Returns True if event should be passed on."""
        return True

    def keyPressed(self, key):
        """Key pressed. Returns True if event should be passed on."""
        return True

    def keyReleased(self, key):
        """Key released. Returns True if event should be passed on."""
        return True

    def postPaintEvent(self):
        """Allow mode to paint on renderWindow just after renderWindow has been repainted."""
        pass
    
    # main interface end

    def isMouseDown(self):
        return self.mouseDown
