# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from GUI.Plots.interaction.CameraMode import CameraMode
from qt import QKeyEvent

class PickMode(CameraMode):
    """Allows user to pick using mouse."""

    def __init__(self, renderWindow):
        CameraMode.__init__(self, renderWindow)

    def endMode(self):
        """Make sure bounding box doesn't still show after ending mode."""
        CameraMode.endMode(self)
        self.renderWindow.hideBoundingBox()

    def mousePressed(self, x, y):
        """Pick actor at mouse-position."""
        CameraMode.mousePressed(self, x, y)
        ev = QKeyEvent(QKeyEvent.KeyPress, QKeyEvent.Key_P, QKeyEvent.Key_P, 0)
        self.renderWindow.keyPressEvent(ev)
        return False

    def mouseReleased(self, x, y):
        """Mouse released at pixel position x,y. Returns True if event should be passed on."""
        ev = QKeyEvent(QKeyEvent.KeyRelease, QKeyEvent.Key_P, QKeyEvent.Key_P, 0)
        self.renderWindow.keyReleaseEvent(ev)
        return False
