# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from GUI.Plots.interaction.InteractionMode import InteractionMode

class RotateMode(InteractionMode):
    """Creates a mode for rotat actors. The actual moving is done by the defined callbacks."""

    def __init__(self, renderWindow, interactiveCallback, endCallback):
        """
        interactiveCallback and endCallback both must take one parameter:
        rotationMatrix - contains rotation for all picked items

        interactiveCallback is called repeatedly while moving the mouse
        with mouse button down.
        
        endCallback is called when releasing the button, making the move
        final."""
        InteractionMode.__init__(self, renderWindow)
        
        self.endCallback = endCallback
        self.interactiveCallback = interactiveCallback
        self.moving = False

    def mousePressed(self, x, y):
        """Only try to rotate actors if mouse is pressed on an actor."""
        InteractionMode.mousePressed(self, x, y)
        picker = self.renderWindow.GetPicker()
        # convert coordinates
        pickY = self.renderWindow.height() - y

        # object hit?
        if picker.Pick((x, pickY, 0.0), self.renderWindow.renderer):
            self.startPosition = picker.GetPickPosition()

            self.moving = True
            self.moved = lambda : None
            self.moved.x = x
            self.moved.y = y
            self.moved.lastx = x
            self.moved.lasty = y

            return False
        else:
            return True



    def mouseReleased(self, x, y):
        """Mouse released at pixel position x,y. Returns True if event should be passed on."""
        InteractionMode.mouseReleased(self, x, y)
        if self.moving:
            self.endCallback()
            self.moving = False
            return False
        else:
            return True

    def mouseMoved(self, x, y):
        """Mouse moved, currently at pixel position x,y. Returns True if event should be passed on."""
        InteractionMode.mouseMoved(self, x, y)
        if self.isMouseDown():
            if self.moving:
                self.moved.lastx = self.moved.x
                self.moved.lasty = self.moved.y
                self.moved.x = x
                self.moved.y = y

                self.interactiveCallback(self.moved.x,
                                         self.moved.y,
                                         self.moved.lastx,
                                         self.moved.lasty)

            return False
        else:
            return True

