# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from GUI.Plots.interaction.InteractionMode import InteractionMode
from qt import QColor, QPainter

class SelectBoxMode(InteractionMode):
    """
    Allows user to use a rectangular selectionbox to select an area within a plot.
    A callback function is used to handle the end of each selection."""

    def __init__(self, renderWindow, callback):
        """Callback must take four parameters, x, y, width, height. It is called
        at end of selection."""
        InteractionMode.__init__(self, renderWindow)
        self.callback = callback
        self.selecting = False

    def startMode(self):
        """Callback, mode is active, set it up."""
        pass

    def endMode(self):
        """Callback, mode is now not active, clean up."""
        pass

    def mousePressed(self, x, y):
        """Mouse pressed down at pixel position x,y. Returns True if event should be passed on."""
        InteractionMode.mousePressed(self, x, y)
        self.selection = lambda : None
        self.selection.x = x
        self.selection.y = y
        self.selection.width = 0
        self.selection.height = 0
        return False

    def mouseReleased(self, x, y):
        """Mouse released at pixel position x,y. Returns True if event should be passed on."""
        InteractionMode.mouseReleased(self, x, y)
        if self.selection.width < 0:
            self.selection.width = -self.selection.width
            self.selection.x = self.selection.x - self.selection.width
        if self.selection.height < 0:
            self.selection.height = -self.selection.height
            self.selection.y -= self.selection.height
                    
        self.callback(self.selection.x,
                      self.selection.y,
                      self.selection.width,
                      self.selection.height)
        return True

    def mouseMoved(self, x, y):
        """Mouse moved, currently at pixel position x,y. Returns True if event should be passed on."""
        if self.isMouseDown():
            self.selection.width = x - self.selection.x
            self.selection.height = y - self.selection.y
            self.renderWindow.repaint()
            return False
        else:
            return True

    
    def postPaintEvent(self):
        """Paint selection rectangle when selecting."""
        if self.isMouseDown():
            qp = QPainter(self.renderWindow)
            self.renderWindow.setPaletteForegroundColor(QColor(255,0,0))
            qp.drawRect(self.selection.x,
                        self.selection.y,
                        self.selection.width,
                        self.selection.height)
