# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from GUI.Plots.plot2d.scatterplot import ScatterPlotSettings, ScatterPlot
from Library.Util import rangeparser
from Library.Util.rtester import RTester, RInstallError
import Numeric

class NormalQqPlot(ScatterPlot):
    """A normal quantile-quantile plot.

    The plot is a normal quantile-quantile plot passing through first
    and third quartiles, showing correlation between data and
    normal distribution.
    """
    
    _type = "normal_qq_plot"
    _name = "Normal QQ Plot"
    
    def set_vector_data(self, y_values, indices=None):
        """Create plot based on vector."""
        
        if len(y_values) > 1:
              try:
                  RTester.r_install_test()
                  import rpy
                  x_values = rpy.r.qqnorm(y_values, plot_it=False)['x']
              except RInstallError, e:
                  x_values = False
        else:
            x_values = [0.0]

        if x_values:
            self.set_data(x_values, y_values, indices)

    def create_settings(self, index, tab_widget, plot_widget, node):
        return NormalQqPlotSettings(node, index, tab_widget, plot_widget, self)
    

class NormalQqPlotSettings(ScatterPlotSettings):
    def __init__(self, node, index, tab_widget, plot_widget, plot):
        ScatterPlotSettings.__init__(self, node, index, tab_widget, plot_widget,
                                     plot)
        # default to being rowwise
        self._combo_box_y_col_row.setCurrentText("row")
        self.set_parameter('y_col_row', 1)
        self.update_data_names_combo_boxes()
        self._combo_box_x_axis_data.hide()
        self._combo_box_x_col_row.hide()
        self._spin_box_x_index.hide()
        self._text_label_x_nr = self._settings_widget.child('text_label_x_nr')
        self._text_label_x_nr.hide()
        self._text_label_x_axis_data = self._settings_widget.child('text_label_x_axis_data')
        self._text_label_x_axis_data.hide()

    def _slot_plot_name_changed(self, name):
        if self in self._tab_widget._plot_settings_widgets:
            ScatterPlotSettings._slot_plot_name_changed(self, name)

    def update_data(self):

        vector = self._y_data_selector.get_list()
        if not vector:
            return

        indices = rangeparser.matlab_parse_range(self.get_parameter('range'),
                                                 range(len(vector)))
        self._plot.set_vector_data(vector, indices)

        self._qwt_plot_widget.replot()
        self._label_settings_dialog.apply_settings()
        self._marker_settings_dialog._set_values()
        self._marker_settings_dialog.apply_settings()

