# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qt import QBoxLayout, QDockWindow, QLabel, QProgressBar, Qt

class ProgressDockWindow(QDockWindow):

    
    def __init__(self, parent):
        QDockWindow.__init__(self, QDockWindow.InDock, parent)
        
        self.running = False
        self.crashed = False
        
        self.progressBar = QProgressBar(100, self)
        self.progressBar.setPercentageVisible(1)
        self.progressBar.setFixedWidth(150)
        self.progressBar.setProgress(0)
        
        self.label = QLabel("Ready", self)
        self.label.resize(20, 20)
        
        layout = self.boxLayout()
        layout.setDirection(QBoxLayout.LeftToRight)
        layout.addWidget(self.label)
        layout.addWidget(self.progressBar)
        
        self.setMovingEnabled(0)
        self.setFixedWidth(205)
        self.setFixedHeight(24)

        self.progressBar.show()
        self.label.show()
        
        self.show()


    def setup(self, steps = None):
        if steps:
            self.progressBar.setTotalSteps(steps)
        if not self.running:
            self.label.setText("Ready")
            self.label.setPaletteForegroundColor(Qt.black)
            self.label.update()
            self.progressBar.setPaletteForegroundColor(Qt.black)
            self.progressBar.update()
            self._clear()

    
    def startProgress(self):
        self.label.setText("Running")
        self.label.update()
        self.running = True

    
    def addProgress(self, step):
        self.label.update()
        if self.progressBar.totalSteps() == 0:
            return False
        else:
            progress = self.progressBar.progress()
            self.progressBar.setProgress(progress + step)
            return True

    
    def refreshBar(self):
        progress = self.progressBar.progress()
        self.progressBar.setProgress(progress)


    def _clear(self):
        self.progressBar.reset()
        self.progressBar.setProgress(0) 
        self.running = False
        self.crashed = False
    

    def paintEvent(self, e):
        self.progressBar.updateGeometry()
        self.label.updateGeometry()
    
    
    def isCrashed(self):
        return self.crashed
        

    def setCrashed(self):
        self.label.setText("ERROR")
        self.label.setPaletteForegroundColor(Qt.red)
        self.label.update()
        self.progressBar.setPaletteForegroundColor(Qt.red)
        self.progressBar.update()
        self.running = False
        self.crashed = True
    
    
    def setFinished(self):
        self.label.setText("Done.")
        self.label.update()
        self.running = False


    def setHalted(self):
        self.label.setText("Interrupted.")
        self.label.setPaletteForegroundColor(Qt.red)
        self.progressBar.setPaletteForegroundColor(Qt.red)
        self.label.update()
        self.progressBar.update()
        self.running = False

