# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qtui import QWidgetFactory
from qt import QWidget, QMimeSourceFactory 

import os

from Library.Util.Config import Config

class AboutViewer:

    def __init__(self, parent):
        
        factory = QWidgetFactory()
        widget = factory.create(os.path.join(Config.uidir, "aboutwidget.ui"), None, parent)

        browser = widget.child("textBrowser")
        text = browser.text().ascii().replace('Version: ', 'Version: %s' % Config.version)
        browser.setText(text)
        
        widget.show()
                                     
class ChangelogViewer:
    def __init__(self, parent):
        factory = QWidgetFactory()
        widget = factory.create(os.path.join(Config.uidir,"changelog_widget.ui"), None, parent)

        browser = widget.child("textBrowser")        
        file_ = open(os.path.join(Config.scicrafthome, 'changelog.html')) 
        text = file_.read()
        file_.close()
        browser.setText(text)
        
        widget.show()


class HelpViewer(QWidget):
    
    def __init__(self, parent, file, mimePath = 0, modal=False):
        QWidget.__init__(self, parent)

        widget = QWidgetFactory.create(os.path.join(Config.uidir, "helpwidget.ui"), None, self)
        self._textBrowser = widget.child("textBrowser")
        
        text = "<h2>Unable to open the requested help file</h2>" +\
            "Please make " +\
            "sure the HTML documentation files have been generated.<br>To " +\
            "generate the HTML documentation, execute the following " +\
            "command from your SciCraft directory: <i>make html</i>" +\
            "<p>If you are unable to generate the help files, or the help " +\
            "files are not generated with the command mentioned, please " +\
            "contact the SciCraft Team to report this error. Please " +\
            "include the following path in your report: <font size='-1'>" +\
            "'" + file + "'</font><p>The SciCraft documentation is" +\
            " also available on the Internet at http://www.scicraft.org."
        
        self.mimeSource = QMimeSourceFactory()
    
        if os.access(file, os.R_OK):
            f = open(file)
            if not mimePath:
                filePath = os.path.dirname(file)
            else:
                filePath = mimePath

            self.mimeSource.addFilePath(filePath)
            text = f.read()
            
        self._textBrowser.setMimeSourceFactory(self.mimeSource)
        self._textBrowser.setText(text)

        if modal:
            widget.exec_loop()
        else:
            widget.show()

