# -*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from qtui import QWidgetFactory
from qt import QWidget, QListViewItem, QObject, SIGNAL, QFileDialog, QPixmap
from qt import QMessageBox, QInputDialog, QListViewItemIterator, QLineEdit
from qt import QPopupMenu

import os.path
import shutil

from GUI.viewers import HelpViewer
from Library.Util.Config import Config
from System.Data.zml import ZMLWriter, FunctionData

FUNCTIONNODE  = 0
OUTPUTPORT    = 1
INPUTPORT     = 2
PARAMETER     = 3
NO_SELECTION  = 4
SEPARATOR     = 5

UNTITLED_FILE = "untitled"

connect = QObject.connect

class ZMLCreator(QWidget):
    """ ZMLCreator main class.
    """
    def __init__(self, parent):
        QWidget.__init__(self, parent)
        
        self._widget = QWidgetFactory().create(os.path.join(Config.uidir, "zmlcreator.ui"), None, self)

        self._filename = UNTITLED_FILE
    
        self._init_gui()
        self._create_new_functionnode()
         
        self._widget.show()
         
        self._set_changes_saved(True)
        
    def _init_gui(self):
        self._widget_stack_details = self._widget.child("widget_stack_details")
        self._list_items = self._widget.child("list_items")
        self._button_move_up = self._widget.child("button_move_up")
        self._button_move_down = self._widget.child("button_move_down")
        
        # Menu items
        
        self._menu_file_new = self._widget.child("file_new")
        self._menu_file_open = self._widget.child("file_open")
        self._menu_file_save = self._widget.child("file_save")
        self._menu_file_save_as = self._widget.child("file_save_as")
        self._menu_file_exit = self._widget.child("file_exit")
        self._menu_new_inputport = self._widget.child("edit_new_inputport")
        self._menu_new_outputport = self._widget.child("edit_new_outputport")
        self._menu_new_parameter = self._widget.child("edit_new_parameter")
        self._menu_delete = self._widget.child("edit_delete")
        self._menu_help = self._widget.child("help_help")
        self._context = self._widget.child("Edit")
        
        # Function details
        
        self._edit_func_title = self._widget.child("edit_func_title")
        self._edit_func_filename = self._widget.child("edit_func_filename")
        self._edit_func_description = self._widget.child("edit_func_description")
        self._edit_func_menu = self._widget.child("edit_func_menu")
        self._edit_func_doc = self._widget.child("edit_func_doc")
        self._combo_func_plugin = self._widget.child("combo_func_plugin")
        self._button_func_browse = self._widget.child("button_func_browse")
        self._edit_func_icon = self._widget.child("edit_func_icon")
        self._button_func_icon_browse = self._widget.child("button_func_icon_browse")
        self._func_icon = self._widget.child("func_icon")
        self._lbl_func_icon_info = self._widget.child("lbl_func_icon_info")
        
        # Outport details
        
        self._edit_output_title = self._widget.child("edit_output_title")
        self._edit_output_description = self._widget.child("edit_output_description")
        self._edit_output_subobject = self._widget.child("edit_output_subobject")
        self._lbl_output_subobject = self._widget.child("lbl_output_subobject")
        self._button_output_ok = self._widget.child("button_output_ok")
        
        # Inport details
        
        self._edit_input_title = self._widget.child("edit_input_title")
        self._edit_input_description = self._widget.child("edit_input_description")        
        self._chk_input_named = self._widget.child("chk_input_named")  
        self._button_input_ok = self._widget.child("button_input_ok")
     
        # Parameter details
        
        self._edit_param_title = self._widget.child("edit_param_title")
        self._edit_param_description = self._widget.child("edit_param_description")
        self._edit_param_max = self._widget.child("edit_param_max")
        self._edit_param_min = self._widget.child("edit_param_min")
        self._edit_param_step = self._widget.child("edit_param_step")

        self._lbl_param_comment = self._widget.child("lbl_param_comment")
        self._lbl_param_default = self._widget.child("lbl_param_default")
        self._lbl_param_max = self._widget.child("lbl_param_max")
        self._lbl_param_min = self._widget.child("lbl_param_min")
        self._lbl_param_step = self._widget.child("lbl_param_step")

        self._edit_param_default = self._widget.child("edit_param_default")
        self._combo_param_type = self._widget.child("combo_param_type")
        self._list_param_values = self._widget.child("list_param_values")
        self._button_param_add = self._widget.child("button_param_add")
        self._button_param_delete = self._widget.child("button_param_delete")
        
        self._button_param_ok = self._widget.child("button_param_ok")
        
        self._list_param_values.clear()
        
        # Signals
        
        connect(self._list_items, SIGNAL("clicked(QListViewItem *)"), self._slot_show_details)
        connect(self._list_items, SIGNAL("rightButtonClicked ( QListViewItem *, const QPoint &, int )"), self._slot_list_context)
        connect(self._button_move_down, SIGNAL("clicked()"), self._slot_move_down)
        connect(self._button_move_up, SIGNAL("clicked()"), self._slot_move_up)
        
        connect(self._combo_func_plugin, SIGNAL("activated(const QString &)"), self._slot_combo_func_plugin)
        connect(self._button_func_browse, SIGNAL("clicked()"), self._slot_browse_docpath)
        connect(self._button_func_icon_browse, SIGNAL("clicked()"), self._slot_browse_icon)        
        
        connect(self._combo_param_type, SIGNAL("activated(const QString &)"), self._slot_combo_param_type)
        connect(self._button_param_add, SIGNAL("clicked()"), self._slot_param_add)
        connect(self._button_param_delete, SIGNAL("clicked()"), self._slot_param_delete)
        
        connect(self._menu_file_new, SIGNAL("activated()"), self._slot_new)
        connect(self._menu_file_open, SIGNAL("activated()"), self._slot_load_file)
        connect(self._menu_file_save, SIGNAL("activated()"), self._slot_save)
        connect(self._menu_file_save_as, SIGNAL("activated()"), self._slot_save_as)
        connect(self._menu_file_exit, SIGNAL("activated()"), self._slot_exit)        
        connect(self._menu_new_inputport, SIGNAL("activated()"), self._slot_new_inputport)
        connect(self._menu_new_outputport, SIGNAL("activated()"), self._slot_new_outputport)
        connect(self._menu_new_parameter, SIGNAL("activated()"), self._slot_new_parameter)
        connect(self._menu_delete, SIGNAL("activated()"), self._slot_delete_item)
        connect(self._menu_help, SIGNAL("activated()"), self._slot_help)
        
        connect(self._button_input_ok, SIGNAL("clicked()"), self._slot_ok)
        connect(self._button_output_ok, SIGNAL("clicked()"), self._slot_ok)
        connect(self._button_param_ok, SIGNAL("clicked()"), self._slot_ok)
        
        # Keep track of editing - '_changes_saved' will be set to false after any data fields has been edited
        
        f = self._slot_data_changed        
        
        s1 = SIGNAL("textChanged (const QString &)")
        connect(self._edit_func_title, s1, f)
        connect(self._edit_func_filename, s1, f)
        connect(self._edit_func_description, s1, f)
        connect(self._edit_func_menu, s1, f)
        connect(self._edit_func_doc, s1, f)
        connect(self._edit_output_title, s1, f)
        connect(self._edit_output_description, s1, f)
        connect(self._edit_output_subobject, s1, f)
        connect(self._edit_input_title, s1, f)
        connect(self._edit_input_description, s1, f)
        connect(self._edit_param_title, s1, f)
        connect(self._edit_param_description, s1, f)
        connect(self._edit_param_max, s1, f)
        connect(self._edit_param_min, s1, f)
        connect(self._edit_param_step, s1, f)
        connect(self._edit_param_default, s1, f)

        s2 = SIGNAL("activated(const QString &)")        
        connect(self._combo_func_plugin, s2, f)
        connect(self._combo_param_type, s2, f)

        s3 = SIGNAL("toggled(bool)")        
        connect(self._chk_input_named, s3, f)
        
        s4 = SIGNAL("clicked()")
        connect(self._button_param_add, s4, f)
        connect(self._button_param_delete, s4, f)
        
        # Miscellaneous
        
        self._list_items.setSorting(-1)        
        self._prev_selected_item = None
        self._list_items.header().hide();

    # Slots
    
    def _slot_list_context(self, item, pos, col):
        self._context.popup(pos)
    
    def _slot_browse_icon(self):
        old_path = str(self._edit_func_icon.text())
        if old_path == "":
            old_path = os.path.split(self._filename)[0]
            
        if not os.path.isabs(old_path):
            old_path = os.path.normpath(os.path.join(os.path.split(self._filename)[0], old_path))                    

        new_path = QFileDialog.getOpenFileName(old_path, "Icon files (*.png *.bmp *.xbm *.xpm *.pnm);;All files (*)",
                    self._widget, "Icon", "Choose a iconfilename ").latin1()
        
        if new_path != None:
            current_path = os.path.split(self._filename)[0]

            # check if icon is placed in same folder or sub-folder of zml-file
            # if not, suggest to copy file to same location as zml-file
            if not os.path.commonprefix([new_path, current_path]) == current_path:
                answer = QMessageBox.question(self._widget,
                                "ZMLCreator", "Would you like to copy the icon to the ZML-file location?", 
                                QMessageBox.Yes, QMessageBox.No)
                if answer == QMessageBox.Yes:
                    new_filename = os.path.split(str(new_path))[-1]
                    try:
                        shutil.copyfile(new_path, os.path.join(current_path, new_filename))
                        new_path = new_filename
                    except:
                        self._show_error_message("Could not copy file.")
                
            self._edit_func_icon.setText(str(new_path))
        
        self._show_icon(str(new_path))
    
    def _slot_browse_docpath(self):
        old_path = str(self._edit_func_doc.text())
        if old_path == "":
            old_path = Config.scicrafthome
            
        if not os.path.isabs(old_path):
            old_path = os.path.normpath(os.path.join(os.path.split(self._filename)[0], old_path))
            
        new_path = QFileDialog.getOpenFileName(old_path, "HTML files (*.htm *.html);;All files (*)",
                    self._widget, "Documentation path", "Choose a documentation path").latin1()            
                    
        if new_path != None:
            self._edit_func_doc.setText(str(new_path))
            
    def _slot_ok(self):
        item = self._list_items.currentItem()
        if item != None:
            self._save_node_details(item)
            self._list_items.clearSelection()
            self._list_items.setSelected(item.parent(), True)
            self._widget_stack_details.raiseWidget(NO_SELECTION)    
    
    def _slot_data_changed(self, data = None):
        self._set_changes_saved(False)
    
    def _slot_combo_func_plugin(self, text):
        if self._get_current_plugin() == "RPlugin":
            self._edit_output_subobject.setEnabled(True)
            self._lbl_output_subobject.setEnabled(True)
        else:
            self._edit_output_subobject.setEnabled(False)
            self._lbl_output_subobject.setEnabled(False)
    
    def _slot_combo_param_type(self, text):
        text = str(text).lower()
        
        label = ""
        max_enable = False
        min_enable = False
        step_enable = False
        
        if text == "integer" or text == "float":
            max_enable = True
            min_enable = True
            step_enable = True
        elif text == "text":
            label = "Number of characters this string may have"
            max_enable = True
            min_enable = True
            
        self._lbl_param_comment.setText(label)
        self._edit_param_max.setEnabled(max_enable) 
        self._edit_param_min.setEnabled(min_enable) 
        self._edit_param_step.setEnabled(step_enable)
        self._lbl_param_max.setEnabled(max_enable) 
        self._lbl_param_min.setEnabled(min_enable) 
        self._lbl_param_step.setEnabled(step_enable)
            
    
    def _slot_param_add(self):
        text = str(QInputDialog.getText("ZMLCreator", "Add value:", QLineEdit.Normal, "", self._widget)[0])
        if text != "":
            self._list_param_values.insertItem(text)
            self._list_param_values.sort()
        
    def _slot_param_delete(self):
        item = self._list_param_values.currentItem()
        if item > -1:
            self._list_param_values.removeItem(item)
        else:
            self._show_error_message("No value marked for deletion!")
        
    def _slot_move_down(self):
        item = self._list_items.currentItem()
        item.move_down()
        self._button_move_up.setEnabled(item.could_move_up())
        self._button_move_down.setEnabled(item.could_move_down())    
        
        self._set_changes_saved(False)
        
    def _slot_move_up(self):
        item = self._list_items.currentItem()
        item.move_up()
        self._button_move_up.setEnabled(item.could_move_up())
        self._button_move_down.setEnabled(item.could_move_down())
        
        self._set_changes_saved(False)
        
    # Menu / toolbar slots
        
    def _slot_new_outputport(self):
        self._save_node_details(self._prev_selected_item)
        data = self._data.add_outputport()
        self._build_zml_tree()
        item = self._get_list_item(data)
        self._list_items.setSelected(item, True)
        self._slot_show_details(item)
        
        self._set_changes_saved(False)

    def _slot_new_inputport(self):
        self._save_node_details(self._prev_selected_item)
        data = self._data.add_inputport()
        self._build_zml_tree()
        item = self._get_list_item(data)
        self._list_items.setSelected(item, True)
        self._slot_show_details(item)
        
        self._set_changes_saved(False)

    def _slot_new_parameter(self):
        self._save_node_details(self._prev_selected_item)
        data = self._data.add_parameter()
        self._build_zml_tree()
        item = self._get_list_item(data)
        self._list_items.setSelected(item, True)  
        self._slot_show_details(item)
        
        self._set_changes_saved(False)

    def _slot_delete_item(self):
        self._save_node_details(self._prev_selected_item)
        self._list_items.currentItem().delete()
        self._widget_stack_details.raiseWidget(NO_SELECTION)
        
        self._set_changes_saved(False)

    def _slot_load_file(self):
        if not self._changes_saved:
            answer = self._show_save_changes_dialog()
            if answer == QMessageBox.Yes:
                self._save_file()
            elif answer == QMessageBox.Abort:
                return

        filename = QFileDialog.getOpenFileName("","SciCraft ZML Files (*.zml);;All files (*)", 
                            self._widget, "Open ZML", "Choose a file").latin1()
        if filename != None:
            try:
                self._data = FunctionData(filename)
            except Exception, e:
                self._show_error_message(str(e))
                return
            self._filename = filename
            self._build_zml_tree()
            self._set_changes_saved(True)
            self._set_status_bar("Loading complete.")
            
    def _slot_save(self):
        self._save_file()

    def _slot_save_as(self):
        self._save_file(True)

    def _slot_exit(self):
        if not self._changes_saved:
            answer = self._show_save_changes_dialog()
            if answer == QMessageBox.Yes:
                self._save_file()
            elif answer == QMessageBox.Abort:
                return
        self._widget.close()                

    def _slot_new(self):
        if not self._changes_saved:
            answer = self._show_save_changes_dialog()
            if answer == QMessageBox.Yes:
                self._save_file()
            elif answer == QMessageBox.Abort:            
                return
        self._create_new_functionnode()                
            
    def _slot_help(self):
        HelpViewer(self._widget, \
            os.path.join(Config.htmldocpath, "node_Using_third_party_functions.html"), Config.htmldocpath)
    
    # Node item slot

    def _slot_show_details(self, node_item):
        self._button_move_up.setEnabled(False)
        self._button_move_down.setEnabled(False)
        
        if node_item != None:
            # diable tracking changes until new data displayed
            tmp_changes_saved = self._changes_saved
            
            self._save_node_details(self._prev_selected_item)
            self._prev_selected_item = node_item        
        
            if node_item.text(0) == "Functionnode":
                self._show_node_details(node_item)
            elif node_item.text(0) == "Inputports" or node_item.text(0) == "Outputports" \
                or node_item.text(0) == "Parameters":
                self._widget_stack_details.raiseWidget(NO_SELECTION)
            elif node_item.get_type() == INPUTPORT or node_item.get_type() == OUTPUTPORT or \
                node_item.get_type() == PARAMETER:
                self._show_node_details(node_item)                                
            else:
                self._widget_stack_details.raiseWidget(node_item.get_type())
                
            # enable tracking changes
            self._set_changes_saved(tmp_changes_saved)
         
    def _create_new_functionnode(self):
        self._data = FunctionData()
        self._build_zml_tree()
        self._set_changes_saved(True)
        self._set_status_bar("Created new functionnode.")
 
    def _show_node_details(self, node_item):
        self._widget_stack_details.raiseWidget(node_item.get_type())

        data = node_item.get_data()

        if node_item.get_type() == FUNCTIONNODE:
            self._edit_func_title.setText(data.get_parameter("title"))
            self._edit_func_description.setText(data.get_parameter("description"))
            self._edit_func_filename.setText(data.get_parameter("filename"))
            self._edit_func_menu.setText(data.get_parameter("menuaddress"))
            self._edit_func_doc.setText(data.get_parameter("doc_path"))
            # remove plugin part from e.g., OctavePlugin becomes Octave
            script_lang = data.get_parameter("plugin")[:-6]
            self._set_combobox(self._combo_func_plugin, script_lang, 0)
            icon = data.get_parameter("icon")
            self._edit_func_icon.setText(icon)
            self._show_icon(icon)
        
        else:
            self._button_move_up.setEnabled(node_item.could_move_up())
            self._button_move_down.setEnabled(node_item.could_move_down())        
            
            if node_item.get_type() == INPUTPORT:
                self._edit_input_title.setText(data.get_parameter("name"))
                self._edit_input_description.setText(data.get_parameter("description"))
                try:
                    self._chk_input_named.setChecked(bool(int(data.get_parameter("isNamed"))))
                except:
                    self._chk_input_named.setChecked(False)

            elif node_item.get_type() == OUTPUTPORT:
                self._edit_output_title.setText(data.get_parameter("name"))
                self._edit_output_description.setText(data.get_parameter("description"))
                self._edit_output_subobject.setText(data.get_subobject())

            elif node_item.get_type() == PARAMETER:
                self._edit_param_title.setText(data.get_parameter("name"))
                self._edit_param_description.setText(data.get_parameter("description"))
                
                self._edit_param_max.setText(data.get_restriction("max"))
                self._edit_param_step.setText(data.get_restriction("step"))
                self._edit_param_min.setText(data.get_restriction("min"))
                self._edit_param_default.setText(data.get_restriction("default"))
                
                self._set_combobox(self._combo_param_type, data.get_parameter("type"), 0)
                self._slot_combo_param_type(self._combo_param_type.currentText())
                
                self._list_param_values.clear()
                self._list_param_values.insertStrList(data.get_values())

    def _get_current_plugin(self):
        """Returns the currently selected script language as plugin text."""
        text = str(self._combo_func_plugin.currentText())
        return text + "Plugin"
    
    def _save_node_details(self, node_item):
        data = node_item.get_data()
        if data == None:
            return
            
        page = self._widget_stack_details.visibleWidget()
        page_id = self._widget_stack_details.id(page)
        
        if page_id == FUNCTIONNODE:
            data.set_parameter("title", str(self._edit_func_title.text()))
            data.set_parameter("description", str(self._edit_func_description.text()))
            data.set_parameter("filename", str(self._edit_func_filename.text()))
            data.set_parameter("menuaddress", str(self._edit_func_menu.text()))
            data.set_parameter("doc_path", str(self._edit_func_doc.text()))
            data.set_parameter("icon", str(self._edit_func_icon.text()))
            data.set_parameter("plugin", self._get_current_plugin())
            self._slot_combo_func_plugin(str(self._combo_func_plugin.currentText()))

        elif page_id == INPUTPORT:
            name = str(self._edit_input_title.text())
            if name != "":
                node_item.setText(0, name)
            data.set_parameter("name", name)
            data.set_parameter("description", str(self._edit_input_description.text()))
            try:
                data.set_parameter("isNamed", str(int(self._chk_input_named.isChecked())))
            except:
                data.set_parameter("isNamed", 0)
            
        elif page_id == OUTPUTPORT:
            name = str(self._edit_output_title.text())
            if name != "":
                node_item.setText(0, name)
            data.set_parameter("name", name)        
            data.set_parameter("description", str(self._edit_output_description.text()))
            data.set_subobject(str(self._edit_output_subobject.text()))
            
        elif page_id == PARAMETER:
            name = str(self._edit_param_title.text())
            if name != "":
                node_item.setText(0, name)
            
            data.set_parameter("name", name)
            data.set_parameter("description", str(self._edit_param_description.text()))
            data.set_parameter("type", str(self._combo_param_type.currentText()))                       
            data.set_restriction("max", str(self._edit_param_max.text()))
            data.set_restriction("step", str(self._edit_param_step.text()))
            data.set_restriction("min", str(self._edit_param_min.text()))
            data.set_restriction("default", str(self._edit_param_default.text()))
            value_list = []
            for i in range(0, self._list_param_values.count()):
                value_list.append(str(self._list_param_values.text(i)))
            data.set_values(value_list)           
            
    def _build_zml_tree(self):
        self._list_items.clear()
        
        functionnode = FunctionNodeItem(self._list_items, FUNCTIONNODE, self._data)
        parameternode = SeparatorItem(functionnode, "Parameters")
        outputnode = SeparatorItem(functionnode, "Outputports")
        inputnode = SeparatorItem(functionnode, "Inputports")
        
        functionnode.setPixmap(0, QPixmap(os.path.join(Config.pixmapdir, "Functions_small.png")))
        image = QPixmap(os.path.join(Config.pixmapdir, "FileHandlers_small.png"))
        outputnode.setPixmap(0, image)
        inputnode.setPixmap(0, image)
        parameternode.setPixmap(0, image)
    
        self._data.get_outputport_list().reverse()
        for port in self._data.get_outputport_list():
            FunctionNodeItem(outputnode, OUTPUTPORT, port)
        self._data.get_outputport_list().reverse()            
        
        self._data.get_inputport_list().reverse()
        for port in self._data.get_inputport_list():
            FunctionNodeItem(inputnode, INPUTPORT, port)
        self._data.get_inputport_list().reverse()            
        
        self._data.get_parameter_list().reverse()
        for port in self._data.get_parameter_list():   
            FunctionNodeItem(parameternode, PARAMETER, port)
        self._data.get_parameter_list().reverse()
            
        self._list_items.insertItem(functionnode)
        
        functionnode.setOpen(True)
        outputnode.setOpen(True)
        inputnode.setOpen(True)
        parameternode.setOpen(True)
        
        self._list_items.setCurrentItem(functionnode)
        self._show_node_details(functionnode)
        self._prev_selected_item = functionnode

    def get_data(self):
        return self._data
        
    def _save_file(self, save_as = False):
        if self._filename == None or self._filename == UNTITLED_FILE or save_as == True:
            if save_as:
                text = "Save File As"
            else:
                text = "Save File"
                
            filename = QFileDialog.getSaveFileName(self._filename,
                        "SciCraft ZML files (*.zml)",
                        self._widget, text, text).latin1()
            
            if filename != None:
                path, ext = os.path.splitext(filename)
                if not ext:
                    filename = path + ".zml"
                self._filename = filename
            else:
                return
        
        # Make sure that we get the edited data
        self._save_node_details(self._list_items.currentItem())
        
        writer = ZMLWriter(self._filename, self._data)
        try:
            writer.write()
        except Exception, e:
            self._show_error_message(str(e))
            return
        self._set_status_bar("Changes saved.")
        self._set_changes_saved(True)
        
    def _show_error_message(self, message):
        QMessageBox.warning(self._widget,
                          "ZMLCreator",
                          message,
                          QMessageBox.Ok,
                          QMessageBox.NoButton,
                          QMessageBox.NoButton)
                          
    def _show_save_changes_dialog(self):
        return QMessageBox.question(self._widget,
                                  "ZMLCreator",
                                  "Save changes?",
                                  QMessageBox.Yes,
                                  QMessageBox.No,
                                  QMessageBox.Abort)
                                  
    def _show_icon(self, icon_path):
        if icon_path:
            # path is absolute
            if os.path.isabs(icon_path):
                full_path = icon_path
            # path given is relative, merge with path to zml-file
            else:
                full_path = os.path.normpath(os.path.join(os.path.split(self._filename)[0], icon_path))

            if os.path.isfile(full_path):
                p = QPixmap(full_path)
                h = p.height()
                w = p.width()
                if w != 40 or h != 40:
                    self._lbl_func_icon_info.setText("Warning: recommended size for functionnode icons is 40x40 pixels. \
The dimensions of this icon is %ix%s." % (w, h))
                else:
                    self._lbl_func_icon_info.setText("")                    

                self._func_icon.setPixmap(p)
                return

        # set empty icon and info if icon not found
        self._func_icon.setText("")
        self._lbl_func_icon_info.setText("")
    
    def _set_combobox(self, combo, text, default):
        for i in range(0, combo.count()):
            if str(combo.text(i)).lower() == text.lower():
                combo.setCurrentItem(i)
                return
        combo.setCurrentItem(default)
        
    def _get_list_item(self, data_object):
        # Returns a listviewitem from the functionnode tree structure based on a data object
        
        iterator = QListViewItemIterator(self._list_items)
        while iterator.current():
            item = iterator.current()
            data = item.get_data()
            if data != None and data == data_object:
                return item
            iterator += 1
        return None
        
    def _update_window_caption(self):
        t = "ZMLCreator - [ " + os.path.split(self._filename)[1]
        if self._changes_saved:
            t = t + " ]"
        else:
            t = t + " *]"
        self._widget.setCaption(t)
        
    def _set_status_bar(self, text):
        self._widget.statusBar().message(text)
        
    def _set_changes_saved(self, bool):
        self._changes_saved = bool
        self._update_window_caption()
        

class SeparatorItem(QListViewItem):
    """ Helper class that displays the "Inputports", "Outputports" and "Parameters" items in the list view.
    """    
    def __init__(self, parent, text):
        QListViewItem.__init__(self, parent, text)
    
    def get_type(self):
        return SEPARATOR
        
    def delete(self):
        return
        
    def move_up(self):
        return
        
    def move_down(self):
        return
        
    def could_move_up(self):
        return False

    def could_move_down(self):
        return False
        
    def get_data(self):
        return None

class FunctionNodeItem(QListViewItem):
    """ Helper class that displays the different inputs, outputs and parameters in the list view.
    """    
    def __init__(self, parent, type, data):
        if type == FUNCTIONNODE:
            text = "Functionnode"
        else:
            text = data.get_parameter("name")
        QListViewItem.__init__(self, parent, text)
        self._type = type
        self._data = data
    
    def get_data(self):
        return self._data
    
    def get_type(self):
        return self._type
        
    def delete(self):
        if hasattr(self._data, "delete"):
            self._data.delete()
            self.parent().takeItem(self)

    def move_up(self):
        if self.could_move_up():
            self._data.move_up()
            self.itemAbove().moveItem(self)
        
    def move_down(self):
        if self.could_move_down():
            self._data.move_down()
            self.moveItem(self.itemBelow())

    def could_move_up(self):
        above = self.itemAbove()
        if above != None:
            return self._type == self.itemAbove().get_type()
        else:
            return False
        
    def could_move_down(self):
        below = self.itemBelow()
        if below != None:
            return self._type == self.itemBelow().get_type()
        else:
            return False
