# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.


from System.Data.Data import Data
from System.Data.Node import Node

# okay, now we'll build the object from scratch...

# create a model instance

def makeModel():
    # import here to creation of node without pymol
    from chempy.models import Indexed
    from chempy import Atom,Bond
    
    atoms = [
        ['C', 'CH3' ,'1','ACE'],
        ['C', 'C'   ,'1','ACE'],
        ['O', 'O'   ,'1','ACE'],
        ['H', '1HH3','1','ACE'],
        ['H', '2HH3','1','ACE'],
        ['H', '3HH3','1','ACE'],
        ['N', 'N'   ,'2','ALA'],
        ['C', 'CA'  ,'2','ALA'],
        ['C', 'CB'  ,'2','ALA'],
        ['C', 'C'   ,'2','ALA'],
        ['O', 'O'   ,'2','ALA'],
        ['H', '1HB' ,'2','ALA'],
        ['H', '2HB' ,'2','ALA'],
        ['H', '3HB' ,'2','ALA'],
        ['H', 'H'   ,'2','ALA'],
        ['H', 'HA'  ,'2','ALA'],
        ['N', 'N'   ,'3','NME'],
        ['C', 'CH3' ,'3','NME'],
        ['H', '1HH3','3','NME'],
        ['H', '2HH3','3','NME'],
        ['H', '3HH3','3','NME'],
        ['H', 'H'   ,'3','NME'],
        ]

    coords = [
        [  -1.862, -11.290,  18.059],
        [  -0.948, -10.106,  18.286],
        [  -1.142,  -9.030,  17.704],
        [  -1.851, -11.572,  17.015],
        [  -1.532, -12.131,  18.651],
        [  -2.873, -11.038,  18.343],
        [   0.186, -10.234,  19.211],
        [   0.862,  -8.940,  19.211],
        [   0.354,  -8.148,  20.428],
        [   2.362,  -9.114,  19.211],
        [   2.929,  -9.926,  19.953],
        [  -0.742,  -7.998,  20.392],
        [   0.578,  -8.662,  21.383],
        [   0.810,  -7.143,  20.485],
        [   0.696, -11.147,  18.941],
        [   0.594,  -8.401,  18.283],
        [   3.174,  -8.292,  18.302],
        [   4.560,  -8.671,  18.519],
        [   4.679,  -9.084,  19.509],
        [   4.859,  -9.412,  17.791],
        [   5.199,  -7.806,  18.421],
        [   2.880,  -7.315,  18.440],
        ]
    
    bonds = [
        [0,1,1],
        [0,3,1],
        [0,4,1],
        [0,5,1],
        [1,2,2],
        [6,1,1],
        [6,7,1],
        [6,14,1],
        [7,8,1],
        [7,9,1],
        [7,15,1],
        [9,10,2],
        [9,16,1],
        [11,8,1],
        [12,8,1],
        [13,8,1],
        [16,17,1],
        [16,21,1],
        [17,18,1],
        [17,19,1],
        [17,20,1],
        ]

    model = Indexed()
    
    # append the atoms onto it 
   
    for a in atoms:
        new_atom = Atom()
        new_atom.symbol = a[0]     # elemental symbol
        new_atom.name = a[1]       # atom name
        new_atom.resi = a[2]       # residue identifier
        new_atom.resn = a[3]       # residue name
        model.atom.append(new_atom)
        # (note that there are a bunch of other fields we're not using -- and none are required)
        
        # add coordinates onto the atoms

    for a in model.atom: # now assign coordinates
        a.coord = coords.pop(0)
        
      # now specify the bonds
         
    for a in bonds:
        new_bond = Bond()
        new_bond.index = [a[0],a[1]]  # atom indices (zero-based)
        new_bond.order = a[2]         # bond order
        model.bond.append(new_bond)
      
    return model


class DummyMolNode(Node):

    def __init__(self, name):
        Node.__init__(self,name)
        self.create_output_port("output","-", "-")

    def execute(self):
        Node.execute(self)
        paramlist = self.getParameters()
        paramnum = 0
        try:
            for param in paramlist:
                param = [makeModel()]
                self.outPorts[paramnum].setData(Data("variable",param))
                paramnum =+ 1
        except ImportError, e:
            self._postEvent("EXCEPTION",
                            "The DummyMol node needs PyMol installed to run.")
            self.clean()
            return
    
    def create_output_port(self, variableName, validType, description,options="NA"):
        """Automagically adds a parameter object for each """
        ports = len(self.getOutputPorts())
        port = Node.create_output_port(self, variableName, validType, description)
        if ports != len(self.getOutputPorts()):
            number = str(len(self.getParameters()))
            self.create_parameter("Output nr " + str(number), "Integer",
                                  "Value of Output " + str(number),default = 1)
        return port


