# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from System.Data import Node

from qt import Qt, QWidget, QVBoxLayout, QTextEdit, QSize

class FileDumpNode(Node.Node):
    """
    Node that reads the contents of the file given by the paramater and dumps it
    to a window, similar to the screendump node."""
    
    def __init__(self, name):
        Node.Node.__init__(self,name)
        self.description = ("Dumps the contents of a file to a window. " +
                            "Specify the filename with the parameter.")
        # self.dumpWindow = None
        self.app = None

        # Dirty GUI stuff, must be placed here in constructor
        # to avoid windows crash.
                
        self.dumpWindow = QWidget(None)
        
        self.dumpWindow.setName("ScreendumpWidget")
        self.dumpWindow.setCaption("File dump results")
        
        self.layout = QVBoxLayout(self.dumpWindow, 11, 6)
        self.te = QTextEdit(self.dumpWindow, "textEdit")
        self.te.setReadOnly(1)
        self.layout.addWidget(self.te)
                
        self.dumpWindow.resize(QSize(250,450))
        self.dumpWindow.hide()

        self.create_parameter("File name", "String", "The file to dump to screen")


    def execute(self):
        """
        Executes the node. Currently this method contains
        a dirty, dirty hack to get screendump results
        displayed in a Qt widget instead of to the console.
        This method has to be radically altered in other words.
        """
        
        self.te.clear()

        params = self.getParameters()

        if len(params) < 1:
            Node.Node.execute(self)
            return

        # Should only be one parameter
        try:
            filename = str(params[0].getValue())

            fileReader = open(filename, 'r')
            content = fileReader.read()

            self.te.append("------ Contents of file \'" + filename + "\' ------")
            self.te.append(str(content))
            self.te.append("\n------")
            
            self.dumpWindow.show()

        except IOError, e:
            print "File error: ", e

        except TypeError, er:
            print "Parameter error, not a String? ", er
            
        Node.Node.execute(self)


