# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from System.Data import Data
from System.Data.Node import Node

class SpreadSheetNode(Node):
    def __init__( self, name ):
        Node.__init__(self, name)
        # backward compatibility 
        self._old_input_port_name = 'matrix'
        self._old_vector_input_port_name = 'input vectors'
        # Add a multi input port to make it possible to assign an arbitrary
        # number of vectors as input.
        self._multi_input = self.create_multi_input_port('matrices')
        
    def get_input_data(self):
        data_objects = []
        input_ports = self._multi_input.get_emulated_input_ports()

        # for backward compatibility: add possible 'matrix' input port
        old_input = self.getInputPortByName(self._old_input_port_name)
        if old_input:
            input_ports.append(old_input)

        # for backward compatibility: add possible 'input vectors' input port
        old_input = None
        for multi_input in self.get_multi_input_ports():
            if multi_input.get_name() == self._old_vector_input_port_name:
                old_input = multi_input

        if old_input:
            input_ports.extend(old_input.get_emulated_input_ports())

        for port in input_ports:
            data = port.getData()
            if data is not None:
                data_objects.append(data)

        return data_objects
    
    def execute(self):
        Node.execute(self)
