# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

class Counter:
    """A simple counter, providing incrementing numbers."""
    def __init__(self):
        """Create a new counter with an optional start value.

        The counter will return 1 as first value from get_next_value.
        """
        self._value = 1

    def get_next_value(self):
        """Get a new value from the counter and increment it."""
        value = self._value
        self._value += 1
        return value

    def set_next_value(self, value):
        """Set start value of counter.

        Next value returned from get_next_value will be the same as
        the set value.
        """
        self._value = value

    def ensure_higher_than(self, value):
        """Make sure next value is atleast higher than value.

        Will not modify counter if value is lower then the next value
        would have been without this call.
        """
        if value >= self._value:
            self._value = value + 1
