#-*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from sys import maxint
from string import strip
import Numeric

# These functions checks if a number is odd or even
odd = lambda x:bool(x % 2)
even = lambda x:not bool(x % 2)

# Checks if something is a string or not. This is the recommended way.
is_string = lambda x:isinstance(x, (str, unicode))

def create_indexed_list(count, prefix=""):
    """Create count indexed string values, optionally with prefix.

    create_indexed_list(3) => ["1", "2", "3"]
    create_indexed_list(2, "Object ") => ["Object 1", "Object 2"]
    """
    return [prefix + str(num) for num in xrange(1, count + 1)]

def get_dim(something=[], check_element_nr=1):
    """Returns the dimensions of the given data.
       If check_element_nr is 1 (or True), it's the "mathematical" version.
       If check_element_nr is 0 (or False), it's the functional "repr" version.
    """
    for dim in xrange(maxint):
        try:
            # Try to go a step deeper every round
            if is_string(something):
                break
            something = something[check_element_nr]
        except Exception:
            break
    return dim

def get_repr_dim(list=[]):
    """Returns the dimensions of a list- or array-structure.
       The functional "repr" version.
    """
    return get_dim(list, 0)

def get_cols(list=[]):
    """Returns the number of columns in a matrix.
        Columns are one step deeper than rows.
    """
    if get_repr_dim(list) == 1:
        return len(list)
    else:
        try:
            return len(list[0]) 
        except IndexError:
            return 0
        except TypeError:
            return -1
        except KeyError:
            return -1

def get_rows(list=[]):
    """Returns the number of rows in a matrix.
        Rows are one step shallower than columns.
    """
    if get_repr_dim(list) == 1:
        return 1
    else:
        try:
            return len(list)
        except TypeError:
            return -1

def describe_variable(variable):
    """Describe a scalar, string, or list or multidimensional matrix.

    describe_variable(5) => "scalar"
    describe_variable("hi") => "String"
    describe_variable([1,2,3]) => "1x3"
    describe_variable(["hi", "hello"]) => "2xString"
    """

    sizes = []

    try:
        while True:
            if is_string(variable):
                sizes.append("String")
                break
            sizes.append(len(variable))
            variable = variable[0]
    except TypeError:
        if len(sizes) == 1:
            sizes.insert(0, 1)
    except IndexError:
        sizes.insert(0, 0)

    if sizes:
        return "x".join(map(str, sizes))
    else:
        return "Scalar"

def filter_list(list_, remove_list):
    """Removes elements in remove_list from list and returns
        this filtered list.
    """
    return [item for item in list_ if item not in remove_list]


def remove_duplicates(list_):
    for x in list_:
        while list_.count(x) != 1:
            list_.remove(x) #list.remove() only removes one of the duplicated items
    

def merge_lists(list1, list2):
    """Merges two lists and removes duplicates"""
    list1.extend(list2)
    remove_duplicates(list1)

def count_dulicates(list1, list2):
    """Counts the number of ojects that can be found in both lists"""
    count = 0
    for x in list1:
        count += list2.count(x)

    return count
        
def to_string(list_):
    return str(list_).replace('\'','')

def try_number_coerce(text):
    """Try to change text into number, or return text."""
    """ 
    if "." in text:
        try:
            return float(text)
        else:
            return text
    """
    try:
        return int(text)
    except:
        try:
            return float(text)
        except:
            return text

def try_strip(text_or_number):
    """Strip whitespace from text, or return unmodified."""
    try:
        return strip(text_or_number)
    except:
        return text_or_number

def flatten(nested_list):
    """Creates a list of atoms from a structured/nested list."""
    result = []
    for element in nested_list:
        try:
            result.extend(flatten(element))
        except TypeError:
            try:
                result.extend(element)
            except:
                result.append(element)

    return result

def to_tuple(data):
    """Converts list and Numeric.array to tuple"""
    if type(data) == Numeric.ArrayType: 
        return to_tuple(data.tolist())
    elif not isinstance(data, list):
        return data     
    for k in range(len(data)): 
        if isinstance(data[k], list): 
            data[k] = to_tuple(data[k])

    return tuple(data)
    
def count_interval(list_, bottom, top):
    """Counts the number of elements with value between bottom and top.

    This function will alther the list.
    """

    result = 0
    for element in list_[:]:
        if element >= bottom and element <= top:            
            result += 1
            if len(list_) > 0 and type(list_) == Numeric.ArrayType:                
                temp = list_.tolist()
                temp.remove(element)
                list_ = Numeric.array(temp)
            else:
                list_.remove(element)
    return result


def instance_filter(instance_list, instance_type):
    """Return only elements in instance_list of type instance_type."""
    return filter(lambda item: isinstance(item, instance_type), instance_list)
