# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from Vector3D import Vector3D

class Point3D(list):
    def __init__(self, initialValue=(0,0,0)):
        list.__init__(self)
        """Create a new Point3D from an existing point or a 3D coordinate tuple."""
        self.extend(initialValue[0:3])
        if len(initialValue) >= 4 and abs(initialValue[3]) > 0.0:
            self.append(initialValue[3]) # homogenous coordinate position
        else:
            self.append(1)

    def vectorToPoint(self, point):
        """Returns vector from self to point."""
        return Vector3D((point[0] - self[0],
                         point[1] - self[1],
                         point[2] - self[2]))

    def distanceTo(self, point):
        """Returns absolute distance from self to point."""
        return self.vectorToPoint(point).length()

    def rotateAboutAxis(self, axis, angle):
        """Rotate angle radians about axis."""
        vector = Vector3D(self)
        vector.rotateAboutAxis(axis, angle)
        self[0:3] = vector[0:3]

    def rotateAboutFreeAxis(self, axis, point, angle):
        """Rotate angle radians about axis with origin at point."""
        self.subtract(point)
        self.rotateAboutAxis(axis, angle)
        self.add(point)

    def add(self, position):
        for i in range(3):
            self[i] += position[i]

    def subtract(self, position):
        for i in range(3):
            self[i] -= position[i]
