#-*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

import types
import Numeric
from Library.Util.rtester import RTester, RInstallError

def is_nan(arg):
        try:
            RTester.r_install_test()
            import rpy
            # Look at behaviour of OctaveFileReader when encountering nan-values
            if isinstance(arg,types.NoneType):
                return True 
            elif isinstance(arg, (float, int, long)):
                return rpy.r.is_na(arg)
            elif isinstance(arg,list):
                return rpy.r.is_na(arg)
            elif isinstance(arg,tuple):
                return rpy.r.is_na(arg)
	    # we can assume that Numeric arrays don't have NaN
	    elif isinstance(arg, Numeric.ArrayType):
		return Numeric.zeros(len(arg))
            else:
                return -1
        except RInstallError, e:
            return -2

def find_invalid_indices(xind,yind):
    indices = xind + yind
    indices.sort()
    last_idx = None
    new_indices = []
    for i in range(len(indices)):
        if last_idx != indices[i][0]:
            new_indices.append(indices[i][0])
            last_idx = indices[i][0]
    return new_indices

def remove_nan_entries_by_indices(x,y,indices):
    ind = indices[:]
    ind.reverse()
    for i in range(len(indices)):
        x.pop(ind[i])
	y.pop(ind[i])

def remove_nans_by_indices(indices,x):
    ind = indices[:]
    ind.reverse()
    for i in range(len(indices)):
	    x.pop(ind[i])

def _ensure_list(value):
    if isinstance(value, (list, Numeric.ArrayType)):
        return value
    else:
        return [value]
    
def find_all_nan_indices(xlist,ylist=None):
	xnan = is_nan(xlist)
		
	if ylist:
		ynan = is_nan(ylist)
		return _ensure_list(xnan), _ensure_list(ynan)
	return _ensure_list(xnan)

def extract_unique_nan_indices(xind,yind=None):
	if yind:
		indices = xind + yind
	else:
		indices = xind
	indices.sort()
	last_idx = None
	nan_indices = []
	for i in range(len(indices)):
		if last_idx != indices[i][0]:
			nan_indices.append(indices[i][0])
			last_idx = indices[i][0]
	return nan_indices
    

def find_unique_nan_indices(xnans,x_values,ynans=None,y_values=None):
	xind = filter(lambda (i, value) : xnans[i], enumerate(x_values))
	yind=None
	if y_values and ynans:
		yind = filter(lambda (i, value) :   ynans[i],
			      enumerate(y_values))
	nan_indices = extract_unique_nan_indices(xind,yind)
	return nan_indices

def define_nan():
	try:
		RTester.r_install_test()
		import rpy
		nan = rpy.r('1/0 - 1/0')
        except RInstallError, e:
		nan = 1e400 - 1e400
	return nan

