#-*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

import re
import os

class RInstallError(Exception):
    """Exection used when R is not properly installed"""
    pass

class RTester:
  
    r_installed = False
    r_tested = False
    # Matches version strings with one or two dots, containing only digits.
    reR_VERSION_STRING = re.compile("R [0-9]+\.[0-9]+(\.[0-9]*)?")

    def r_install_test():
        """This method tests if R is installed."""

        error_msg = ''
        if os.name == 'nt':
            error_msg = 'Loading the R library failed. R is not installed or not registered in ' +\
                  'the registry. Please consult the SciCraft documentation on how to install R correctly.'
        else:
            error_msg = 'R does not seem to be installed. ' +\
                  'R is required for this feature to work.'

        if not RTester.r_tested:
            if os.name == 'nt':
                # need to use popen3 here since R on Windows will only write to stderr
                (stdin, stdout, stderr) = os.popen3("RTerm --version")
                output = stderr.read()
            else:
                
                output = os.popen("R --version 2>&1").read()

            if RTester.reR_VERSION_STRING.match(output):
                if os.name == 'nt':
                    # need to also check for reg key
                    import _winreg as wreg
                    try:
                        key = wreg.OpenKey(wreg.HKEY_LOCAL_MACHINE, "SOFTWARE\\R-core\\R")
                        path = wreg.QueryValueEx(key, "InstallPath")[0]
                        RTester.r_installed = True
                    except WindowsError, e: # R is not installed properly
                        print e
                else:
                    RTester.r_installed = True

        RTester.r_tested = True
        if not RTester.r_installed:
            raise RInstallError, error_msg

        return RTester.r_installed


    r_install_test = staticmethod(r_install_test)
