# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.
import unittest
import time

from qt import QApplication, QTimer

class QtTestCase(unittest.TestCase):
    """TestCase initializing and ending Qt before/after each test."""
    def __call__(self, result=None):
        qApp = QApplication([])

        try:
            return_value = unittest.TestCase.__call__(self, result)
        finally:
            QTimer.singleShot(0, qApp.quit)
            qApp.exec_loop()
            del qApp
            
        return return_value

class _TimingTextTestResult(unittest._TextTestResult):
    def __init__(self, *args):
        unittest._TextTestResult.__init__(self, *args)
        self._start_times = {}
        self.run_times = {}

    def startTest(self, test):
        self._start_times[test] = time.time()
        unittest._TextTestResult.startTest(self, test)

    def stopTest(self, test):
        self.run_times[test] = time.time() - self._start_times[test]


class TimingTextTestRunner(unittest.TextTestRunner):
    def _makeResult(self):
        return _TimingTextTestResult(self.stream, self.descriptions,
                                     self.verbosity)
        
    def run(self, test):
        def swap(pair):
            return (pair[1], pair[0])
        
        result = unittest.TextTestRunner.run(self, test)
        if result.wasSuccessful():
            sorted_list = map(swap, result.run_times.items())
            sorted_list.sort()
            self.stream.writeln("Runtimes:")
            for time, t in sorted_list:
                self.stream.writeln("%.3fs %s" % (time, t))
        return result
            
