# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from Library.Nodes.Plot.develplotnode import UserPlot
from Library.Nodes.Plot.component import PointsComponent, ImageComponent
from Library.Util.Config import Config
from Library.Util import colormap
from Library.Util.rtester import RTester, RInstallError

import Numeric
import os

class UserDensity(UserPlot):
    name = "Density Plot"
    
    def __init__(self):
        UserPlot.__init__(self)
        self.add_port_input('x_source', 'X data:')
        self.add_port_input('y_source', 'Y data:')
        self.add_integer_input('x_index', 'X Index:', 1, 1)
        self.add_integer_input('y_index', 'Y Index:', 1, 1)
        self.add_list_input('x_transpose', 'Orientation:', ['row', 'column'], [False, True])
        self.add_list_input('y_transpose', 'Orientation:', ['row', 'column'], [False, True])

        self.add_list_input('resolution', 'Resolution',
                            ['8', '16', '32',
                             '64', '128', '256',
                             '512', '1024'],
                            [8, 16, 32,
                             64, 128, 256,
                             512, 1024])

        self.add_integer_input('x_smooth', 'X Smoothing', 1, 10000)
        self.add_integer_input('y_smooth', 'Y Smoothing', 1, 10000)

        colormaps = colormap.look_up_available_colormaps()
        self.add_list_input("color_map", "Color Map:", colormaps, colormaps)

        self.set_use_floating_scale()
        self.set_user_interface('userdensity.ui')
        
    def input_changed(self, ident):
        if ident == 'x_source':
            matrix = self.get_value('x_source')
            if matrix != None:
                self.update_integer_input('x_index', 1, len(matrix))
            else:
                self.update_integer_input('x_index', 1, 1)
        if ident == 'y_source':
            matrix = self.get_value('y_source')
            if matrix != None:
                self.update_integer_input('y_index', 1, len(matrix))
            else:
                self.update_integer_input('y_index', 1, 1)
        
        self.replot()

    def get_components(self):
        x_matrix = self.get_value('x_source')
        y_matrix = self.get_value('y_source')

        if not x_matrix or not y_matrix:
            return []

        if self.get_value("x_transpose"):
            x_matrix = Numeric.transpose(x_matrix)
        if self.get_value("y_transpose"):
            y_matrix = Numeric.transpose(y_matrix)

        length = min(len(x_matrix[0]), len(y_matrix[0]))

        x_data= x_matrix[self.get_value("x_index")-1][:length]
        y_data =  y_matrix[self.get_value("y_index")-1][:length]
        
        try:
            RTester.r_install_test()
            import rpy
            rpy.r('library(MASS)')

            x_bandwidth = rpy.r.bandwidth_nrd(x_data)*(self.get_value('x_smooth')/100.)
            y_bandwidth = rpy.r.bandwidth_nrd(y_data)*(self.get_value('y_smooth')/100.)
            bandwidths = (y_bandwidth, x_bandwidth)
            resolution = self.get_value('resolution')

            # x and y is swapped to make the result correspond with the input data
            count_matrix = rpy.r.kde2d(y_data, x_data,
                                       h=bandwidths,
                                       n=resolution)['z']
        except RInstallError, e:
            return []

        matrix = Numeric.sqrt(count_matrix)            
        image_matrix = matrix[::-1]

        selected_color_map = colormap.get_color_maps()[self.get_value('color_map')]
        area = (min(x_data), max(x_data), max(y_data), min(y_data))

        image_component = ImageComponent(image_matrix, 
                                         image_area=area,
                                         color_map=selected_color_map)
        points_component = PointsComponent(x_data, y_data)


        image_component.set_selection_disabled(True)
        points_component.set_draw_only_selected(True)


        return [image_component, points_component]
        
