# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from Library.Nodes.Plot.develplotnode import UserPlot
from Library.Nodes.Plot.component import ImageComponent
from Library.Nodes.Plot.choice import BooleanChoice
from Library.Util import colormap


class UserImage(UserPlot):
    name = "Image Plot"
    
    def __init__(self):
        UserPlot.__init__(self)
        self.add_port_input('image_source', "Image source:")
        colormaps = colormap.look_up_available_colormaps()
        self.add_list_input("color_source", "Color Map:", colormaps, colormaps)
        self.set_user_interface("userimage.ui")
        self.set_should_reverse_y()
        self.add_input(BooleanChoice("flip_y", "Reverse Y-axis?", True))
        self.set_use_floating_scale()

    def input_changed(self, ident):
        if ident == "flip_y":
            self.set_should_reverse_y(self.get_value("flip_y"))
        self.replot()

    def get_components(self):
        matrix = self.get_value('image_source')

        if not matrix:
            return []

        selected_color_map = colormap.get_color_maps()[self.get_value('color_source')]
        
        return [ImageComponent(matrix, color_map = selected_color_map)]
        
