# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from Library.Nodes.Plot.develplotnode import UserPlot
from Library.Nodes.Plot.component import PointsComponent
from Library.Util.Config import Config

import Numeric
import os

class UserScatter(UserPlot):
    name = "Scatter Plot"
    
    def __init__(self):
        UserPlot.__init__(self)
        self.add_port_input('xport', "X Source:")
        self.add_integer_input('x', "X Index:", 1, 1)
        self.add_list_input('xtranspose', "Orientation:", ["row", "column"], [False, True])
        self.add_port_input('yport', "Y Source:")
        self.add_integer_input('y', "Y Index:", 1, 1)
        self.add_list_input('ytranspose', "Orientation:", ["row", "column"], [False, True])
        self.set_user_interface("userscatter.ui")

    def input_changed(self, ident):
        if ident == "xport":
            matrix = self.get_value("xport")
            if matrix != None:
                self.update_integer_input("x", 1, len(matrix))
            else:
                self.update_integer_input('x', 1, 1)

        if ident == "yport":
            matrix = self.get_value("yport")
            if matrix != None:
                self.update_integer_input("y", 1, len(matrix))
            else:
                self.update_integer_input('y', 1, 1)

            
        self.replot()

    def get_components(self):
        xmatrix = self.get_value("xport")
        ymatrix = self.get_value("yport")
        if not xmatrix or not ymatrix:
            return []

        if self.get_value("xtranspose"):
            xmatrix = Numeric.transpose(xmatrix)
        if self.get_value("ytranspose"):
            ymatrix = Numeric.transpose(ymatrix)

        length = min(len(xmatrix[0]), len(ymatrix[0]))

        x_values = xmatrix[self.get_value("x")-1][:length]
        y_values = ymatrix[self.get_value("y")-1][:length]

        component = PointsComponent(x_values, y_values)
        component.set_color(64, 64, 64)
        component.set_tooltip_texts(["%d (%s, %s)" % (i+1, x_values[i], y_values[i]) for i in range(len(x_values))])

        return [component]
