# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.


class Category:

    def __init__(self,name):
        """Category objects will be used by GUIs to display the nodes in a tree-structure"""
        #the contents of the category, filebasenames -> dotted filebasenames
        self.contentList = {}
        #a list of this category's sub-categories
        self.subcategoryList = []
        self.name = name

    def addSubcategory(self,category):
        """
        Params:
               - category : Category - a subcategory to be appended to the subcategory-list
               """
        
        self.subcategoryList.append(category)

    def getSubcategories(self):
        """
        Returns:
                - List[Category] - A list containing all the sub-categories of this object
                """
        
        return self.subcategoryList

    def addContent(self,content,path):
        """
        Params:
               - content : String - A short name of the node in this category
               - path    : String - A log name (dotted name: Function.Octave.pca) of the node to be inserted
        Adds a file name to the contentList       """
        
        self.contentList[content] = path

    def getContents(self):
        """
        Return:
               - Dictionary[String : String] - Dictionary containing the short names and long names of the contents
               """
        return self.contentList
