# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

import os

from System.Data.Data import data_info


class FileReader:
    
    supportedFileExtensions = []
    description = ""        
    fileDescription = ""
    variable_name_support = False
    name = "Unknown"
        
    
    def __init__(self):
        pass
        
    def read_data(self, source_path):
        raise NotImplementedError, "Method must be implemented!"
    
    def get_variable_info(self, filename, variable_name=None, node = None):

        variable_info = {}

        if node:
            filename = self.convert_to_absolute_filepath(filename, node.get_module_diagram().getFilename())
        
        data_sets = {}
        for data in self.read_data(filename):
            data_sets[data.getName()] = data.getData()        

        
        if variable_name:
            if data_sets.has_key(variable_name):
                return data_info(data_sets[variable_name])
            else:
                return ""
        
        for name, data in data_sets.items():
            variable_info[name] = data_info(data)
            
        return variable_info

    def get_default_output_ports(self):
        return ()
    
    
    def get_description(self):
        return self.description


    def get_filetype(self):
        return self.fileDescription
    

    def convert_to_absolute_filepath(self, file_path, diagram_file_name):
        """This method returns an absolute filepath to a file relative
        to the module diagram. If the filepath is all ready absolute
        it returns the filepath given
        """
        
        if not os.path.isabs(file_path):

            if diagram_file_name:
                # treat as relative to modulediagram
                diagram_path = os.path.dirname(diagram_file_name)
                abs_path = os.path.join(diagram_path, file_path)
            else:
                # treat as relative to current working directory
                abs_path = os.path.join(os.getcwd(), file_path)
            return abs_path

        return file_path
