# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

import re
from System.Data.Data import Data
from System.FileHandlers.Input.FileReader import FileReader


class GaussDalFileReader(FileReader):
    
    supportedFileExtensions = ["gaussdal"]
    description = "GaussDal file format"        
    fileDescription = "GaussDal"
    variable_name_support = True
    name = "GaussDalFileReader"
        
    
    def __init__(self):
        FileReader.__init__(self)
        self.gauss_format = re.compile("[a-zA-Z0-9\s]+\|")
    
        
    def read_data(self, sourcePath):
        try:
            filereader = open(sourcePath)
            f = filereader.read()
            filereader.close()
        except IOError, e:
            print "SoftError. File %s not found" % sourcePath
            return
        if not re.match(self.gauss_format, f):
            return ""
        

        split = f.split("\n")
            
        columnnames = (split[0]).split("|")
        it = 0
        for element in columnnames:
            columnnames[it] = element.strip()
            it +=1
        data = split[2:]
        data_it = 0
        del_list = []
        for row in data:
                
            row = row.split("|")
            it = 0
            for element in row:
                element = element.strip()
                #parse to int and float data
                try:
                    element = int(element)
                except:
                    try:
                        element = float(element)
                    except:
                        pass
                row[it] = element
                it += 1
            if data[data_it] == '':
                del_list.append(data[data_it])
            elif data[data_it].startswith("(") and (data[data_it].endswith("rows)")or data[data_it].endswith("row)")):
                del_list.append(data[data_it])
            else:
                data[data_it] = row           
            data[data_it] = row
            data_it += 1
        for i in del_list:
            data.remove([i])
        return ([Data("Data", data), Data("Colnames",columnnames)])
        
    def get_variable_info(self, sourcePath, variable_name = None):
        data_array = self.read_data(sourcePath)
        variable_info = {}
        dim = ""        

        data = data_array[0].getData()
        dim_len = len(data)
        dim_width = len(data[0])
        variable_info[data_array[0].getName()] = str(dim_len)+" * "+str(dim_width)
         
        colnames = data_array[1].getData()
        variable_info[data_array[1].getName()] = str(len(colnames[0]))
         
        if variable_name:
            if variable_info.has_key(variable_name):
                return variable_info[variable_name]
            else:
                return ""
        else:
            return variable_info

