# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

import os
import string

from System.Data.MoleculeData import MoleculeData
from System.FileHandlers.Input.FileReader import FileReader

#hack for redhat-installed pymol
import sys
import os.path
for path in sys.path:
    combopath = os.path.join(path, 'pymol/modules')
    if os.path.exists(combopath):
        if sys.path.count(combopath) == 0:
            sys.path.append(combopath)

import string


class MissingPymolError(Exception):
    def __init__(self):
        Exception.__init__(self, "MoleculeFileReader needs PyMol installed to run. Aborting.")
        

class MoleculeFileReader(FileReader):
    """This class is able to read molecule data in different formats from a file"""
    
    supportedFileExtensions = ["pkl", "pdb"]
    description = "Molecule file formats (pk1, pdb)."
    fileDescription = "Molecule"
    name = "MoleculeFileReader"
    
    def __init__(self):
        """Constructor for creating an MoleculeFileReader-object"""
        FileReader.__init__(self)
        self.port_name = "molecule"
        self.port_description = "One or more molecules."


    def get_default_output_ports(self):
        """Let containing Node set up outputports useful for this reader."""
        return ((self.port_name, "", self.port_description),)
    
    
    def read_data(self, sourcePath):
        """
           Params:
                  - sourcePath : string - path to the file that will be read
           Return:
                  - List[Data] - Returnes a List with Data-objects

           Function which will read a file with molecule data. 
        """
        # imported here to delay exception in case of missing module
        try:
            import chempy
        except ImportError:
            raise MissingPymolError()
        
        from chempy import feedback
        from chempy.pkl import PKL
        from chempy.pdb import PDB
        from Library.Util.molecular import Fragment, ConnPDB

        oldFeedback = feedback['io']
        feedback['io'] = 0
                
        loaders = {'pdb' : ConnPDB, 'pkl' : PKL}

        dataArray = [] #array for holding the dataobjects
        try:
            loader = loaders[sourcePath.split('.')[-1].lower()]()
            model = loader.fromFile(sourcePath)
            if isinstance(model, Fragment):
                model = model.getModel()
            molArray = [model]
            dataArray.append(MoleculeData("molecule", molArray))
        except KeyError, e:
            pass
            #print "KeyError:", e
            
        feedback['io'] = oldFeedback
        return dataArray


    def get_variable_info(self, filename, variable_name = None, node = None):
        variable_info = {}
        variable_info[self.port_name] = "molecule"


        if variable_name:
            if variable_info.has_key(variable_name):
                return variable_info[variable_name]
            else:
                return ""
        else:
            return variable_info
            
            
