# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from Library.Util.rpyclient import rpy_silent_eval, rpy_eval, rpy_gc
from System.Data.Data import RData
from System.FileHandlers.Input.FileReader import FileReader


class RFileReader(FileReader):
    """This class is responsible for reading R-files. It inherits its methods from
        FileReader, but overwrites all methods."""

    supportedFileExtensions = ["RData"]
    variable_name_support = True
    description = "GNU R file format."
    fileDescription = "R"
    name = "RFileReader"
        
    def __init__(self):
        """Constructor for creating an RFileWriter-object"""
        FileReader.__init__(self)

    def read_data(self, file_path):

        file_path = file_path.replace('\\', '/')
        names = rpy_eval("load('%s')" % file_path)
        if not isinstance(names, list):
            # 'names' wont be a list if the file contains
            # only one variable
            names = [names]

        data_set = []
        for name in names:
            data = RData(name)
            rpy_silent_eval("%s <- %s" %(data.get_pointer(), name))
            rpy_silent_eval("rm(%s)" % name)
            data_set.append(data)

        rpy_gc()

        return data_set
        
