# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from System.FileHandlers.Input.FileReader import FileReader
from System.Data.Data import Data
from Library.Util.experiment import Scan

import cPickle

class ExperimentFileReader(FileReader):
    name = "ExperimentFileReader"
    supportedFileExtensions = ["exp"]
    fileDescription = "Experiment"
    variable_name_support = False
    description = "SciCraft MA experiment format"
    
    def get_default_output_ports(self):
        return (("laser", "", ""),
                ("pmt", "", ""),
                ("from_bio_matter", "", ""),
                ("to_bio_matter", "", ""),
                ("bio_replica", "", ""),
                ("hybridization", "", ""),
                ("filename", "", ""),
                ("raw_data_file_name", "", ""),
                ("physical_array", "", ""),
                ("dye_swapped", "", ""))

    def read_data(self, path):
        import string
        data = "\n".join(map(string.rstrip, open(path).read().splitlines()))
        experiment = cPickle.loads(data)

        laser_settings = []
        pmt_settings = []
        from_bio_matter = []
        to_bio_matter = []
        bio_replicas = []
        hybridizations = []
        physical_arrays = []
        scan_names = []
        filenames = []
        dye_swapped = []

        scan_strings = {Scan.NOT_SET : "not set",
                        Scan.LOW : "low",
                        Scan.MEDIUM : "medium",
                        Scan.HIGH : "high"}
        
        for comparison in experiment.get_comparisons():
            from_bio, to_bio = comparison.get_bio_materials()
            for replica in comparison.get_bio_replicas():
                for array in replica.get_micro_arrays():
                    for scan in array.get_scans():
                        laser_settings.append(scan_strings[scan.get_laser()])
                        pmt_settings.append(scan_strings[scan.get_pmt()])
                        if not array.is_dye_swapped():
                            from_bio_matter.append(from_bio.get_name())
                            to_bio_matter.append(to_bio.get_name())
                            dye_swapped.append("No")
                        else:
                            from_bio_matter.append(to_bio.get_name())
                            to_bio_matter.append(from_bio.get_name())
                            dye_swapped.append("Yes")
                        bio_replicas.append(replica.get_name())
                        hybridizations.append(array.get_name())
                        physical_arrays.append(array.get_array_name())
                        scan_names.append(scan.get_name())
                        filenames.append(scan.get_filename())

        return (Data("laser", laser_settings),
                Data("pmt", pmt_settings),
                Data("from_bio_matter", from_bio_matter),
                Data("to_bio_matter", to_bio_matter),
                Data("bio_replica", bio_replicas),
                Data("hybridization", hybridizations),
                Data("filename", filenames),
                Data("physical_array", physical_arrays),
                Data("raw_data_file_name", scan_names),
                Data("dye_swapped", dye_swapped))
                        
