# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from System.FileHandlers.Input.FileReader import FileReader
from Library.Util.lists import try_number_coerce
from Library.Util import parsing
from System.Data.Data import Data
import os.path

# class containing all the surrounding stuff necessary for commincation with the the rest of SciCraft
class TextFileReader(FileReader):
    """This class is able to read data in ascii-format from a file"""

    name = "TextFileReader"
    supportedFileExtensions = ["txt","data"]
    description = "ASCII file format."
    variable_name_support = False
    fileDescription = "Textfile"

    def __init__(self):
        FileReader.__init__(self)
        self._var_name = "Data 1"

    # automatic/best guess reading of textfiles. 
    def read_data(self, file_path):
        self._var_name = os.path.basename(file_path)

        # Here, autodetection or something fancy could have been used.
        col_split = '\n'
        row_split = ' \t'      
 
        textfile = TextFileParser()
        # read dataset
        data = textfile.read(file_path)
        # split dataset
        data = textfile.split_(data,col_split,row_split)
     
        # One dimensional? (This is automatic, so assuming user doesn't want lists within lists)
        if len(data)==0:
            data = data[0]
        # are all elements of length 1?
        if len(data)==sum([len(item)==1 for item in data]):
            data = [item[0] for item in data]

        # Automatic check for headers
        col , row = textfile.check_headers(data)
        data, col_headings, row_headings = textfile.split_headers(data,col, row)
        
        # convert data
        parsing.convert(data)
     
        # create datalists
        datalist = [Data(self._var_name,data)]

        if col_headings:
            datalist.append(Data("Coloumn Headings",col_headings))
        if row_headings:
            datalist.append(Data("Row Headings",row_headings))
     
        return datalist

   
    # reads data using settings from TextFileSettings objects 
    def read_data_with_settings(self, file_path, settings):
        self._var_name = os.path.basename(file_path)

        # create instance for parsing    
        textfile = TextFileParser()

        # read dataset
        data = textfile.read(file_path)

        # remove lines
        if settings.lines_to_remove:
            # urg, spliting and joining is ugly
            data = "\n".join(data.split("\n")[settings.lines_to_remove:])
        
        row_sep, col_sep = settings.get_row_col_seps_as_chars()

        # split dataset, last True is wether fields should be attempted parsed into ints. 
        data = textfile.split_(data,col_sep, row_sep)
         
        data, col_headings, row_headings = textfile.split_headers(data,settings.use_col_headers, settings.use_row_headers)

        # parsing
        parsing.convert(data)
      
        # create datalists
        datalist = [Data(self._var_name,data)]

        if col_headings:
            datalist.append(Data("Coloumn Headings",col_headings))
        if row_headings:
            datalist.append(Data("Row Headings",row_headings))
         
        return datalist

                
# class for doing the actual parsing
class TextFileParser:

    def read(self,filename):
        self.filename = filename
        data = open(filename).read()

        if data.endswith("\n"):
            data = data[:-1]
        return data
             
    # splits and parses the dataset. Does not change types! 
    def split_(self,data,col_split,row_split):
        """ --  Prepare seperators  -- """
        col_sep, row_sep = None, None

        if col_split:
            col_sep = col_split[0]
            # merges seperators
            for sep in col_split[1:]:
                data = data.replace(sep,col_sep)
        
        if row_split:
            row_sep = row_split[0]         
            # again,  merge seperators
            for sep in row_split[1:]:
                data = data.replace(sep,row_sep)
 
        # -- split the lists -- 
        # split column
        if col_split:
            data = data.split(col_sep)
        else:
            # temporary change to avoid duplication/special cases
            data = [data] 

        if row_split:
            # split rows, ignore empty instances
            data =  [f.split(row_sep) for f in data if f]
       
            # remove empty instances created by this splitting:
            for x in xrange(len(data)):
                while '' in data[x]:
                    data[x].remove('')
       
        else:
            # no more splitting, we still have to room empty items from first split though
            [data.remove(item) for item in data if not item]

        # take back temporary change
        if not col_split:
            data = data[0]       
        
        return data

    def check_headers(self,data):
        coloumn, row = False, False        

        # take a little slice of the dataset to make it workable: (cutting all dimensions to size 5)
        data = [item[0:min(5,len(item))] for item in data[0:min(5,len(data))]]
        if parsing.isStringInstance(data[0]):
            data = [data]

        # if length is over 2 and all lists have atleast 2 items:
        if len(data)>1 and len(data)==sum([1 for item in data if len(item)>1]):

            # if set of first items contains a string, and the resto the dataset doesn't. Use headers. (first row isn't checked though, as these may be column headere)
            rowheader = [[item[0]] for item in data[1:5]]
            parsing.convert_doublelist(rowheader)
            rowdata   = [item[1:] for item in data[1:5]]
            parsing.convert_doublelist(rowdata)

            if parsing.isStringInstance(rowheader[0][0]) and parsing.isNumberInstance(rowdata[0][0]):
                row = True
        
        # if we have row headers and first line is shorter than the others, let's guess it's a header
        if row and len(data)>1 and len(data[0])+1==len(data[1]):
            coloumn = True
        elif len(data)>1:
            colheader = [data[0][1:]]
            coldata   = [item[1:] for item in data[1:]]
            parsing.convert_doublelist(colheader)
            parsing.convert_doublelist(coldata)

            if parsing.isStringInstance(colheader[0][0]) and parsing.isNumberInstance(coldata[0][0]):
                coloumn = True
        return coloumn, row

    def split_headers(self,data,col_split,row_split):
        cols, rows = None, None
        if col_split and len(data)>1:
            cols = data[0]
            data = data[1:]
        if row_split and isinstance(data[0],list):
            rows = [row[0] for row in data]
            data = [row[1:] for row in data]
        if row_split and col_split and len(cols)==len(data[0])+1:
            cols = cols[1:]

        return data, cols, rows
        
# Dataholder (with a few convience methods) for textfilesettings
class TextFileSettings:

    def __init__(self):
        self.automatic          = True
        self.row_separators     = ['Space','Tab']
        self.col_separators  = ['Newline']
        self.use_row_headers    = False  
        self.use_col_headers    = False
        self.lines_to_remove    = 0
    
        self._conversion = {'Space' : ' ',
                            'Newline' : '\n',
                            'Return' : '\n',
                            'Tab'   : '\t'}

    def getSettings(self):
        return {'automatic'      : self.automatic ,
                'row_separators' : self.row_separators,
                'col_separators' : self.col_separators,
                'row_headers'   : self.use_row_headers,
                'col_headers'   : self.use_col_headers,
                'lines_to_remove' : self.lines_to_remove}

    # updates settings, must be given a dictionary equal to getSettings()
    def set(self,automatic, row_seps, col_seps, row_headers, col_headers, lines_to_remove):
        self.automatic = bool(automatic)
        self.row_separators = list(row_seps)
        self.col_separators = list(col_seps)
        self.use_row_headers = bool(row_headers)
        self.use_col_headers = bool(col_headers)
        self.lines_to_remove = int(lines_to_remove)
    

    # Returns separators, only with readable names swapped with the actual chars as per self._conversion
    def get_row_col_seps_as_chars(self):
        row = list(self.row_separators)
        col = list(self.col_separators)

        # urg, least elegant method of switching ever!
        for key in self._conversion.keys():
            if key in row:
                row.remove(key)
                row.append(self._conversion[key])            
            if key in col:
                col.remove(key)
                col.append(self._conversion[key])

        return (row, col)
    

    def toXML(self):
        text = '\t<TextFileSettings automatic="'+str(self.automatic)+'">\n'
        text += '\t\t<remove lines="'+str(self.lines_to_remove)+'"/>\n'
        text += '\t\t<headers column="'+str(self.use_col_headers)+'" row="'+str(self.use_row_headers) +'"/>\n'

        text += '\t\t<separators>\n'
        text += '\t\t\t<row>'
        for sep in self.row_separators:
            text += '<i>'+str(sep)+'</i>'
        text += '</row>\n'
       
        text += '\t\t\t<column>'
        for sep in self.col_separators:
            text += '<i>'+str(sep)+'</i>'
        text += '</column>\n'
        text += '\t\t</separators>'

        text += '\t</TextFileSettings>'
        
        return text.split("\n")
        

    def from_xml_element(self,element):
        self.automatic       = parsing.isTrue(element.get("automatic"))
        self.lines_to_remove = parsing.toInt(element.find("remove").get("lines"),default=0)
        self.use_col_headers = parsing.isTrue(element.find("headers").get("column"))
        self.use_row_headers = parsing.isTrue(element.find("headers").get("row"))
        self.col_separators = [el.text for el in element.find("separators").find("row").findall("i")]
        self.row_separators = [el.text for el in element.find("separators").find("column").findall("i")]
                
                        
