# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from System.FileHandlers.Output.FileWriter import FileWriter
from System.Exceptions import ZPluginError

#hack for redhat-installed pymol
import sys
import os.path
for path in sys.path:
    combopath = os.path.join(path, 'pymol/modules')
    if os.path.exists(combopath):
        if sys.path.count(combopath) == 0:
            sys.path.append(combopath)

class MoleculeFileWriter(FileWriter):
    """This is class for writing Molecule-files to disk."""

    supportedFileExtensions = ["pkl", "pdb"]
    fileDescription = "Molecule"
    description = "Molecule file format."
    name = "MoleculeFileWriter"
    
    #def __init__(self, name="MoleculeFileWriter"):
    #    """Constructor for creating a MoleculeFileWriter-object."""
    #    FileWriter.__init__(self, name)

        
    def write_data(self, data, destinationPath):
        """
            Params:
                - data : List[Data] - A List with Data objects
                - destinationPath : String - A String with the path to write
                                             the data to

            Excption:
                - IOError - File can not be written

            A method that writes molecules to a file."""

        from chempy.pkl import PKL
        from chempy.pdb import PDB

        molecules = data[0].getData()
        mainMolecule = molecules[0]
        for m in molecules[1:]:
            mainMolecule.merge(m)

        savers = {'pdb' : PDB, 'pkl' : PKL}
        extension = destinationPath.split('.')[-1].lower()

        if extension in savers:
            saver = savers[extension]()
        else:
            destinationPath += '.pdb'
            saver = savers['pdb']()
            
        try:
            saver.toFile(mainMolecule, destinationPath)
        except IOError, e:
            print e
            raise ZPluginError.ZPluginError, "Could not open file for " +\
                "writing. Check path, permissions and free space."
