# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

from System.FileHandlers.Output.FileWriter import FileWriter
from System.Data.Data import RData

from Library.Util.rtester import RTester
from Library.Util.rpyclient import rpy_eval, rpy_silent_eval, rpy_gc

from threading import Lock
import time

_write_mutex = Lock()
        
class RFileWriter(FileWriter):
    supportedFileExtensions = ["RData"]
    fileDescription = "R"
    description = "GNU R file format."
    name = "RFileWriter"
    
        
    def write_data(self, data_set, file_path):
        _write_mutex.acquire()
        try:

            RTester.r_install_test()
            import rpy

            input_names = []

            file_path = file_path.replace("\\", "/")

            rpy_silent_eval("scwriterenv = new.env()")

            for data in data_set:
                if not isinstance(data, RData):
                    data = RData(data.getName(), data.getData())

                rpy_silent_eval('scwriterenv$%s <- %s' % (data.getName(), data.get_pointer()))
                input_names.append(data.getName())

            rpy_silent_eval("save(list=c('%s'), file='%s', envir=scwriterenv)" %("','".join(input_names),
                                                                                 file_path))

            # Remove environment
            rpy_silent_eval("rm(scwriterenv)")
            rpy_gc()
        finally:
            _write_mutex.release()
