# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.
  
from Library.Util.InterruptibleCommand import InterruptibleCommand

import os
import sys
import re

# domain exceptions
class PluginInterrupted(Exception):
    """Exception for the plugins to raise if they got interrupted"""
    pass

class Plugin:
    """Superclass for plugins."""

    def __init__(self): 
        self.lock = 0 # Mark if plugin is currently being used, or not.
        self.PLUGINDEBUG = 0
        
    def execute(self, function_name, script_name, input_ports, output_ports,
                parameters, interruptCallback):
        "Executes a function externally. Needs to be implemented by subclasses."
        raise NotImplementedError

    def getLockStatus(self):
        return self.lock 
    
    def setLocked(self):
        self.lock = 1

    def setUnlocked(self):
        self.lock = 0


    def clean(self):
        """Clean up mess after computation.

        Overridable by subclasses.
        """
        pass

    def get_stdout_from_last_run(self):
        """Returns what the plugin wrote to stdout during last run.

        All subclasses needs to implement this method.
        """
        raise NotImplementedError

    def get_stderr_from_last_run(self):
        """Returns what the plugin wrote to stderr during last run.

        All subclasses needs to implement this method.
        """
        raise NotImplementedError

def get_python_command():
    if os.name == 'nt':
        # 'SciCraft --magic' starts the python interpreter
        # this is really a HACK
        # the following example will match:
        #  sys.argv[0] = 'C:\Program Files\SciCraft\scicraft-0.7.0.exe'
        if re.search("scicraft.*\.exe", sys.argv[0]):
            cmd = InterruptibleCommand(sys.argv[0], "--magic")
        else:
            # assume that we're running from python and that
            # python.exe is in %path%
            cmd = InterruptibleCommand("python")
    else:
        cmd = InterruptibleCommand("python")
    return cmd

