# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

import re
import types

def arrayDims(array):
    if str(type(array)) != "<type 'array'>":
        raise TypeError, 'Needed \'array\', got %s' % str(type(array))
    return __arrayDims(array, 0)


def __arrayDims(array, dim):
    if str(type(array)) == "<type 'array'>" and len(array) > 0:
        dim = __arrayDims(array[0], dim + 1)
    return dim


def listDims(list):
    if type(list) is not types.ListType:
        raise TypeError, 'Needed \'list\', got %s' % str(type(list))
    return __listDims(list, 0)


def __listDims(list, dim):
    if type(list) is types.ListType and len(list) > 0:
        dim = __listDims(list[0], dim + 1)
    return dim


def stringToNumber(string):
    if type(string) is not types.StringType:
        #print string
        raise TypeError, "Expected string, got %s" % str(type(string))

    try:
        string = int(string)
        return string
    except OverflowError:
        try:
            string = long(string)
            return string
        except:
            pass
    except ValueError:
        pass
    try:
        string = float(string)
        return string
    except ValueError:
        complexType = re.compile("^\(?(\-?\d*(\.\d*)?(e(\+|\-)\d*)?)[ ]?(\+|\-[ ]?(\-?\d*(\.\d*)?(e(\+|\-)\d*)?))*i|j\)?")
        if complexType.match(string) != None:
            string = string.replace(" ", "").replace("i","j")
            #print "found complex", string
            res = complexType.match(string)
            return complex(float(res.group(1)), float(res.group(5)))
        else:
            raise ValueError, "String '%s' not a valid number." % string


def stringListToNumberList2d(list):
    # Own method with lots of code identical to stringToNumber(). This is done because method-calling is very slow in python.
    # For large sets of data, this method should be called at the last level, instead of iterating through every string-number.
    if type(list) is not types.ListType:
        raise TypeError, 'Expected string, got %s' % str(type(list))
    retlist = []
    for row in list:
        numberlist = []
        for string in row:
            try:
                string = int(string)
                numberlist.append(string)
                continue
            except OverflowError:
                try:
                    string = long(string)
                    numberlist.append(string)
                    continue
                except:
                    pass
            except ValueError:
                pass
            try:
                string = long(string)
                numberlist.append(string)
                continue
            except:
                pass
            try:
                string = float(string)
                numberlist.append(string)
                continue
            except ValueError:
                complexType = re.compile("^\(?(\-?\d*(\.\d*)?(e(\+|\-)\d*)?)[ ]?(\+|\-[ ]?(\-?\d*(\.\d*)?(e(\+|\-)\d*)?))*i|j\)?")
                if complexType.match(string) != None:
                    string = string.replace(" ", "").replace("i","j")
                    res = complexType.match(string)
                    numberlist.append(complex(float(res.group(1)), float(res.group(5))))
                    continue
                else:
                    raise ValueError, "String '%s' not a valid number." % string
        retlist.append(numberlist)
    return retlist

                    
def stringListToNumberList(list):
    # Own method with lots of code identical to stringToNumber(). This is done because method-calling is very slow in python.
    # For large sets of data, this method should be called at the last level, instead of iterating through every string-number.
    if type(list) is not types.ListType:
        raise TypeError, 'Expected string, got %s' % str(type(list))
    numberlist = []
    for string in list:
        try:
            string = int(string)
            numberlist.append(string)
            continue
        except OverflowError:
            try:
                string = long(string)
                numberlist.append(string)
                continue
            except:
                pass
        except ValueError:
            try:
                string = long(string)
                numberlist.append(string)
                continue
            except:
                pass
        try:
            string = float(string)
            numberlist.append(string)
            continue
        except ValueError:
            complexType = re.compile("^\(?(\-?\d*(\.\d*)?(e(\+|\-)\d*)?)[ ]?(\+|\-[ ]?(\-?\d*(\.\d*)?(e(\+|\-)\d*)?))*i|j\)?")
            if complexType.match(string) != None:
                string = string.replace(" ", "").replace("i","j")
                res = complexType.match(string)
                continue
            else:
                raise ValueError, "String '%s' not a valid number." % string
    return numberlist


def xml2lambda(element):
    def handleElement(element):
            if element.nodeType == element.TEXT_NODE:
                # element is a textnode. Return text right away
                return element.data

            stringValue = ""
            returnvalue = lambda : None

            # check each child this element has
            for child in element.childNodes:

                # iterate this over this element
                value = handleElement(child)

                # check if checked node was a textNode
                if child.nodeType == child.TEXT_NODE:
                    stringValue = value

                elif hasattr(returnvalue,child.localName):
                    # the node already has checked an occurence of this childNode

                    # get the attribute
                    attr = getattr(returnvalue,child.localName)

                    # if not list, make it a list
                    if not isinstance(attr,list):
                        attr = [attr]

                    # add the value, and put it back on the returnvalue object
                    attr.append(value)
                    setattr(returnvalue,child.localName,attr)

                else:
                    # new node, just adding the variable to the dict
                    setattr(returnvalue,child.localName,value)

            if returnvalue.__dict__:
                # object had non-text childNodes. Return parsed input from these
                return returnvalue
            else:
                # object had no non-text childNodes, return text node if any, else return empty string
                return stringValue

    # this section used to include more code, hence the need for a private method
    return handleElement(element)


def lambda2xml(expr):
        #Takes in a lambda expression and recursively generates xml from it

        ret = "" #string for building the xml

        # if input is a lambda expression:
        if type(expr) == types.FunctionType:
            # for all the attributes of the expression:
            for attr in expr.__dict__:
                attrib = getattr(expr,attr)

                # the attribute is a new lambda expression:
                if type(attrib) == types.FunctionType:
                    ret += "<" + attr + ">\n"
                    # dig deeper, watson
                    ret += lambda2xml(attrib)
                    ret += "</" + attr + ">\n"

                    # the attribute is a list:
                elif type(attrib) == types.ListType:
                    # walk the list...
                    for elem in attrib:
                        ret += "<" + attr + ">\n"
                        # and dig into each of them
                        ret += lambda2xml(elem)
                        ret += "</" + attr + ">\n"

                        # the attribute is a leaf (value) node:
                else:
                    ret += "<" + attr + ">" + str(attrib) + "</" + attr + ">\n"

        # input is no lambda expression, just return its text value
        else:
            ret += str(expr)

        return ret


def assertList(list):
    """
        Takes a result from a RPy call, and makes sure a list is returned.

        Params:
            list - object : The object to be verified.

        Returns:
            '[]'     if object is None.
            '[list]' if variable list is of non-list type.
            'list'   if variable list is a list.
    """
    if list == None                    : return []
    if type(list) is not types.ListType: return [list]

    return list

