#-*- coding: utf-8 -*-
# SciCraft - An interactive graphics front end to advanced data mining
# Copyright (C) 2002-2005 SciCraft Development Team
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
# 
# As a special exception, SciCraft Development Team gives permission
# to link this program with  Qt non-commercial edition, and distribute
# the resulting executable, without including the source code for the
# Qt non-commercial edition in the source distribution.

#client.py provides methods for searching the Norwegian Consortium
#Annotation Database Web APIs

from SOAPpy import WSDL

#wsdlpath = 'http://nova2.idi.ntnu.no/webservice/ADBSearch.wsdl'
#key = 'W27ADqBQFHKv9c5IRNYXTBxUye+vUAp6'


class DbConnect:
    """
    The constructor takes as input a name, the database
    path and the database key, and uses the databasepath
    for creating a connection to the database with
    SOAP and WSDL. The databasekey is used in other
    methods when extracting information from the database.
    """
    def __init__(self, name, dbPath, dbKey):
        self.name = name
        self._dbKey = dbKey
        self._dbPath = dbPath
        connection = self.connect_to_db(dbPath)
        if connection[1]:
            self._server = connection[0]
        self.connected = connection[1]

    def get_db_path(self):
        return self._dbPath

    def get_db_key(self):
        return self._dbKey
                
    """
    Method used for connecting to the database,
    called from the constructor. Returns a 2-tuple
    where the first part is the connectionobject
    and the latter is a boolean telling whether
    the connection succeeded.
    """
    def connect_to_db(self, dbPath):
        try:
            server = WSDL.Proxy(dbPath)
            connectSucceeded = True
        except:
            #print 'Error connecting to database'
            server = ''
            connectSucceeded = False

        return (server, connectSucceeded)


    """
    Search method with inputs query and option.
    Query is the gene ID and option is the type of
    gene id, e.g. locuslink. Valid options are:
    unigene, locuslink, accno and clone(?)
    The result and a boolean variable telling
    whether the search was successful is returned
    in a 2-tuple
    """
    def search(self, query, option):
        if self.connected:
            try:
                result = self._server.search(self.get_db_key(), str(query), option)
                searched = True
            except:
                #print 'Error searching database'
                result = ''
                searched = False
        else:
            #print 'Not connected to database'
            result = ''
            searched = False
        return (result, searched)

    """
    Method for retrieving title and description (returned in a 2-tuple)
    of a certain gene, specified by query and option as
    described in the method above
    """
    def get_gene_info(self, query, option):
        #print 'query: '+str(query)
        #print 'option: '+str(option)
        search = self.search(query, option)
        if search[1]:
            result = search[0]
            try:
                title = result.LocusLinkSearchResult.official_gene_name
                #hmm...veldig rart!..function funker ikkje lenger
                #description = result.SwissProtSearchResult.function
                description = result.SwissProtSearchResult.description
            except:
                #print 'Error retrieving information from search'
                title = 'No match in database'
                description = ''
        else:
            #print 'Error searching'
            title = ''
            description = ''
        return (title, description)
            

