function Xnew = procrus_wrapper(Uj,vj,Ur,vr)
% Xnew = procrus_wrapper(Uj,vj,Ur,vr)
% Wrapper function for call to Procrustes software that
% rotates molecules into a common frame of reference given by 
% reference molecule
%
% INPUT VARIABLES
%
% Uj                = Coordinate matrix (XYZ) for molecule i
% vj                = vector of atom indices that are comparable atoms to ref
% Ur                = Coordinate matrix (XYZ) for reference molecule
% vr                = vector of atom indices in reference molecule used for comparison
% 
% OUTPUT VARIABLE
%
% Xnew              = Translated/rotated coordinate matrix for molecule i which now is oriented
%                     such that the comparable atoms in i and the reference have maximum overlap
%
% NOTE: Remember to compare Xnew with the CENTERED version of Ur!!!
%
% B.K.Alsberg
% Last modified: 27/8-2004
%

Xj = Uj(vj,:);
Xr = Ur(vr,:);

if length(vr) ~= length(vj),
  error('vr and vj must have the same length');
end;

nr = size(Xr,1);
Xr = Xr - ones(nr,1)*mean(Xr);

[Vr,Vj,diagnosj] = procrusND(Xr,Xj);
nj = size(Uj,1);

% The rotation matrix is contained in the diagnosj struct:

Rj = diagnosj.Q;

% Given the transformation matrices (rotation and translation) we are able to transform all 
% atoms in Uj to be aligned with the atoms in the reference

% Extract centering used by ProcrusND routine, we need this to translate to reference
uj = diagnosj.cY;

% Perform transformation on all atoms in molecule j
Uj2 = Uj - ones(nj,1)*uj; 
Xnew = Uj2*Rj;





