function [Xred,xKept,tStat] = fssir(X,Y,nVarMax)

%Feature subset selection by individual ranking. t-score by (Nguyen
%and Rocke,2002)
%
%[Xred,xKept,tStat] = fssir(X,Y,nVarMax)
%
%Input data:
%  X:            Input data matrix
%  Y:            Binary class vector
%  nVarMax:      Number of variables to keep
%
%Output data:
%  Xred:         Reduced data matrix
%  xKept:        Index to kept variables in X
%  tStat:        T-statistics for class separation for each
%                variable in X
%
%Related functions:
%plsr.m

%author L. Gidskehaug, Apr 07, 2003

[nSamples,nVariablesX] = size(X);
nVariablesY = size(Y,2);

if ~all(Y==1 | Y==0)
  error('Y must be binary (0/1)');
end %if

X0 = X(find(~Y),:);
n0 = size(X0,1);
X1 = X(find(Y),:);
n1 = size(X1,1);

tStat = (mean(X0) - mean(X1))./sqrt(var(X0)/n0 + var(X1)/n1);
[tSort,tInd] = sort(abs(tStat));
xKept = sort(tInd(nVariablesX-nVarMax+1:nVariablesX));
Xred = X(:,xKept);
