
function [mscData] = msc(data)
offset = 1
slope = 1
%Performs Multiplicatve Signal Correction (MSC) on data
%
% [mscData, offsetParam, slopeParam] = msc(data, offset, slope)
%
%Input Variables:
%  data:        Data matrix to be transformed
%  offset:      1 for including additive coefficient(ai). 0 otherwise.
%  slope:       1 for including multiplicative coefficient(bi). 0 otherwise.
%
%Output Variables:
%  mscData:     MSC transformed data matrix.
%  offsetParam: Correction parameters for additive effect (vector)
%  slopeParam:  Correction parameters for multiplicative effect (vector)
%
%  The mean spectrum is chosen as reference spectrum for the
%  multiplicative model term

%author M.B. Rye, Oct 10, 2002

X = data;

CondNumber = 1e19; % Uses CondNumber if model terms are linearly dependent.

[N,M] = size(X);
MSCWeights = ones(1,M);

Xmod = [];
Ref = mean(X)';

%Estimate all parameters at the same time.
%Offset
   
if offset == 1
  Xmod = [ones(M,1)];
end % if

%Slope 
if slope == 1
  Xmod = [Xmod Ref];
end % if
  
diagW = diag(MSCWeights);
XX = Xmod'*diagW*Xmod;

% Ridging if CondNumber is specified. Calculetion of inverse XX.

if CondNumber>0
  [u,S,v]=svd(XX);
  s=diag(S)';
  sCorrected=max(s, (s(1)/CondNumber)); 
  XXCorrected=u*(diag(sCorrected))*v';
  InvXX = inv(XXCorrected);
else
  InvXX=inv(XX);
end % if

MSCParam = InvXX*Xmod'*diagW*X';
MSCParam = MSCParam';

%estimating Xnew

Xnew = X;
j = 1;

ai = [];
bi = [];

%Offset
if offset == 1
  ai = MSCParam(:,j);
  Xnew = Xnew-(ai*ones(1,M));
  j = j+1;
end % if

%Slope
if slope == 1
  bi = MSCParam(:,j);
  Xnew = Xnew./(bi*ones(1,M));
  j = j+1;
end % if
    
mscData = Xnew;
offsetParam = ai;
slopeParam = bi;





        
    

       
   







