function [X,meanX,stdX] = normalize(X,ctr,scl)

%Mean-centering of matrix X and/or scaling to unit variance.
%
%[Xsc,meanX,stdX] = normalize(X,ctr,scl)
%
%Input variables:
%  X:     Input data matrix/column-vector
%  ctr:   If true, mean-centering is performed on X
%  scl:   If true, auto-scaling is performed on X
%
%Output variables:
%  Xsc:     Processed data
%  meanX:   Vector of column-means used in centering
%  stdX:    Vector of standard deviations used in scaling
%

%author L. Gidskehaug, Jan 17, 2003 

[nSamples,nVars] = size(X);

if ctr
  meanX = mean(X);
  X = X - ones(nSamples,1)*meanX;
else
  meanX = zeros(1,nVars);
end %if

if scl
  stdX = std(X);
  X = X./(ones(nSamples,1)*stdX);
else
  stdX = ones(1,nVars);
end %if
