
function [sisData] = sis(data, anSpectra, intSpectra, weights)

%Performs Spectral Interference Subtraction on data
%
% [sisData] = sis(data, anSpectra, intSpectra, Weights)
%
%Input Variables:
%  data:        Data matrix to be transformed (nSamp, nVar)
%  anSpectra:   Analyte spectra matrix (nAnSpec, nVar)
%  intSpectra:  Interference spectra matrix (nIntSpec, nVar)
%  weights:     Matrix of Weights (Optional). Set to 0 if not
%               specified. The default value sets the diagonal
%               elements of the wight matrix to 1 for analytes and
%               0 for interferences. Matrix has size (nAnal+nInt, nAnal+nInt)
%
%Output Variables:
%  sisData:     Transformed data matrix (nSamp, nVar)

%References:
% Martens H and Stark E. Journal of Pharmaceutical & Biomedical
% Analysis. Vol.9, No.8, pp.625-635, 1991

%%author M.B. Rye, Oct 18, 2002

W = weights;

K = [anSpectra' intSpectra'];
KK = K'*K;
invKK = inv(KK);
cons = invKK*K'*data';


if weights == 0
  [nAnal, nWave] = size(anSpectra);
  [nInt, nWave] = size(intSpectra);
  analyte = ones(1,nAnal);
  interf = zeros(1,nInt);
  W = diag([analyte interf]);
end % if
  

sisData = K*W*cons;



