function [Out,SNR] = AddNoise(X,method,level)
% [Out,SNR] = AddNoise(X,method,level)
% This is a very simple function for adding noise to a data matrix X
%
% INPUT VARIABLES
%
% X             =  data matrix (N rows of e.g. spectra and M
%                  columns)
% method        =  string for selecting method for adding noise, choices are:
%                  - 'Normal' normal distributed noise, N(0,1)
%                  - 'Flat'  flat distributed noise
%                  (options for heteroscedastic noise types will
%                  be added later)
% level         = controls how much noise is added
%
% OUTPUT VARIABLES
%
% Out           = X matrix added noise
% SNR           = the mean signal to noise ratio (using a very
%                 simple method for this: sum(signal.^2)/(sum(noisy_signal.^2))
%
%
% Copyright(C), B.K. Alsberg, The SciCraft Team, www.scicraft.org
% Last update: 9/3-06
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.

[N,M] = size(X);

if method == 'Normal'
  Noise = randn(N,M)*level;
elseif method == 'Flat'
    Noise = rand(N,M)*level;
end;


Out = X + Noise;

xm = mean(X);
xmn = mean(Out);

a = xm.^2;
b = (xm-xmn).^2;

SNR = sqrt(sum(a)/sum(b));
