function [qmfopt,optfam,optpar,PP] = FindBestWavelet(X)
% [qmfopt,optfam,optpar,PP] = FindBestWavelet(X)
% This functions will only deliver a wavelet which is part of the
% WaveLab toolbox
% 
% INPUT VARIABLE
%
% X                  = Data set to be analysed. Will find the best
%                      wavelet which can reconstruct it by working
%                      on a compressed representation (such as the
%                      mean) 
%
% OUTPUT VARIABLES
%
% qmfopt             = the quadrature mirror filter vector for the
%                      optimal wavelet type (can be used directly in computations)
% famopt             = string containing the name of the optimal wavelet type
% optpar             = a scalar indicating the vanishing moments
% PP                 = matrix of standarized reconsruction errors for each wavelet
%
%
% Copyright(C), B.K. Alsberg, The SciCraft Team, www.scicraft.org
% Last update: 8/3-06
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%


% Here we use the mean:

xm = mean(X);

col1 =':k';
col2 ='k';
lw1 = 0.5;
lw2 = 2;

M{1,1} ='Haar';
M{1,2} = 1;

M{2,1} = 'Beylkin';
M{2,2} = 1;

M{3,1} = 'Coiflet';
M{3,2} = [1 :5];

M{4,1} = 'Daubechies';
M{4,2} = [4:2:20 ];

M{5,1} = 'Symmlet' ;
M{5,2} =  [5:10];

M{6,1} = 'Vaidyanathan';
M{6,2} = 1;

k=1;
for i = 1:6
   par = M{i,2};
   for j = 1:length(par)
      qmf = MakeONFilter(M{i,1},par(j));
      w = FWT_PO(xm,0,qmf);
      [cc(j),PP(k,:)] = CompressionFactor(w);
      cctot(k,1) = cc(j);
      cctot(k,2) = i;
	  cctot(k,3) = j;
      k=k+1;
   end;
   M{i,3} = cc;
end;

PP0=PP;
% this part must be included to make only positive values:
ml = min(min(PP));
PP = PP - ml;
cctot(:,1) = (sum(PP'))';

%cctot = cc';

[mc,idx0] = min(cctot(:,1));
idx1 = round(cctot(idx0,2));
idx2 = cctot(idx0,3);
paropt1 = M{idx1,2}(idx2);

%[dummy,paropt0] = min(M{idx1,3});
%par = M{idx1,2};
%paropt1 = par(paropt0);

str = ['The best wavelet for this profile is ' M{idx1,1} ' ' int2str(paropt1)];
disp(str);
optfam = M{idx1,1};
optpar = paropt1;

qmfopt = MakeONFilter(optfam,paropt1);

% Let us normalize PP:

mtot = max(max(PP));

PP = lintrans(PP,0,mtot,0,1);

%clf
%for i = 1:size(PP,1)
%  h1=plot(PP(i,:),col1);
%  set(h1,'linewidth',lw1);
%  hold on
%end;

%h2 = plot(PP(idx0,:),col2);
%set(h2,'linewidth',lw2);

%xlabel('Coefficients');
%ylabel('Normalised reconstruction error ');
