function [FreQSpec,AC,FullComPlexSpetrum] = FourierTransform1D(x)

% $$$ ##[FreQSpec,AC,FullComPlexSpetrum] = FourierTransform1D(x)
% $$$ ##Performs 1D Fourier transform of x. 
%
% $$$ ##INPUT VARIABLE
%
% $$$ ##x                   = input vector to be FFT ed
%
% $$$ ##OUTPUT VARIABLES
%
% $$$ ##FreQSpec            = Frequency spectrum of input signal x
% $$$ ##                      this vector is approx. half length of x
% $$$ ##AC                  = AC component of x (i.e. frist element of fft(x))
% $$$ ##FullComPlexSpetrum  = the raw output vector from Octave fft(x)
% $$$ ##                      routine. This is a complex vector
%
% $$$ ##Copyright (C), B.K. Alsberg, bka@phys.chem.ntnu.no
% $$$ ##Last update: 25/6-2004
%
% $$$ ## This file is part of SciCraft.
% $$$ ##
% $$$ ## SciCraft is free software; you can redistribute it and/or modify it
% $$$ ## under the terms of the GNU General Public License as published by
% $$$ ## the Free Software Foundation; either version 2, or (at your option)
% $$$ ## any later version.
% $$$ ##
% $$$ ## SciCraft is distributed in the hope that it will be useful, but
% $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
% $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% $$$ ## General Public License for more details.
% $$$ ##
% $$$ ## You should have received a copy of the GNU General Public License
% $$$ ## along with SciCraft; see the file COPYING.  If not, write to the Free
% $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
% $$$ ## 02111-1307, USA.
% $$$ 

n = length(x);
ns = round((n-1)/2);
f = fft(x);
FullComPlexSpetrum = f;
v = abs(f);
AC = v(1);
vv = v(2:end);
FreQSpec = vv(1:ns);


