function Xh = InverseWaveletTransform(W,qmf,L)
% Xh = InverseWaveletTransform(W,qmf,L)
% Performs the Inverse Fast Wavelet Transform (IWT) on data
% with 2^J elements. The IWT is performed on each ROW in X
%
% INPUT VARIABLES
%
% W             = wavelet coefficient matrix with N rows and M columns
%                 M = 2^J. 
% qmf           = Quadrature mirror filter indicating of the
%                 wavelet types used. See WaveletTransform for details
% L             = Coarsest Level of V_0;  L << J (Default=0)
%
% OUTPUT VARIABLE
%
% Xh            = estimated data matrix with N rows and M columns
%                 M = 2^J. 
%
% Copyright(C), B.K. Alsberg, The SciCraft Team, www.scicraft.org
% Last update: 7/3-06
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.


[N,M] = size(W);

if round(loge(M,2))-loge(M,2) ~= 0,
  error('You have not M=2^J number of variables');
end

if nargin < 3,
  L=0;
end

for i = 1:N
 Xh(i,:) = IWT_PO(W(i,:),L,qmf);
end;
