KNearestNeighbour <- function(Xin,yin,testin=NULL,k) {
#Performes a K-Means clustering on a data matrix.

# INPUT VARIABLES
# Xin -        matrix containing the data
# yin -        A vector containing the classes for the samples given in the Xin-matrix.
# testin -     Matrix of test set cases. In order words, each row contains the values of the independent variables for a sample with unknown class. Optional.
# k -          Number of neighbours considered
#              

# OUTPUT VARIABLES
# calerror -    The percentwise calibration error for the classification rule.
# prederror -   The percentwise prediction error for the
# classification rule estimated using leave-on-out crossvalidation.
# predobjects - The predicted classes for the samples in the test matrix.  
#  
# Copyright(C), Jon Strom, The SciCraft Team, www.scicraft.org
#Last update: 17/3-06


# $$$ ## This file is part of SciScraft.
# $$$ ##
# $$$ ## SciScraft is free software; you can redistribute it and/or modify it
# $$$ ## under the terms of the GNU General Public License as published by
# $$$ ## the Free Software Foundation; either version 2, or (at your option)
# $$$ ## any later version.
# $$$ ##
# $$$ ## SciScraft is distributed in the hope that it will be useful, but
# $$$ ## WITHOUT ANY WARANTY; without even the implied warranty of
# $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# $$$ ## General Public License for more details.
# $$$ ##
# $$$ ## You should have received a copy of the GNU General Public License
# $$$ ## along with R; see the file COPYING.  If not, write to the Free
# $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
# $$$ ## 02111-1307, USA.
# $$$ 
# $$$ ## -*- texinfo -*-
library(class)
X <- as.matrix(Xin)
y <- as.factor(yin)
n <- length(y)

if(nrow(X)!=n) {
  stop("Wrong input. number of columns of Xin must match number of
  columns in yin")
}

########## Perform classification on test data ##########
if (is.null(testin)) {
   knn.pred <- NULL
 }
else {
  test <- as.matrix(testin)
  knn.pred <- knn(X,test,y,k)
}


############## Estimating calibration error #############
tmp <- knn(X,X,y,k)
cal.error <- 100*(1-mean(tmp==y))
############## Estimating prediction error #############
tmp.cross <- knn.cv(X,y,k)
pred.error <- 100*(1-mean(tmp.cross==y))
return(list(predobjects=as.integer(knn.pred),calerror=cal.error,prederror=pred.error,))
}
