LinearDiscriminantAnalysis <- function(Xin,yin) {
#Performes a Linear Discriminant Analysis.

# INPUT VARIABLES
# Xin -        The values for the independent variables for the
#               calibration samples. X is a matrix or data frame from R. 
# yin -        A vector containing the classes for the samples given
#               in the X-matrix.
        

# OUTPUT VARIABLES
# rule -        R object with the estimated classification rule.
# calerror -    The percentwise calibration error  for the classification rule.
# prederror -   The percentwise prediction error for the
#                 classification rule estimated using leave-on-out crossvalidation.
#  
# Copyright(C), Endre Anderssen, The SciCraft Team, www.scicraft.org
#Last update: 19/3-06


# $$$ ## This file is part of SciScraft.
# $$$ ##
# $$$ ## SciScraft is free software; you can redistribute it and/or modify it
# $$$ ## under the terms of the GNU General Public License as published by
# $$$ ## the Free Software Foundation; either version 2, or (at your option)
# $$$ ## any later version.
# $$$ ##
# $$$ ## SciScraft is distributed in the hope that it will be useful, but
# $$$ ## WITHOUT ANY WARANTY; without even the implied warranty of
# $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# $$$ ## General Public License for more details.
# $$$ ##
# $$$ ## You should have received a copy of the GNU General Public License
# $$$ ## along with R; see the file COPYING.  If not, write to the Free
# $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
# $$$ ## 02111-1307, USA.
# $$$ 
# $$$ ## -*- texinfo -*- 
  library(MASS)
  X <- as.matrix(Xin)
  y <- as.factor(yin)
  n <- length(y)
  
  if(n!=nrow(X)) {
    stop("Wrong input: number of rows in Xin must mach the length of
       yin. ")
  }
  #Compute classification rule
  lda.rule <- lda(X,y)
  #Compute calibration error 
  pred.lda <- predict(lda.rule,X)$class
  cal.error <- 100*(1-mean(y==pred.lda))
 #  Compute prediction error using crossvalidation
   y.pred <- NULL
   y.true <- NULL
   for (i in 1:n) {
     X.cal <- X[-i,]
     y.cal <- y[-i]
     X.pred <- X[i,]    
     X.lda <- lda(X.cal,y.cal)
     y.pred[i] <- predict(X.lda,X.pred)$class[[1]]
     y.true[i] <- y[[i]]  }  
  pred.error=100*(1-mean(y.pred==y.true))
  return(list(rule=lda.rule,calerror=cal.error,prederror=pred.error))
}
