# issues
# Modified T scores when using loadings
# Computing levrage values for samples DONE
# Computing residual vectors for samples and variables DONE
# Computing residual matrixes of X (Y is in fit) DONE
# Set up return data structure
predictPLS <- function(fit,Xnew,NumberOfComponents){
 library(pls)
 ncomp<- NumberOfComponents
 Xnew <- as.matrix(Xnew)
 scores <- predict.mvr(fit,list(X=Xnew),type = "scores")
 response <- predict.mvr(fit,list(X=Xnew),cumulative = FALSE,type = "response")
 
 return(list(scores=as.matrix(scores),yPred=as.matrix(response)))
 
} 



EAcv <- function (X, Y, ncomp, method = c("kernelpls", "simpls", "oscorespls", 
    "svdpc"), segments = 10, segment.type = c("random", "consecutive", 
    "interleaved"), length.seg, trace = FALSE, ...) 
{
    Y <- as.matrix(Y)
    dy <- dim(Y)
    dx <- dim(X)
    dnX <- dimnames(X)
    dnY <- dimnames(Y)
    dimnames(X) <- dimnames(Y) <- NULL
    if (is.list(segments)) {
        if (is.null(attr(segments, "type"))) 
            attr(segments, "type") <- "user supplied"
    }
    else {
        if (missing(length.seg)) {
            segments <- cvsegments(dx[1], k = segments, type = segment.type)
        }
        else {
            segments <- cvsegments(dx[1], length.seg = length.seg, 
                type = segment.type)
        }
    }
    method <- match.arg(method)
    fitFunc <- switch(method, simpls = simpls.fit, kernelpls = kernelpls.fit, 
        oscorespls = oscorespls.fit, svdpc = svdpc.fit)
    adj <- numeric(ncomp)
    cvPred <- pred <- array(dim = c(dx[1], dy[2], ncomp))
    
    #Inserted jack knife storage space here
    jkT <- array(NA,dim=c(dx[1],ncomp,length(segments)))
    jkW <- array(NA,dim=c(dx[2],ncomp,length(segments)))
    jkB <- array(NA,dim=c(dx[2],dy[2],ncomp,length(segments)))
   
    if (trace) 
        cat("Segment: ")
    for (n.seg in 1:length(segments)) {
        if (trace) 
            cat(n.seg, "")
        seg <- segments[[n.seg]]
        fit <- fitFunc(X[-seg, ], Y[-seg, ], ncomp, stripped = FALSE, 
            ...)
        #Insert jacknifing storage here
	#Store CV scores
	jkT[-seg,,n.seg] <- fit$scores 
	#Store CV loading weights
	jkW[,,n.seg] <- fit$loadings
	#Store CV Beta
        jkB[,,,n.seg] <- fit$coefficients
        
        
        Xtest <- sweep(X, 2, fit$Xmeans)
        for (a in 1:ncomp) pred[, , a] <- sweep(Xtest %*% fit$coefficients[, 
            , a], 2, fit$Ymeans, "+")
        cvPred[seg, , ] <- pred[seg, , , drop = FALSE]
        adj <- adj + length(seg) * colSums((pred - c(Y))^2)
    }
    if (trace) 
        cat("\n")
    MSEP0 <- apply(Y, 2, var) * dx[1]/(dx[1] - 1)
    MSEP <- colMeans((cvPred - c(Y))^2)
    R2 <- matrix(nrow = dy[2], ncol = ncomp)
    for (i in 1:dy[2]) R2[i, ] <- cor(cvPred[, i, ], Y[, i])^2
    objnames <- dnX[[1]]
    if (is.null(objnames)) 
        objnames <- dnY[[1]]
    yvarnames <- dnY[[2]]
    nCompnames <- paste(1:ncomp, "comps")
    names(MSEP0) <- yvarnames
    dimnames(adj) <- dimnames(MSEP) <- dimnames(R2) <- list(yvarnames, 
        nCompnames)
    dimnames(cvPred) <- list(objnames, yvarnames, nCompnames)
    
    #add dimnames to jackknife results
    dimnames(jkT)<-list(objnames,nCompnames,as.character(segments))
    if (is.null(dnX[[2]])){
     varnames <- as.character(1:dx[2])}
    else{
     varnames <- dnX[[2]]
     }
    #print(varnames) 
    dimnames(jkW)<-list(varnames,nCompnames,as.character(segments))
    dimnames(jkB)<-list(varnames,yvarnames,nCompnames,as.character(segments))
    
    
    jkRes <- list(scores = jkT, loadings = jkW, coefficients= jkB)
    
    cvRes <-list(method = "CV", pred = cvPred, MSEP0 = MSEP0, MSEP = MSEP, 
        adj = adj/dx[1]^2, R2 = R2, segments = segments)
    
    return(list(cvRes=cvRes,jkRes=jkRes))
        
}

jkPLS <-function(X,Y,fit,jk,NumberOfComponents,JackKnife,ModifiedTtest){

ValidationSegments <- length(fit$validation$segments)
aOpt <- NumberOfComponents


dx <- dim(X)
dy <- dim(Y)
 
  for (i in 1:ValidationSegments){
   #rotate scores
   rot <- procrustes(as.matrix(fit$scores[-fit$validation$segments[[i]],1:aOpt]),as.matrix(jk$jkRes$scores[-fit$validation$segments[[i]],1:aOpt,i]),scale = FALSE)
   jk$jkRes$scores[-fit$validation$segments[[i]],1:aOpt,i] <- rot$Yrot
   jk$jkRes$scores[fit$validation$segments[[i]],1:aOpt,i]  <- fit$scores[fit$validation$segments[[i]],1:aOpt]
   
   #rotate loadings using scores results
   jk$jkRes$loadings[,1:aOpt,i] <- jk$jkRes$loadings[,1:aOpt,i] %*% rot$rotation
   }
 
 #compute T statistics
  if (JackKnife=="T-scores on Coefficients"){
   t2 <- matrix(0,dy[2],dx[2])
   Sb <- matrix(0,dy[2],dx[2])
   
   #for each response variable
   
   for (i in 1:dy[2]){
    Sb[i,] <- (diag(var(t(as.matrix(jk$jkRes$coefficients[,i,aOpt,])))))
    
    dummy <- sort(Sb[i,])
    ind <- round(dx[2]*ModifiedTtest)
   
    if (ind!=0){
     Sb[i,] <- Sb[i,] + dummy[ind]    
    }     
   t2[i,] <- ValidationSegments*fit$coefficients[,i,aOpt]/Sb[i,]
   }
   
  }
  
  
 if (JackKnife=="T^2-scores on loadings"){
  t2 <- matrix(0,1,dx[2])
  
  
  if (ModifiedTtest !=0){
  
  cvmx <- matrix(0,dx[2],aOpt)
  penaltyEigs <- vector("numeric",length=aOpt)
 
   for (i in 1:dx[2]){
    usv <- svd(as.matrix(jk$jkRes$loadings[i,1:aOpt,]))
    cvmx[i,] <- usv$d
   } 
   
   for (i in 1:aOpt){
    dummy <- sort(cvmx[,i])
    ind <- round(dx[2]*ModifiedTtest)
    penaltyEigs[i] <- dummy[ind]
   }
  
   for (i in 1:dx[2]){
    usv <- svd(as.matrix(jk$jkRes$loadings[i,1:aOpt,]))
    usv$d <- usv$d + penaltyEigs
    jk$jkRes$loadings[i,1:aOpt,] <- usv$u%*% diag(usv$d)%*%t(usv$v)
    
    }
  }
 
  
  hotell <- function(x){
   x <- as.matrix(x)
   cvm <- cov(x)
   d <- colMeans(x)
   tsq <- (ValidationSegments/(ValidationSegments-1))*d%*%(ginv(cvm)%*%(d))
   }
  
  t2 <- apply(jk$jkRes$loadings,1,hotell)
  t2 <- as.matrix(t2)
  }
 
 t2
 
 }


SciCraftPLS <- function(X,Y,NumberOfComponents,Validation="none",ValidationSegments=10,JackKnife="none",ForceComponents="Use NumberOfComponents",FDR="none",ModifiedTtest=0,permutations= 50){
library(pls)
library(vegan)
library(MASS)

#JackKnife("none","T-scores on Coefficients","T^2-scores on loadings") 
#Validation("none","Leave one out (LOO)","Random segments")
#ForceComponents("Use NumberOfComponents","Find optimum")
#FDR("none", "Compute FDR q-values")

##########################################################
###########Ensure exisence################################
nperm <- permutations
ModifiedTtest <- ModifiedTtest/100

t2 <- 0
qvalue <- 0
Ypred <- 0

##########################################################
#########Quality control##################################


#check dims agains NumberOfComponents and ValidationSegments
X <- as.matrix(X)
Y <- as.matrix(Y)
dy <- dim(Y)
dx <- dim(X)

maxNcomp=min(dx)-1

if (Validation =="none" & ForceComponents == "Find optimum"){
 stop("Can not find optimum number of components without validation")
}

if (JackKnife == "T^2-scores on loadings" & (ValidationSegments < NumberOfComponents)){
 stop("Need more validation segments than components for q value calculations")
}

if(NumberOfComponents > maxNcomp){
NumberOfComponents <- maxNcomp
warning("NumberofComponents too large reduced to 'min(dim(X))'")
}

if (ModifiedTtest >= 1){
 stop("ModifiedTtest { [0,1>")}
if (FDR=="Compute FDR q-values" & JackKnife == "none"){
 stop("FDR calculation requaires Jackknifing")
 }

if(dx[1] != dy[1]){stop("need same number of samples in X and Y")}

if (Validation=="none" & JackKnife !="none"){
stop("Jackknifing requires some form of cross validation")}

if (Validation == "none"){
 fit <- mvr(Y ~ X,data = list(X,Y),validation="none",ncomp=NumberOfComponents)
 }

if ((Validation != "none") &  (JackKnife == "none")){
 if(Validation == "Leave one out (LOO)"){
  fit <- mvr(Y ~ X,data = list(X,Y),validation="LOO",ncomp=NumberOfComponents)}
 if(Validation == "Random segments"){ 
  fit <- mvr(Y ~ X,data = list(X,Y),validation="CV",segments=ValidationSegments,ncomp=NumberOfComponents)}
   



}
else{
 if(Validation=="Leave one out (LOO)"){ValidationSegments <- dx[1]} 
 jk <- EAcv(X,Y,ncomp=NumberOfComponents,segments=ValidationSegments)
 fit <- mvr(Y ~ X,data =list(X,Y),ncomp=NumberOfComponents,validation="none")
 fit$validation <- jk$cvRes
 }
 #Determine optimum model
 if ((Validation != "none") & (ForceComponents == "Find optimum")){ 
   aOpt <- which.min(fit$validation$adj)
} 





if (ForceComponents == "Use NumberOfComponents"){
 aOpt <- NumberOfComponents
}
   
if (JackKnife != "none"){ 
 t2 <- jkPLS(X,Y,fit,jk,NumberOfComponents=aOpt,JackKnife,ModifiedTtest)
}

if (FDR=="Compute FDR q-values" & JackKnife != "none"){
 
 Tarray <- array(0,dim =c(dim(t2)[1],dim(t2)[2],nperm))
  
 for (i in 1:nperm){
  Ys <- sample(1:dy[1])
  Ys <- as.matrix(Y[Ys,])
  sjk <- EAcv(X,Ys,ncomp=NumberOfComponents,segments=ValidationSegments)
  sfit <- mvr(Ys ~ X,data =list(X,Y),ncomp=NumberOfComponents,validation="none")
  sfit$validation <- sjk$cvRes
  Tarray[,,i] <- jkPLS(X,Ys,sfit,sjk,NumberOfComponents=aOpt,JackKnife,ModifiedTtest) 
  
 }
 
 
 mediant <- apply(Tarray,c(1,2),median)
 qvalue  <- t2
 
 if (JackKnife=="T-scores on Coefficients"){
  for (i in 1:dy[2]){
   for (j in 1:dx[2]) {
    qv <- qvalue[i,j]
     
    if (qv > 0) {    
     qvalue[i,j] <- sum(mediant[i,] >= qv)/sum(t2[i,] >= qv)
     }
    if(qv < 0){
     qvalue[i,j] <- sum(mediant[i,] <= qv)/sum(t2[i,] <= qv)
     }
    } 
   }
 }

 if(JackKnife == "T^2-scores on loadings"){
  for (i in 1:dx[2]){
   qv <- t2[i,1]
   qvalue[i,1] <- sum(mediant >= qv)/sum(t2 >= qv)
  }
 } 

 qvalue[qvalue > 1] <- 1
}
#compute q values

Xmeans <- X

for (i in 1:dx[1]){
Xmeans[i,] <- fit$Xmeans
}

Xres <- X - Xmeans - fit$scores[,1:aOpt]%*%t(fit$loadings[,1:aOpt])
XVarRes <- colSums(Xres)
XSamRes <- rowSums(Xres)

Leverage <- vector("numeric",length= dx[1])

for (i in 1:dx[1]){
Leverage[i] <-100*((1/dx[1]) + (t(fit$scores[i,1:aOpt])%*%ginv(t(fit$scores[,1:aOpt])%*%(fit$scores[,1:aOpt]))%*%(fit$scores[i,1:aOpt])))
}

#additional output:
#aOpt
#t2
#qval
#
print(aOpt)
if (Validation!="none"){
diagnostics <- list(optimumNumberOfComponents = aOpt,Tstat= t2,qValue = qvalue, Ypred = as.matrix(fit$validation$pred[,,aOpt]))
}
if (Validation=="none"){
diagnostics <- list(optimumNumberOfComponents = aOpt,Tstat= 0,qValue = 0, Ypred = 0)
}

return(list(plsModel=fit,diagnostics = diagnostics))#, t2 = t2, qval = qvalue,mt = mediant))
}
