function [T,W,Yval,Ycal,B,B0,MSEC,MSEP,P,PValues,aOpt,Q] =
SciCraft_crossval(X,Y,aMax)

% $$$ ## -*- texinfo -*-
% $$$ ##Easy to use cross validation function for scicraft
% $$$ ##Usage: [T,W,Yval,Ycal,B,B0,MSEC,MSEP,P,PValues,aOpt,Q] = SciCraft_crossval(X,Y,aMax)
% $$$ ##
% $$$ ##
% $$$ ## INPUT VARIABLES:
% $$$ ## X,Y             = Input data matrices 
% $$$ ## aMax            = the maximum no. of PLSR factors tested for
% $$$ ##
% $$$ ## OUTPUT VARIABLES
% $$$ ##
% $$$ ## T               = scores
% $$$ ## W               = weights
% $$$ ## Yval            = Y crossvalidation validation data
% $$$ ## Ycal            = Y crossvalidation calibration data
% $$$ ## B               = regression matrix
% $$$ ## B0              = regression offset
% $$$ ## MSEC            = calibration error
% $$$ ## MSEP            = prediction error
% $$$ ## P               = loadings (X)
% $$$ ## PValues         = p-values for each variable from Jacknife
% $$$ ## aOpt            = the optimal no. of PLSR factors from
% $$$ ##                   crossvalidation
% $$$ ## Q               = loadings (Y)
% $$$ ##
% $$$ ##Remaining issues
% $$$ ##INPUTS
% $$$ ## more cross validation methods
% $$$ ##  Random at set #segments
% $$$ ##  Venetian blinds
% $$$ ##  Replicates
% $$$ ##
% $$$ ##OUTPUTS
% $$$ ## Leverage
% $$$ ## Residuals of a sample
% $$$ ## Validation residuals of a sample
% $$$ ## Residuals of a variable
% $$$ ## Validatio residuals of a variable
% $$$ ##

% $$$ ## This file is part of SciCraft.
% $$$ ##
% $$$ ## SciCraft is free software; you can redistribute it and/or modify it
% $$$ ## under the terms of the GNU General Public License as published by
% $$$ ## the Free Software Foundation; either version 2, or (at your option)
% $$$ ## any later version.
% $$$ ##
% $$$ ## SciCraft is distributed in the hope that it will be useful, but
% $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
% $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% $$$ ## General Public License for more details.
% $$$ ##
% $$$ ## You should have received a copy of the GNU General Public License
% $$$ ## along with SciCraft; see the file COPYING.  If not, write to the Free
% $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
% $$$ ## 02111-1307, USA.
% $$$ 

%Checking dimension of matrix compared with the maximum number of PCs
[m,n] = size(X);

if min([m,n])<aMax
aMax=min([m,n]);
end

%Determine if deflatin is to be used
if n > 10*m 
dfl = 1;
else
dfl = 0;
end

%Make cross validation set up
segment_index = makeXval('loo',X); 

%Make data struct
data = struct('X',X,'Y',Y);

%Compute models and cross validation
[full_model,sub_models,errors] = crossval2(data,segment_index,aMax,dfl,2);

%Set Outputs
aOpt = full_model.aOpt;
T = full_model.T;
W = full_model.W;
Yval = sub_models.Yhat(:,:,aOpt);
Ycal = full_model.Yhat(:,:,aOpt);
Btmp = full_model.B;
% Added (bka):
mx   = full_model.mx;
my   = full_model.my;
MSEC = errors.MSEC;
MSEP = errors.MSEP;
%%%%%%%%%%%%%%%%%%%%

B = squeeze(Btmp(:,:,aOpt));
B0 = my - mx*B;

PValues = full_model.Bpval;
P = full_model.P;
Q = full_model.Q;
