function [X] = TimeScalePlotMatrix(W,row)
% [X] = TimeScalePlotMatrix(W,row)
% Creates a matrix which can be visualised as a time-scale plot
% if using Image Plot in SciCraft
%
% INPUT PARAMETERS
%
% W            = wavelet coefficients (or in same domain)
% row          = what row in W should be plotted (default is one)
%
% OUTPUT PARAMETER
%
% X            = matrix (n x scales) used in plotting
%
%
% Copyright(C), B.K. Alsberg, The SciCraft Team, www.scicraft.org
% Last update: 8/3-06
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.


%addpath('toolboxes/core/chemometrics/WaveLab802')
%addpath('toolboxes/core/chemometrics/WaveLab802/Orthogonal')
%addpath('toolboxes/core/chemometrics/WaveLab802/DeNoising')
%addpath('toolboxes/core/chemometrics/WaveLab802/Utilities')

if nargin < 2,
  row = 1;
end;

w = W(row,:);

n = length(w);
J = loge(n,2) -1;
w = abs(w);

w = max(w) - w;

X = zeros(J+1,n);
for i = 0:J
   X(i+1,:) = loc_merge(w(dyad(i)),n);
end;

X = flipud(X);

%%% Local  function %%%%

function vec = loc_merge(v,n)
% vec = loc_merge(v,n)
% v = vector with coefficients
% n = total length of data (not v)

q = n/length(v);
tmp =[];
for i = 1:length(v)
   tmp = [tmp v(i)*ones(1,q)];
end;

vec = tmp;




