function [Wh] = WaveletDenoiseW(W,method,L)
% [Wh] = WaveletDenoiseW(W,method,L)
% Perform wavelet denoising on wavelet coefficients of the raw data
% and returns denoised wavelet coefficient matri
% (this is in contrast to WaveletDenoiseX which performs the
% operation on the raw data matrix directly)
%
%
% W             = wavelet coefficients for each row in data matrix 
% method        = integer indicating type of denoise method. Choices are:
%                 'Visu'
%                 'SURE'
%                 'Hybrid'
%                 'MinMax'
%                 'MAD'
% L             = Coarsest Level of V_0;  L << J (Default=0)
%
% OUTPUT VARIABLES
%
% Wh            = the corresponding wavelet coefficient matrixc
%                 (one for every row) after the wavelet denoising
%
%
% Copyright(C), B.K. Alsberg, The SciCraft Team, www.scicraft.org
% Last update: 8/3-06
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

if nargin < 3,
  L =0;
end;

[N,M] = size(W);


[n,J] = dyadlength(W(1,:));


if strcmp(method,'Visu'),
  for i = 1:N
    wc = W(i,:);
    wc((2^(L)+1):n) = W(i,(2^(L)+1):n);
    Wh(i,:) = VisuThresh(wc) ;
  end;
elseif strcmp(method,'SURE'),
  for i = 1:N
    Wh(i,:) = MultiSURE(W(i,:),L);
  end;
  
elseif strcmp(method,'Hybrid'),
  for i = 1:N
    Wh(i,:) = MultiHybrid(W(i,:),L);
  end;
  
elseif strcmp(method,'MinMax'),
  for i = 1:N
    wc = W(i,:);
    wc((2^(L)+1):n) = W(i,(2^(L)+1):n);
    Wh(i,:) = MinMaxThresh(wc) ;
  end;
  
elseif strcmp(method,'MAD'),
  for i = 1:N
    Wh(i,:) = MultiMAD(W(i,:),L);
  end;
else
  error('Wrong denoising method selected');
end



