function [T,v] = deflate(X,a)



%inflate-deflate functions
%A singular value decomposition on a matrix. The left eigenvectors are mult. with 
% the accomp. eigenvalues (T).
%
%file: deflate.m
%
%input:		X - matrix to deflate
%		a - optional (# factors if less than max(m,n))
%
%output: 	v - original row space 
%		T - scaled column space of decomposition (scores)
%
%
% $$$ ## This file is part of SciCraft.
% $$$ ##
% $$$ ## SciCraft is free software; you can redistribute it and/or modify it
% $$$ ## under the terms of the GNU General Public License as published by
% $$$ ## the Free Software Foundation; either version 2, or (at your option)
% $$$ ## any later version.
% $$$ ##
% $$$ ## SciCraft is distributed in the hope that it will be useful, but
% $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
% $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% $$$ ## General Public License for more details.
% $$$ ##
% $$$ ## You should have received a copy of the GNU General Public License
% $$$ ## along with SciCraft; see the file COPYING.  If not, write to the Free
% $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
% $$$ ## 02111-1307, USA.
% $$$ 
% $$$ ## -*- texinfo -*-

if nargin == 1 % use 
a = min(size(X));
end
[m,n] = size(X');
if m>n
  if a>n
    error(['Max number of factors to use is:  ' num2str(min(m,n))]);
  end
  [v,sig,u] = svd(X',0);
  T = u(:,1:a)*sig(1:a,1:a);
  %Xn = u(1:a)*sig(1:a,1:a)*v(:,1:a)';
else
  error('There is no need to deflate this matrix: nVars less than samples!');
end









