function [W,T,P,Q,B] = plsr(X,Y,aMax,mcent)
% $$$ ## -*- texinfo -*-

%PLSR algorithm that handles one or more Y-variables 
%
%[W,T,P,Q,B] = plsr(X,Y,aMax,meanCtr)
%
%Input variables:
%  X/Y:     Input data
%  aMax:    Number of components to calculate
%  mcent: If true, data are mean-centered prior to analysis
%
%Output variables:
%  W:       Loading weights
%  T:       Scores
%  P/Q:     X-/ Y-loadings
%  B:       Regression coefficients
%
%Wolds PLSR is performed. The algorithm is faster when the number
%of columns is larger than the number of rows in X (nVars>nSamples)
%
%Related functions:
%crossval.m, plsrnipals.m, plsrmartens.m, pcr.m

%author L. Gidskehaug, Oct 08, 2002
% $$$ ## This file is part of SciCraft.
% $$$ ##
% $$$ ## SciCraft is free software; you can redistribute it and/or modify it
% $$$ ## under the terms of the GNU General Public License as published by
% $$$ ## the Free Software Foundation; either version 2, or (at your option)
% $$$ ## any later version.
% $$$ ##
% $$$ ## SciCraft is distributed in the hope that it will be useful, but
% $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
% $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% $$$ ## General Public License for more details.
% $$$ ##
% $$$ ## You should have received a copy of the GNU General Public License
% $$$ ## along with SciCraft; see the file COPYING.  If not, write to the Free
% $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
% $$$ ## 02111-1307, USA.
% $$$ 
[nSamples,nVars] = size(X);

if mcent == 1,
  meanX = mean(X);
  meanY = mean(Y);
  X = X - ones(nSamples,1)*meanX;
  Y = Y - ones(nSamples,1)*meanY;
end %if

T = zeros(nSamples,aMax);
W = zeros(nVars,aMax);
E = X;
II = eye(nSamples);
for a=1:aMax
  [U,S,V] = svd(E'*Y,0);
  w = U(:,1);
  t = E*w;
  E = (II-t*t'/(t'*t))*E;
  W(:,a) = w;
  T(:,a) = t;
end %for

P = X'*T*inv(T'*T);
Q = Y'*T*inv(T'*T);
B = W*inv(P'*W)*Q';
