function [A2, Q, r] = procrust( A, B )
% $$$ ## -*- texinfo -*-

% PROCRUST Orthogonal Procrustes problem
%    A2 = PROCRUST( A, B ) applies an orthogonal transformation to matrix B
%    by multiplication with Q such that A-B*Q has minimum Frobenius norm. The
%    results B*Q is returned as A2.
%
%    [A2, Q] = PROCRUST( A, B ) also returns the orthogonal matrix Q that was
%    used for the transformation.
%
%    [A2, Q, R] = PROCRUST( A, B ) also returns the Frobenius norm of A-B*Q.

% Author : E. Larsen
% Date   : 12/22/03
% Email  : erik.larsen@ieee.org

% Reference: Golub and van Loan, p. 601.

% $$$ ## This file is part of SciCraft.
% $$$ ##
% $$$ ## SciCraft is free software; you can redistribute it and/or modify it
% $$$ ## under the terms of the GNU General Public License as published by
% $$$ ## the Free Software Foundation; either version 2, or (at your option)
% $$$ ## any later version.
% $$$ ##
% $$$ ## SciCraft is distributed in the hope that it will be useful, but
% $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
% $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% $$$ ## General Public License for more details.
% $$$ ##
% $$$ ## You should have received a copy of the GNU General Public License
% $$$ ## along with SciCraft; see the file COPYING.  If not, write to the Free
% $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
% $$$ ## 02111-1307, USA.
% $$$ 
% Error checking
msg = nargchk( 2, 2, nargin );
if ~isempty( msg )
  error( msg );
end

% Do the computation
C = B.'*A;
[U, S, V] = svd( C );
Q = U*V.';
A2 = B*Q;

% Optional output of norm
if nargout > 2
  r = norm( A-A2, 'fro' );
end
