AgilentFilterRG <-function(RG,BothChannels=TRUE,NotFound="Remove spots that were not found",ControlSpots="Weigh down controls",FilterMethod="Remove spots",NoiseWeights="No noise weights",RedMinIntensity=200,GreenMinIntensity=200,RedBgRatio=2,GreenBgRatio=2,SaturationLimit=50,PixelLimit= 25,MaxMdev=2){

#Last update: 20/3-06
# $$$ ## This file is part of SciCraft.
# $$$ ##
# $$$ ## SciCraft is free software; you can redistribute it and/or modify it
# $$$ ## under the terms of the GNU General Public License as published by
# $$$ ## the Free Software Foundation; either version 2, or (at your option)
# $$$ ## any later version.
# $$$ ##
# $$$ ## SciCraft is distributed in the hope that it will be useful, but
# $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
# $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# $$$ ## General Public License for more details.
# $$$ ##
# $$$ ## You should have received a copy of the GNU General Public License
# $$$ ## along with R; see the file COPYING.  If not, write to the Free
# $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
# $$$ ## 02111-1307, USA.
# $$$ 
# $$$ ## -*- texinfo -*-
#
#
  
library(limma)
#######Functions to handle control spots###############
##################################################
weighdownControls<-function(RG) {

gene_index<- RG$genes$ControlType == 0

RG$weights[!gene_index,]=10^-6
RG

}

get_genes<-function(RG) {

gene_index<- RG$genes$ControlType == 0

RG<-RG[gene_index,]
RG

#make sure integrity of replicates
}


#######################################################
######################################################


if (is.null(RG$weights)){
RG$weights <- matrix(1,nrow=dim(RG$R)[1],ncol=dim(RG$R)[2])
}


#set up initial information about the dataset
n_arrays<-dim(RG)
n_spots <-n_arrays[1]
n_arrays<-n_arrays[2]


#Detect bad spots
#If both channals are saturated

Gsat_index <- (RG$other$gNumSatPix/RG$other$gNumPix)*100 > SaturationLimit
Rsat_index <- (RG$other$gNumSatPix/RG$other$gNumPix)*100 > SaturationLimit
size_index <- 0.5*(RG$other$gNumPix+RG$other$rNumPix) < PixelLimit

#If both cannals are low
g_index <- RG$G < GreenMinIntensity | RG$G < RG$Gb*GreenBgRatio 
r_index <- RG$R < RedMinIntensity | RG$R < RG$Rb*RedBgRatio 

#Identify spots that were not found


if(NotFound=="Remove spots that were not found"){
 nf_index <- !(as.logical(RG$other$gIsFound) | as.logical(RG$other$rIsFound))
}
else{nf_index <- as.logical(matrix(0,nrow=n_spots,ncol=n_arrays))}

dM = sqrt((1/RG$R^2)*(RG$other$rPixSDev^2)/sqrt(RG$other$rNumPix)+(1/RG$G^2)*(RG$other$gPixSDev^2)/sqrt(RG$other$gNumPix))

#Correct Standard deviation for number of pixels?????????


s2n_index <- dM > MaxMdev

 if (BothChannels=="TRUE") {  
  spot_index <- g_index & r_index  | s2n_index  | (Gsat_index & Rsat_index) | size_index |nf_index
 } 
 else{
  spot_index <- g_index | r_index | Rsat_index|Gsat_index | s2n_index | size_index  | nf_index
 }



#set to NA or use weights
if (FilterMethod=="Remove spots"){
 RG$G[spot_index]<-NA
 RG$R[spot_index]<-NA
 RG$weights[spot_index] <-0
}

#Add delta parameter?????????????????

if(NoiseWeights == "Weigh by 1/(s^2+delta)"){
RG$weights <- 1/(dM+0.5)
#ind <-RG$weights > 1
#RG$weights[ind] <- 1
}

if(NoiseWeights == "Weigh by 1/s^2"){
RG$weights <- 1/(dM)
#ind <-RG$weights > 1
#RG$weights[ind] <- 1
}

if (FilterMethod == "Reduce spot weight to 10^-6"){
RG$weights[spot_index]<-10^-6
}

if (FilterMethod== "Reduce spot weight to 0.1"){
RG$weights[spot_index]<-0.1}

if (ControlSpots=="Weigh down controls"){
  RG<-weighdownControls(RG)
 }

if (ControlSpots=="Remove controls"){
  RG<- get_genes(RG)
 }

return(list(RGfiltered=RG))#,dM = dM))
}

