DiffExp <- function(MA,from_bio_matter,to_bio_matter,bio_replica,filename,physical_array,dye_swapped,ReferenceMaterial,Merges,Nduplicates){
#
#
#Last update: 20/3-06
# $$$ ## This file is part of SciCraft.
# $$$ ##
# $$$ ## SciCraft is free software; you can redistribute it and/or modify it
# $$$ ## under the terms of the GNU General Public License as published by
# $$$ ## the Free Software Foundation; either version 2, or (at your option)
# $$$ ## any later version.
# $$$ ##
# $$$ ## SciCraft is distributed in the hope that it will be useful, but
# $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
# $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# $$$ ## General Public License for more details.
# $$$ ##
# $$$ ## You should have received a copy of the GNU General Public License
# $$$ ## along with R; see the file COPYING.  If not, write to the Free
# $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
# $$$ ## 02111-1307, USA.
# $$$ 
# $$$ ## -*- texinfo -*-
#
#    
##############################
#############################
###Tidy up the input###########
###############################
##############################
from_bio_matter <- as.vector(matrix(from_bio_matter))
to_bio_matter <- as.vector(matrix(to_bio_matter))
bio_replica <-as.vector(bio_replica)
filename <- as.vector(matrix(filename))
physical_array<-as.vector(matrix(physical_array))
dye_swapped <-as.vector(matrix(dye_swapped))

bt <- bio_replica
bio_replica <- vector(mode="character",length=length(bt))

for (i in 1:length(bt)){
 bio_replica[i] <- bt[[i]][1]
}

bt <- to_bio_matter
to_bio_matter <- vector(mode="character",length=length(bt))
for (i in 1:length(bt)){
 to_bio_matter[i] <- bt[[i]][1]
}

bt <- from_bio_matter
from_bio_matter <- vector(mode="character",length=length(bt))
for (i in 1:length(bt)){
 from_bio_matter[i] <- bt[[i]][1]
}

bt <- filename
filename <- vector(mode="character",length=length(bt))
for (i in 1:length(bt)){
 filename[i] <- bt[[i]][1]
}

bt <- physical_array
physical_array <- vector(mode="character",length=length(bt))
for (i in 1:length(bt)){
 physical_array[i] <- bt[[i]][1]
}

bt <- dye_swapped
dye_swapped <- vector(mode="character",length=length(bt))
for (i in 1:length(bt)){
 dye_swapped[i] <- bt[[i]][1]
}


design <- list(from_bio_matter=from_bio_matter,to_bio_matter = to_bio_matter,bio_replica=bio_replica,filename=filename,physical_array=physical_array,dye_swap=dye_swapped)
design <-as.data.frame(design)

#############################################
############################################
#####Merging functions
###########################################
##########################################
merge_techs <- function(MA,design){
library(limma)
to_bio_matter <- design$to_bio_matter
from_bio_matter <-design$from_bio_matter
dyeswap <- design$dye_swapped
bioreplicate <- design$bio_replica
#Change to and from to include dye swaps
dye_ind <- dyeswap == "Yes"
to_temp <-to_bio_matter
to_temp[dye_ind] <- from_bio_matter[dye_ind]
from_bio_matter[dye_ind] <- to_bio_matter[dye_ind]

#Decide on size of output arrays
#Try to find arrays from the same biorplica
fromto <-paste(from_bio_matter,to_bio_matter)
i <- 0

for (contrast in unique(fromto)){
 contrast_ind <- fromto==contrast
  for (bior in unique(as.vector(bioreplicate[contrast_ind]))){
   ind <- (fromto==contrast & bioreplicate==bior)
    i <- i +1
 }
}

n_genes <- dim(MA)[1]
MATargets <-MA[,1:i]
M <- matrix(0,nrow = n_genes,ncol = i)
A <- matrix(0,nrow = n_genes,ncol = i)
W <- matrix(0,nrow = n_genes,ncol = i)
design_up <- design[1:i,]

i <- 0

for (contrast in unique(fromto)){
 contrast_ind <- fromto==contrast
  for (bior in unique(as.vector(bioreplicate[contrast_ind]))){
    ind <- (fromto==contrast & bioreplicate==bior)
     i <- i +1     
     M[,i] <- rowSums(MA$M[,ind]*MA$weights[,ind],na.rm=T)/rowSums(MA$weights,na.rm=T)
     A[,i] <- rowSums(MA$A[,ind]*MA$weights[,ind],na.rm=T)/rowSums(MA$weights,na.rm=T)
     W[,i] <- rowMeans(as.matrix(MA$weights[,ind]),na.rm=T)
    
    design_temp <- design[ind,]
    design_up[i,] <-design_temp[1,]
    #Deal with the target field
    MATargets$targets[i,] <- MA$targets[ind,][1]
   #Design list needs to be updated 
   }
   
 }


   
MATargets$M <-M
MATargets$A <-A
MATargets$weights <-W

return(list(MA=MATargets,design=design_up))

}

Compute.design.matrix <- function(design,MA,ReferenceMaterial){

biomats <- c(as.vector(design$from_bio_matter),as.vector(design$to_bio_matter))
biomats <- unique(biomats)
biomats <- biomats[!biomats == ReferenceMaterial]

n <- dim(design)[1]
des <- matrix(0,nrow = n,ncol = length(biomats))
colnames(des) <- biomats

for (i in 1:n){
 if (!design$from_bio_matter[i]==ReferenceMaterial){
  des[i,design$from_bio_matter[i]==biomats] <- -1
  }

 if (!design$to_bio_matter[i]==ReferenceMaterial){
  des[i,design$to_bio_matter[i]==biomats] <- 1
  }

colnames(des) <- biomats  
des

}
}

###########################
############################################
###########Main function
#################################
################################

biomats <- c(as.vector(design$from_bio_matter),as.vector(design$to_bio_matter))
biomats <- unique(biomats)
biomats <- biomats[!biomats == ReferenceMaterial]



if (Merges == "MergeReplicates"){
MA <- merge_techs(MA,design)
design<-MA$design
MA <- MA$MA
}

des <- Compute.design.matrix(design,MA,ReferenceMaterial)

library(limma)
library(affy)

#Make main model


fit <- lmFit(MA,design=des,ndups=Nduplicates,method="ls")

k <- 0
CM <- matrix(0,length(biomats),(length(biomats)^2 - length(biomats))/2)
rownames(CM) <- biomats

if(length(biomats) > 1){


for (i in 1:(length(biomats)-1)){
 for (j in (i+1):length(biomats)){
  
  if (k == 0){
   ContrastsString <- paste(biomats[i]," - ", biomats[j])
     
  }
  else{
   ContrastsString <- c(ContrastsString,paste(biomats[i]," - ", biomats[j]))  
  }
  k <- k+1
 
  cont <- ContrastsString[k]
  
  CM[biomats[i],k] <-  1
  CM[biomats[j],k] <- -1
  
  print(i-j)
 }
}
colnames(CM) <- ContrastsString
print(CM)
#makeContrastFit
fit2 <- contrasts.fit(fit,CM)
ContrastsModel <- eBayes(fit2)
}
else{ContrastsModel <- 0}

ReferenceModel <- eBayes(fit)

return(list(ReferenceModel=ReferenceModel,ContrastsModel=ContrastsModel,Biomaterials=biomats,Contrasts=ContrastsString))

}

#Fit contrasts between all Bio Materials
