FilterMA <- function(MA,GeneStatus,SortGenes="TRUE",RemoveControls=TRUE,MergeDuplicates="TRUE"){
# this function filters out genes that are missing in to many arrays,removes control spots 
# and sorts genes to make repicate spots appear together.

#Last update: 20/3-06
# $$$ ## This file is part of SciCraft.
# $$$ ##
# $$$ ## SciCraft is free software; you can redistribute it and/or modify it
# $$$ ## under the terms of the GNU General Public License as published by
# $$$ ## the Free Software Foundation; either version 2, or (at your option)
# $$$ ## any later version.
# $$$ ##
# $$$ ## SciCraft is distributed in the hope that it will be useful, but
# $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
# $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# $$$ ## General Public License for more details.
# $$$ ##
# $$$ ## You should have received a copy of the GNU General Public License
# $$$ ## along with R; see the file COPYING.  If not, write to the Free
# $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
# $$$ ## 02111-1307, USA.
# $$$ 
# $$$ ## -*- texinfo -*-
#
#  

library(limma)


get_genes<-function(RG,GeneStatus="cDNA"){

gene_index <- RG$genes$Status == GeneStatus

RG<-RG[gene_index,]
RG

#make sure integrity of replicates
}

sortGenes <- function(RG){
 #Sort by ID  
   #Sort list object
   ID_index <- sort(RG$genes$ID,index.return=T)
   RG <- RG[ID_index$ix,]   
 #Data organized 
}

averageGenes <- function(MA){

#MA <- sortGenes(MA)
Dims <-dim(MA)
N <- unique(MA$genes$ID)
M<-matrix(0,length(N),Dims[2])
A <-matrix(0,length(N),Dims[2])
MA2 <-MA[1:length(N),]
W <-matrix(1,length(N),Dims[2])


for (i in 1:length(N)){
 gene_index <- MA$gene$ID==N[i]
 if (sum(gene_index) > 1.5){	
   w<-as.matrix(colSums(as.matrix(MA$weights[gene_index,]),na.rm=T))
   #print(w) 
   na_ind<-w==0
   w[na_ind] <- NA
   M[i,] <- colSums(as.matrix(MA$M[gene_index,]*MA$weights[gene_index,]),na.rm=T)/w
   A[i,] <- colSums(as.matrix(MA$A[gene_index,]*MA$weights[gene_index,]),na.rm=T)/w
   W[i,] <- colMeans(as.matrix(MA$weights[gene_index,]),na.rm=T)
  
 }
 else{
 M[i,] <- MA$M[gene_index,]
 A[i,] <- MA$A[gene_index,]
 W[i,] <- MA$weights[gene_index,]
 }
 
 MA2$genes$Name[i]<-MA$genes$Name[gene_index][1]
 MA2$genes$Status[i]<- MA$genes$Status[gene_index][1]
 
}

MA2$M <-M
MA2$A <-A
MA2$genes$ID<-N
MA2$weights <-W
MA2
}


if (SortGenes=="TRUE"){
SortGenes <-TRUE
MA<-sortGenes(MA)
}

if (RemoveControls=="TRUE"){
RemoveControls <- TRUE
MA<-get_genes(MA,GeneStatus=GeneStatus)
}

if (MergeDuplicates=="TRUE"){
MA <- averageGenes(MA)}

return(list(MAfiltered=MA))
}
