FilterRG <-function(RG,FilterInfo,GeneStatus,BothChannels=TRUE,Flags="Remove spots with negative flags",ControlSpots="Weigh down controls",FilterMethod="Remove spots",NoiseWeights="No noise weights",RedMinIntensity=200,GreenMinIntensity=200,RedBgRatio=2,GreenBgRatio=2,SaturationLimit=50,PixelLimit= 40,MaxMdev=2,delta=0.2){

#Last update: 20/3-06
# $$$ ## This file is part of SciCraft.
# $$$ ##
# $$$ ## SciCraft is free software; you can redistribute it and/or modify it
# $$$ ## under the terms of the GNU General Public License as published by
# $$$ ## the Free Software Foundation; either version 2, or (at your option)
# $$$ ## any later version.
# $$$ ##
# $$$ ## SciCraft is distributed in the hope that it will be useful, but
# $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
# $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# $$$ ## General Public License for more details.
# $$$ ##
# $$$ ## You should have received a copy of the GNU General Public License
# $$$ ## along with R; see the file COPYING.  If not, write to the Free
# $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
# $$$ ## 02111-1307, USA.
# $$$ 
# $$$ ## -*- texinfo -*-
#
#  

  
library(limma)
#######Functions to handle control spots###############
##################################################
weighdownControls<-function(RG,GeneStatus="cDNA") {

gene_index<- RG$genes$Status == GeneStatus

RG$weights[!gene_index,]=10^-6
RG

}

get_genes<-function(RG,GeneStatus="cDNA") {

gene_index<- RG$genes$Status == GeneStatus

RG<-RG[gene_index,]
RG

#make sure integrity of replicates
}

FindGeneStatus <- function(RG) {
 #find gene code
 stati <- unique(RG$genes$Status)
 counts <- vector("numeric",length(stati))
 index <- 0

  for (sta in stati) {
   index <- index+1
   ind <- RG$genes$Status==sta
   counts[index]<-sum(ind)
   }

 ind<-which.max(counts)
 GeneStatus<-stati[ind]
 GeneStatus
}

#######################################################
######################################################


if (is.null(RG$weights)){
RG$weights <- matrix(1,nrow=dim(RG$R)[1],ncol=dim(RG$R)[2])
}

 #GeneStatus<-FindGeneStatus(RG)
 
#}

#set up initial information about the dataset
n_arrays<-dim(RG)
n_spots <-n_arrays[1]
n_arrays<-n_arrays[2]


#Detect bad spots
#If both channals are saturated

Gsat_index <- FilterInfo$Gsat > SaturationLimit
Rsat_index <- FilterInfo$Rsat > SaturationLimit
size_index <- FilterInfo$FGpixels < PixelLimit

print(PixelLimit)
print(dim(FilterInfo$Rsat))

#If both cannals are low
g_index <- RG$G < GreenMinIntensity | RG$G < RG$Gb*GreenBgRatio 
r_index <- RG$R < RedMinIntensity | RG$R < RG$Rb*RedBgRatio 


if (Flags == "Remove spots with negative flags") {
 w_index <- FilterInfo$Flags < 0
 RG$G[w_index]<-NA
 RG$R[w_index]<-NA
 RG$weights[w_index] <- 0
}


if (Flags == "Reduce spot weight to 10^-6") {
 w_index <- FilterInfo$Flags < -0.1
 RG$weights[w_index]<- 10^-6
}

if (Flags == "Reduce spot weight to 0") {
 w_index <- FilterInfo$Flags < -0.1
 RG$weights[w_index]<- 0
}

#Signal to noise for both channals
#Rs2n <- (sqrt(FilterInfo$R_SD^2))/RG$R
#Gs2n <- (sqrt(FilterInfo$G_SD^2))/RG$G

dM = sqrt((1/RG$R^2)*(FilterInfo$R_SD^2)+(1/RG$G^2)*(FilterInfo$G_SD^2))

#Correct Standard deviation for number of pixels?????????
print("lalala")

s2n_index <- dM > MaxMdev

 if (BothChannels=="TRUE") {
  print(dim(g_index))
  print(dim(r_index))
  print(dim(s2n_index))
  print(dim(Gsat_index))
  print(dim(Rsat_index))
  print(dim(size_index))
  
  spot_index <- g_index & r_index  | s2n_index  | (Gsat_index & Rsat_index) | size_index
  print("lalala")
 } 
 else{
  spot_index <- g_index | r_index | Rsat_index|Gsat_index | s2n_index | size_index 
 }



#set to NA or use weights
if (FilterMethod=="Remove spots"){
 RG$G[spot_index]<-NA
 RG$R[spot_index]<-NA
 RG$weights[spot_index] <-0
}

dM = sqrt((1/RG$R^2)*(FilterInfo$R_SD^2)+(1/RG$G^2)*(FilterInfo$G_SD^2))



if(NoiseWeights == "Weigh by 1/(s^2+delta)"){
RG$weights <- 1/(dM+delta)
#ind <-RG$weights > 1
#RG$weights[ind] <- 1
}

if(NoiseWeights == "Weigh by 1/s^2"){
RG$weights <- 1/(dM)
#ind <-RG$weights > 1
#RG$weights[ind] <- 1
}

if (FilterMethod == "Reduce spot weight to 10^-6"){
RG$weights[spot_index]<-10^-6
}

if (FilterMethod== "Reduce spot weight to 0.1"){
RG$weights[spot_index]<-0.1}

if (FilterMethod== "Reduce spot weight to 0"){
RG$weights[spot_index]<-0}


if (ControlSpots=="Weigh down controls"){
  RG<-weighdownControls(RG,GeneStatus=GeneStatus)
 }

if (ControlSpots=="Remove controls"){
  RG<- get_genes(RG,GeneStatus=GeneStatus)
 }

print(colSums(is.na(RG$R)))
print(colSums(RG$weights))
return(list(RGfiltered=RG))#,dM = dM))
}

