SpikeCheck <- function(MA,SpikeFile="SpikeMix2_ratios.csv"){

#Last update: 20/3-06
# $$$ ## This file is part of SciCraft.
# $$$ ##
# $$$ ## SciCraft is free software; you can redistribute it and/or modify it
# $$$ ## under the terms of the GNU General Public License as published by
# $$$ ## the Free Software Foundation; either version 2, or (at your option)
# $$$ ## any later version.
# $$$ ##
# $$$ ## SciCraft is distributed in the hope that it will be useful, but
# $$$ ## WITHOUT ANY WARRANTY; without even the implied warranty of
# $$$ ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# $$$ ## General Public License for more details.
# $$$ ##
# $$$ ## You should have received a copy of the GNU General Public License
# $$$ ## along with R; see the file COPYING.  If not, write to the Free
# $$$ ## Software Foundation, 59 Temple Place - Suite 330, Boston, MA
# $$$ ## 02111-1307, USA.
# $$$ 
# $$$ ## -*- texinfo -*-
#
#      
library(limma)
library(boot)


#spike load
#load spike mix file
Spikes<-read.table(file=SpikeFile,sep=",",skip=2,col.names=c("Number","ID","Ratio","M","Cy5","Cy3"))

#Build MA object of spikes only

#get spikes from MA object
# and build a set of expected ratios
spike_ind <- MA$genes$ID == Spikes$ID[1]
reps<-sum(spike_ind)

M <- vector("numeric",reps)+Spikes$M[1]

MAspike<-MA[spike_ind,]
scatters <- matrix(0,nrow=length(Spikes$ID),ncol = dim(MA)[2])
scatters[1] <- mad(MAspike$M,na.rm=TRUE)

#bias
biases = matrix(0,nrow=length(Spikes$ID),ncol=dim(MA)[2])
biases[1] = mad(MAspike$M,na.rm=TRUE,center = Spikes$M[1])

for (i in 2:(dim(Spikes)[1])){
 spike_ind <- MA$genes$ID == Spikes$ID[i]
 MAspike<-rbind(MAspike,MA[spike_ind,])
 reps<-sum(spike_ind)
 M <- c(M,vector("numeric",reps)+Spikes$M[i])
}



#for each spike
 for (i in 1:(dim(Spikes)[1])){
  #for each array
  for (j in 1:dim(MA)[2]){
  spike_ind <- MA$genes$ID == Spikes$ID[i]
  scatters[i,j] <- mad(MA$M[spike_ind,j],na.rm=TRUE)
  biases[i,j] <- median(MA$M[spike_ind,j]-Spikes$M[i],na.rm=TRUE)
}
}

medbiases = colMeans(biases,na.rm=T)
medscatters = colMeans(scatters,na.rm=T)

scatters = rbind(scatters,medscatters)
biases= rbind(biases,medbiases)


#x11()
#plot(M,MAspike$M,title="Correlation for first array")

return(list(MAspike=MAspike,Mtrue=M,bias=biases,scatter = scatters,SpikeIDs = c(Spikes$ID,"ArrayMean")))
}
